﻿--[[
****************************************************************************************
AckisRecipeList v0.6
15 October 2007
(Written for live servers v2.2.0.7272)

Author: Ackis on Gurubashi US Horde
****************************************************************************************
Description:
	Scans a currently open tradeskill window, and displays a list of missing recipes (along with how to
	get them) in the chat window or a seperate window.

Notes:
	Currently my first add-on.  It is a learning experience for myself and there will be bugs and other
	problems that crop up during the development cycle.

Known Issues:
	If headings are closed, they do not expand properly when scanning a trade skill (they will
		expand but the recipes under them will not be included in the scan).
	If "have materials" is checked, only recipes that show up will be scanned.
	Data for skills needs to be updated, specifically:
		-Jewelcrafting
	Too many globals in the add-on
	Too much of the add-on is exposed (global functions) (is local func bob same as func addon:bob?)

Where to contact me:
	Contact me via e-mail (see TOC), on the WoW Ace Forums, or even in-game (if I'm not raiding)
	http://www.wowace.com/forums/index.php?topic=8670.0

What I need:
	Any missing recipe names from scans along with how to aquire them.

Credits:
	Ideas for the mod came from FGTradeLacker (original mod no longer updated, however someone has
	taken over updating the recipes for it)
	Ace2 community for listening to my questions on the IRC channel and helping me out.
	Add-ons suchs as Spellbinder, FGTradelacker which I reviewed code on how to figure out things
	Beast training information obtained from Petopia

****************************************************************************************
]]

local Crayon	= AceLibrary("LibCrayon-3.0")
local BTS		= AceLibrary("Babble-Tradeskill-2.2")
local BFAC		= AceLibrary("Babble-Faction-2.2")
local BCLASS	= AceLibrary("Babble-Class-2.2")
local L			= AceLibrary("AceLocale-2.2"):new("AckisRecipeList")

AckisRecipeList = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")

-- Namespace for an array containing recipes
local RecipeListing = nil
local MissingRecipeListing = nil
local SkillType = nil
local FoundRecipes = nil
local NumberOfRecipes = nil
local AckisRecipeListFrame  = nil

-- Command line options for the mod.
-- Allows you to filter which recipes to display based on faction, class, profession speciality, rare raid recipes, and current/max skill level

local command_options = {
    type = "group",
    args =
	{
		scan =
		{
			type = "execute",
			name = "scan",
			desc = L["SCAN"],
			func = "AckisRecipeList_SCAN",
			order = 1,
		},
		guiscan =
		{
			type = "execute",
			name = "guiscan",
			desc = L["GUISCAN"],
			func = "AckisRecipeList_GUISCAN",
			order = 2,
		},
    	title =
		{
    		type = "header",
    		name = L["ARL_CONFIG_HEADER"],
    		order = 3,
    	},
        display =
		{
            type = "group",
			name = "display",
			desc = L["DISPLAY_OPTIONS"],
			order = 4,
			args =
				{
				factions =
					{
                    name      = "faction",
                    desc      = L["FACTION_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllFactions",
                    set       = "ToggleAllFactions",
                    order     = 1,
					},
				classes =
					{
                    name      = "classes",
                    desc      = L["CLASS_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllClasses",
                    set       = "ToggleAllClasses",
                    order     = 2,
					},
				specialities =
					{
                    name      = "specialities",
                    desc      = L["SPECIALITY_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllSpecialities",
                    set       = "ToggleAllSpecialities",
                    order     = 3,
					},
				raid =
					{
                    name      = "raid",
                    desc      = L["RAID_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllRaid",
                    set       = "ToggleAllRaid",
                    order     = 4,
					},
				skill =
					{
                    name      = "skill",
                    desc      = L["SKILL_TOGGLE"],
                    type      = "toggle",
                    get       = "GetAllSkill",
                    set       = "ToggleAllSkill",
                    order     = 5,
					}
				}
		},
		sorting =
		{
			name      = "sort",
			desc      = L["SORT_OPTIONS"],
			type      = "text",
			validate  = { L["SORT_Name"], L["SORT_Skill"], L["SORT_Unsorted"] },
			get       = "GetAllSorting",
			set       = function(name) AckisRecipeList:ToggleAllSorting(name) end,
			order     = 5,
		}
	}
}


--[[

	Saved variables functions

]]--

-- Initialize the database and set the default options

AckisRecipeList:RegisterDB("AckisRecipeListDB", "AckisRecipeListDBPC")

-- Set default options, which are to include everything in the scan
AckisRecipeList:RegisterDefaults("profile",
	{
    faction = true,
	classes = false,
	specialities = false,
	raid = true,
	skill = true,
	sorting = L["SORT_Skill"],
	}
)

-- Returns the  value of the Sorting variable in the database.

function AckisRecipeList:GetAllSorting()

	return AckisRecipeList.db.profile.sorting

end

-- Toggles the boolean value of the AllFactions variable in the database.

function AckisRecipeList:ToggleAllSorting(NewValue)

	AckisRecipeList.db.profile.sorting = NewValue

end

-- Returns the boolean value of the AllFactions variable in the database.

function AckisRecipeList:GetAllFactions()

	return AckisRecipeList.db.profile.faction

end

-- Toggles the boolean value of the AllFactions variable in the database.

function AckisRecipeList:ToggleAllFactions()

	AckisRecipeList.db.profile.faction = not AckisRecipeList.db.profile.faction

end

-- Returns the boolean value of the AllClasses variable in the database.

function AckisRecipeList:GetAllClasses()

	return AckisRecipeList.db.profile.classes

end

-- Sets the boolean value of the AllClasses variable in the database.

function AckisRecipeList:ToggleAllClasses()

	AckisRecipeList.db.profile.classes = not AckisRecipeList.db.profile.classes

end

-- Returns the boolean value of the AllSpecialities variable in the database.

function AckisRecipeList:GetAllSpecialities()

	return AckisRecipeList.db.profile.specialities

end

-- Sets the boolean value of the AllSpecialities variable in the database.

function AckisRecipeList:ToggleAllSpecialities()

	AckisRecipeList.db.profile.specialities = not AckisRecipeList.db.profile.specialities

end

-- Returns the boolean value of the AllRaid variable in the database.

function AckisRecipeList:GetAllRaid()

	return AckisRecipeList.db.profile.raid

end

-- Sets the boolean value of the AllRaid variable in the database.

function AckisRecipeList:ToggleAllRaid()

	AckisRecipeList.db.profile.raid = not AckisRecipeList.db.profile.raid

end

-- Returns the value of the AllSkill variable in the database.

function AckisRecipeList:GetAllSkill()

	return AckisRecipeList.db.profile.skill

end

-- Sets the boolean value of the AllSkill variable in the database.

function AckisRecipeList:ToggleAllSkill()

	AckisRecipeList.db.profile.skill = not AckisRecipeList.db.profile.skill

end

--[[

	Reset functions

]]--

-- Empties the RecipeList table

local function ARL_ResetRecipeList()

	if ( RecipeListing ~= nil) then

		local CurrentRecipe = next(RecipeListing, nil)

		while (CurrentRecipe ~= nil) do

			RecipeListing[ CurrentRecipe ][ "Level" ] = nil
			RecipeListing[ CurrentRecipe ][ "Acquire" ] = nil
			RecipeListing[ CurrentRecipe ][ "Speciality" ] = nil		
			RecipeListing[ CurrentRecipe ][ "Known" ] = nil

			local OldRecipe = CurrentRecipe

			-- Move on to the next entry in the table
			CurrentRecipe = next(RecipeListing, CurrentRecipe)

			RecipeListing[ OldRecipe ] = nil

		end

	end

	RecipeList = nil

end

-- Empties the MissingRecipeList table

local function ARL_ResetMissingRecipeList()

	if ( MissingRecipeListing ~= nil) then

		local CurrentRecipe = next(MissingRecipeListing, nil)

		while (CurrentRecipe ~= nil) do

			MissingRecipeListing[ CurrentRecipe ][ "Level" ] = nil
			MissingRecipeListing[ CurrentRecipe ][ "Acquire" ] = nil
			MissingRecipeListing[ CurrentRecipe ][ "Speciality" ] = nil		
			MissingRecipeListing[ CurrentRecipe ][ "Known" ] = nil

			local OldRecipe = CurrentRecipe

			-- Move on to the next entry in the table
			CurrentRecipe = next(MissingRecipeListing, CurrentRecipe)

			MissingRecipeListing[ OldRecipe ] = nil

		end

	end

	MissingRecipeListing = nil

end

-- Reset all variables

local function ARL_ResetVariables()

	ARL_ResetRecipeList()
	--ARL_ResetMissingRecipeList()

	SkillType = nil
	FoundRecipes = nil
	NumberOfRecipes = nil

end

-- Initializes the initial recipe array, reseting it completely.

local function ARL_InitializeRecipeArray()

	-- Reset namespace to be empty
	RecipeListing = {}
	MissingRecipeListing = {}
  
	-- Sets the total number of recipes to 0.
	NumberOfRecipes = 0

	-- Sets the number of found recipes to 0.
	FoundRecipes = 0

end

--[[

	Initialization functions

]]--

-- When the add-on is enabled, register slash commands, and which events to watch

function AckisRecipeList:OnEnable()

	-- Add slash commands
	self:RegisterChatCommand(L["LONG_COMMAND"], L["SHORT_COMMAND"], command_options)

	-- Make addon respond to the tradeskill and crafting windows being shown
	self:RegisterEvent("TRADE_SKILL_SHOW")
	self:RegisterEvent("CRAFT_SHOW")

	-- Addon responds to tradeskill and crafting windows being closed.
	self:RegisterEvent("CRAFT_CLOSE")
	self:RegisterEvent("TRADE_SKILL_CLOSE")

end

-- Hides the frame if the mod gets disabled

function AckisRecipeList:OnDisable()

	ARL_ResetVariables()

	if AckisRecipeListFrame then

		AckisRecipeListFrame:Hide()

	end

end

-- Watch for the trade skill window to be shown, add all specific trade skills to an array, then scan the trade skill window for all recipes.

function AckisRecipeList:TRADE_SKILL_SHOW()

	SkillType = "Trade"

end

-- Clean up tables from memory when trade skill window is closed

function AckisRecipeList:TRADE_SKILL_CLOSE()

	ARL_ResetVariables()

end

-- Watch for the craft skill window to be shown, add all specific trade skills to an array, then scan the craft skill window for all recipes.

function AckisRecipeList:CRAFT_SHOW()

	SkillType = "Craft"

end

-- Clean up tables from memory when craft window is closed

function AckisRecipeList:CRAFT_CLOSE()

	ARL_ResetVariables()

end

--[[

	Tradeskill functions

]]--

-- Adds a specifc recipe to the recipe list array.  Also provides information regarding recipe level, if there is any trade skill recipe speciality, how to aquire the recipe, and if the recipe is known or not.

local function addTradeSkill(RecipeName, RecipeLevel, RecipeAquire, RecipeSpeciality, RecipeKnown)

	-- Creates a table in the RecipeListing table storing all information about a recipe
	RecipeListing[ RecipeName ] = {}
	RecipeListing[ RecipeName ][ "Level" ] = RecipeLevel
	RecipeListing[ RecipeName ][ "Acquire" ] = RecipeAquire
	RecipeListing[ RecipeName ][ "Speciality" ] = RecipeSpeciality

	if (RecipeKnown == nil) then

		RecipeListing[ RecipeName ][ "Known" ] = false

	else

		RecipeListing[ RecipeName ][ "Known" ] = RecipeKnown

	end

	-- Increment the total number of recipes added to the list
	NumberOfRecipes = NumberOfRecipes + 1

end

-- Modifies recipe array if a recipe is found, setting the Known flag as true.

function AckisRecipeList:foundTradeSkill(RecipeName)

	RecipeListing[ RecipeName ][ "Known" ] = true

	-- Increase found count
	FoundRecipes = FoundRecipes + 1

end

-- Checks to see if a recipe is known or not.  If the recipe is not in the database, output it to chat.

function AckisRecipeList:CheckRecipe(RecipeName)

	if ( RecipeListing[ RecipeName ] ) then

		-- Update array that recipe was found
		AckisRecipeList:foundTradeSkill(RecipeName)
	
	else

		-- Notify users in chat that skill is missing from the database.
		AckisRecipeList:printMissingSkill(RecipeName)

	end

end

-- Check to see if recipe should be displayed or not

function AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentSpeciality)

	-- Variable to determine if recipe is to be displayed or not, assume yes
	local displayRecipe = true

	-- Display hard to obtain raid recipes
	if ( not AckisRecipeList:GetAllRaid() ) then
	
		if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == L["Raid"] ) then

			displayRecipe = false

		end

	end

	-- Display all faction recipes
	if ( not AckisRecipeList:GetAllFactions() ) then

		local playerFaction, _ = UnitFactionGroup("player")

		-- Make sure it's Horde or Alliance
		if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BFAC["Horde"] ) or
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BFAC["Alliance"] ) then

			if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] ~= playerFaction ) then
			
				displayRecipe = false

			end

		end

	end

	-- Display all class type recipes
	if ( not AckisRecipeList:GetAllClasses() ) then

		local playerClass, _ = UnitClass("player")

		-- Make sure it's a class
		if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Warlock"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Warrior"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Hunter"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Mage"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Priest"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Druid"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Paladin"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Shaman"] ) or 
		( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BCLASS["Rogue"] ) then

			if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] ~= playerClass ) then
			
				displayRecipe = false

			end

		end

	end

	-- Display all skill levels
	if ( MissingRecipeListing[ RecipeName ][ "Level" ] > CurrentProfessionLevel ) then

		if ( not AckisRecipeList:GetAllSkill() ) then

			displayRecipe = false

		end

	end

	-- Display all specialities (ie: Primal Mooncloth, Spellcloth, etc.)
	if ( not AckisRecipeList:GetAllSpecialities() ) then

		if ( CurrentProfession == BTS["Blacksmithing"] ) then

			if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Armorsmith"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Master Axesmith"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Master Hammersmith"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Master Swordsmith"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Weaponsmith"] ) then

					if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] ~= CurrentSpeciality ) then

						displayRecipe = false

					end

			end

		elseif ( CurrentProfession == BTS["Engineering"] ) then

			if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Gnomish Engineering"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Goblin Engineering"] ) then

					if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] ~= CurrentSpeciality ) then

						displayRecipe = false

					end

			end

		elseif ( CurrentProfession == BTS["Leatherworking"] ) then

			if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Dragonscale Leatherworking"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Elemental Leatherworking"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Tribal Leatherworking"] ) then

					if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] ~= CurrentSpeciality ) then

						displayRecipe = false

					end

			end

		elseif ( CurrentProfession == BTS["Tailoring"] ) then

			if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Mooncloth Tailoring"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Shadoweave Tailoring"] ) or
				( MissingRecipeListing[ RecipeName ][ "Speciality" ] == BTS["Spellfire Tailoring"] ) then

					if ( MissingRecipeListing[ RecipeName ][ "Speciality" ] ~= CurrentSpeciality ) then

						displayRecipe = false

					end

			end

		end

	end

	return displayRecipe

end

-- Returns the number of recipes missing

function AckisRecipeList:GetNumMissingRecipes()

	return NumberOfRecipes - FoundRecipes

end

-- Scans the first 24 entries in the spellbook to find which profession speciality someone is (assumption is that it will be within the first 24 because of the general tab)

function AckisRecipeList:GetTradeSpeciality(CurrentProfession)

local index = 1

	while true do

		local spellName, _ = GetSpellName(index, BOOKTYPE_SPELL)

		if ( not spellName ) or ( index == 25 ) then

			return ""
			--break

		end

		if ( CurrentProfession == BTS["Alchemy"] ) then

			if ( spellName == BTS["Elixir Master"] ) or
				( spellName == BTS["Potion Master"] ) or
				( spellName == BTS["Transmutation Master"] ) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Blacksmithing"] ) then

			if ( spellName == BTS["Armorsmith"] ) or
				( spellName == BTS["Master Axesmith"] ) or
				( spellName == BTS["Master Hammersmith"] ) or
				( spellName == BTS["Master Swordsmith"] ) or
				( spellName == BTS["Weaponsmith"] ) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Engineering"] ) then

			if ( spellName == BTS["Gnomish Engineering"] ) or
				( spellName == BTS["Goblin Engineering"] ) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Leatherworking"] ) then

			if ( spellName == BTS["Dragonscale Leatherworking"] ) or
				( spellName == BTS["Elemental Leatherworking"] ) or
				( spellName == BTS["Tribal Leatherworking"] ) then

				return spellName

			end

		elseif ( CurrentProfession == BTS["Tailoring"] ) then

			if ( spellName == BTS["Mooncloth Tailoring"] ) or
				( spellName == BTS["Shadoweave Tailoring"] ) or
				( spellName == BTS["Spellfire Tailoring"] ) then

				return spellName

			end

		end

		index = index + 1

	end

end

--[[

	Output functions

]]--

-- Prints out to chat a message stating that a current recipe is missing from the internal database.

function AckisRecipeList:printMissingSkill(RecipeName)

	DEFAULT_CHAT_FRAME:AddMessage( Crayon:Red( RecipeName ) .. Crayon:White( L["MissingFromDB"] ) )

end

-- Prints out to chat the recipe and where it can be found.

function AckisRecipeList:PrintRecipeInfo(RecipeName)

	local RecipeMessage1 = Crayon:Purple( L["MissingRecipePrefix"] )
	local RecipeMessage2 = Crayon:Green( L["MissingRecipe"]:format (RecipeName, MissingRecipeListing[ RecipeName ][ "Level" ]) )

	if (MissingRecipeListing[ RecipeName ][ "Acquire" ] ~= nil) then

		local RecipeMessage3 = Crayon:White( L["MissingRecipeAcquire"]:format ( MissingRecipeListing[ RecipeName ][ "Acquire" ] ))

		DEFAULT_CHAT_FRAME:AddMessage(RecipeMessage1 .. RecipeMessage2 .. RecipeMessage3)

	else

		DEFAULT_CHAT_FRAME:AddMessage(RecipeMessage1 .. RecipeMessage2)

	end

end

-- Combines a rep level and faction into a single string

local function ARL_AddReputation1(RepLevel, Faction)

	return L["REPUTATIONOUTPUT1"]:format( RepLevel, Faction )

end

-- Combines a rep level and two factions into a single string

local function ARL_AddReputation2(RepLevel, Faction1, Faction2)

	return L["REPUTATIONOUTPUT2"]:format( RepLevel, Faction1, RepLevel, Faction2 )

end

-- Identifies that a scan is occuring in chat

function AckisRecipeList:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)

	if ( CurrentSpeciality == "" ) then

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage( Crayon:Purple( L["InitiateScan"]:format( CurrentProfession, CurrentProfessionLevel ) ) )

	else

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage( Crayon:Purple( L["InitiateScanSpecial"]:format( CurrentProfession, CurrentSpeciality, CurrentProfessionLevel ) ) )
	
	end

end

-- Displays a summary of known recipes, total recipes and percentages.

function AckisRecipeList:PrintRecipeListSummary()

	DEFAULT_CHAT_FRAME:AddMessage( Crayon:Purple( L["RecipeListSummary"]:format(FoundRecipes, NumberOfRecipes, math.floor( FoundRecipes / NumberOfRecipes * 100 ), AckisRecipeList:GetNumMissingRecipes() ) ) )

end

-- Determines which recipes are known and which are not known, printing them out to the chat frame.

function AckisRecipeList:DisplayRecipeResults(CurrentProfessionLevel, SortedList, CurrentProfession, CurrentSpeciality)

	-- Parse the MissingRecipeListing, printing out the entries
	if ( MissingRecipeListing ~= nil ) then

		-- No sorting at all
		if ( SortedList == nil ) then

			local RecipeName = next(MissingRecipeListing, nil)

			while ( RecipeName ~= nil ) do

				if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality) ) then

					AckisRecipeList:PrintRecipeInfo(RecipeName)

				end

				-- Move on to the next entry in the table
				RecipeName = next(MissingRecipeListing, RecipeName)
	
			end

		else

			for i, RecipeName in ipairs(SortedList) do

				if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality) ) then

					AckisRecipeList:PrintRecipeInfo(RecipeName)

				end

			end

		end

	end

	AckisRecipeList:PrintRecipeListSummary()

end

--[[

	Sorting Functions

]]--

-- Returns true if a Recipe1 has a lower skill level than Recipe2

local function ARL_SortMissingSkill(Recipe1, Recipe2)

	return MissingRecipeListing[ Recipe1 ][ "Level" ] < MissingRecipeListing[ Recipe2 ][ "Level" ]

end

-- Returns true if a Recipe1 come before Recipe2 in the alphabet

local function ARL_SortMissingName(Recipe1, Recipe2)

	return Recipe1 < Recipe2

end

-- Sorts the MissingRecipeListing with the given sorting function

function AckisRecipeList:SortMissingRecipes(SortFunction)

	local TempRecipeSort = {}

	-- Get all the indexes of the MissingRecipeListing
	for n in pairs( MissingRecipeListing ) do

		table.insert(TempRecipeSort, n)

	end

	-- Sort the indexes according to the function
	table.sort(TempRecipeSort, SortFunction)

	return TempRecipeSort

end 

--[[

	Recipe Array Functions

]]--

-- Initializes the array adding all Alchemy recipes.  As of 2.2 there are 178 recipes.

local function ARL_InitAlchemy()

	ARL_InitializeRecipeArray()

	-- Original Game Recipes
	addTradeSkill( L["Minor Healing Potion"], 1, L["Trainer"] )
	addTradeSkill( L["Elixir of Lion's Strength"], 1, L["Trainer"] )
	addTradeSkill( L["Elixir of Minor Defense"], 1, L["Trainer"] )
	addTradeSkill( L["Weak Troll's Blood Potion"], 15, L["Trainer"] )
	addTradeSkill( L["Minor Mana Potion"], 25, L["Trainer"] )
	addTradeSkill( L["Minor Rejuvenation Potion"], 40, L["Trainer"] )
	addTradeSkill( L["Elixir of Minor Agility"], 50, L["UWD"] )
	addTradeSkill( L["Discolored Healing Potion"], 50, L["Discolored Healing Potion Obt"], BFAC["Horde"] )
	addTradeSkill( L["Elixir of Minor Fortitude"], 50, L["Trainer"] )
	addTradeSkill( L["Lesser Healing Potion"], 55, L["Trainer"] )
	addTradeSkill( L["Rage Potion"], 60, L["Vendor"] )
	addTradeSkill( L["Swiftness Potion"], 60, L["UWD"] )
	addTradeSkill( L["Blackmouth Oil"], 80, L["Trainer"] )
	addTradeSkill( L["Elixir of Wisdom"], 90, L["Trainer"] )
	addTradeSkill( L["Elixir of Water Breathing"], 90, L["Trainer"] )
	addTradeSkill( L["Elixir of Giant Growth"], 90, L["UWD"] )
	addTradeSkill( L["Holy Protection Potion"], 100, L["Vendor"] )
	addTradeSkill( L["Swim Speed Potion"], 100, L["Trainer"] )
	addTradeSkill( L["Minor Magic Resistance Potion"], 110, L["UWD"] )
	addTradeSkill( L["Healing Potion"], 110, L["Trainer"] )
	addTradeSkill( L["Lesser Mana Potion"], 120, L["Trainer"] )
	addTradeSkill( L["Potion of Curing"], 120, L["UWD"] )
	addTradeSkill( L["Strong Troll's Blood Potion"], 125, L["Trainer"] )
	addTradeSkill( L["Elixir of Defense"], 130, L["Trainer"] )
	addTradeSkill( L["Fire Oil"], 130, L["Trainer"] )
	addTradeSkill( L["Shadow Protection Potion"], 135, L["Vendor"] )
	addTradeSkill( L["Elixir of Lesser Agility"], 140, L["UWD"] )
	addTradeSkill( L["Elixir of Firepower"], 140, L["Trainer"] )
	addTradeSkill( L["Elixir of Ogre's Strength"], 150, L["UWD"] )
	addTradeSkill( L["Free Action Potion"], 150, L["Vendor"] )
	addTradeSkill( L["Greater Healing Potion"], 155, L["Trainer"] )
	addTradeSkill( L["Mana Potion"], 160, L["Trainer"] )
	addTradeSkill( L["Lesser Invisibility Potion"], 165, L["Trainer"] )
	addTradeSkill( L["Shadow Oil"], 165, L["Vendor"] )
	addTradeSkill( L["Fire Protection Potion"], 165, L["Vendor"] )
	addTradeSkill( L["Elixir of Fortitude"], 175, L["UWD"] )
	addTradeSkill( L["Great Rage Potion"], 175, L["Vendor"] )
	addTradeSkill( L["Mighty Troll's Blood Potion"], 180, L["Mighty Trolls Blood Potion Obt"] )
	addTradeSkill( L["Elixir of Agility"], 185, L["Trainer"] )
	addTradeSkill( L["Frost Protection Potion"], 190, L["Vendor"] )
	addTradeSkill( L["Nature Protection Potion"], 190, L["Vendor"] )
	addTradeSkill( L["Elixir of Frost Power"], 190, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Elixir of Detect Lesser Invisibility"], 195, L["UWD"] )
	addTradeSkill( L["Elixir of Greater Defense"], 195, L["Trainer"] )
	addTradeSkill( L["Frost Oil"], 200, L["Vendor"] )
	addTradeSkill( L["Catseye Elixir"], 200, L["Trainer"] )
	addTradeSkill( L["Oil of Immolation"], 205, L["Trainer"] )
	addTradeSkill( L["Greater Mana Potion"], 205, L["Trainer"] )
	addTradeSkill( L["Magic Resistance Potion"], 210, L["UWD"] )
	addTradeSkill( L["Goblin Rocket Fuel"], 210, L["Vendor"] )
	addTradeSkill( L["Lesser Stoneshield Potion"], 215, L["Lesser Stoneshield Potion Obt"] )
	addTradeSkill( L["Restorative Potion"], 215, L["Restorative Potion Obt"] )
	addTradeSkill( L["Superior Healing Potion"], 215, L["Trainer"] )
	addTradeSkill( L["Elixir of Greater Water Breathing"], 215, L["Trainer"] )
	addTradeSkill( L["Wildvine Potion"], 225, L["Wildvine Potion Obt"] )
	addTradeSkill( L["Philosopher's Stone"], 225, L["Vendor"] )
	addTradeSkill( L["Transmute: Iron to Gold"], 225, L["Vendor"] )
	addTradeSkill( L["Transmute: Mithril to Truesilver"], 225, L["Vendor"] )
	addTradeSkill( L["Elixir of Detect Undead"], 230, L["Trainer"] )
	addTradeSkill( L["Dreamless Sleep Potion"], 230, L["Trainer"] )
	addTradeSkill( L["Arcane Elixir"], 235, L["Trainer"] )
	addTradeSkill( L["Invisibility Potion"], 235, L["UWD"] )
	addTradeSkill( L["Elixir of Greater Intellect"], 235, L["Trainer"] )
	addTradeSkill( L["Gift of Arthas"], 240, L["Gift of Arthas Obt"] )
	addTradeSkill( L["Elixir of Greater Agility"], 240, L["Trainer"] )
	addTradeSkill( L["Elixir of Dream Vision"], 240, L["UWD"] )
	addTradeSkill( L["Elixir of Giants"], 245, L["UWD"] )
	addTradeSkill( L["Ghost Dye"], 245, L["Vendor"] )
	addTradeSkill( L["Elixir of Shadow Power"], 250, L["Vendor"] )
	addTradeSkill( L["Elixir of Demonslaying"], 250, L["Vendor"] )
	addTradeSkill( L["Elixir of Detect Demon"], 250, L["Trainer"] )
	addTradeSkill( L["Stonescale Oil"], 250, L["Trainer"] )
	addTradeSkill( L["Limited Invulnerability Potion"], 250, L["UWD"] )
	addTradeSkill( L["Elixir of Greater Firepower"], 250, L["Elixir of Greater Firepower Obt"] )
	addTradeSkill( L["Mighty Rage Potion"], 255, L["Mighty Rage Potion Obt"] )
	addTradeSkill( L["Superior Mana Potion"], 260, L["Vendor"] )
	addTradeSkill( L["Elixir of Superior Defense"], 265, L["Vendor"] )
	addTradeSkill( L["Elixir of the Sages"], 270, L["Elixir of the Sages Obt"] )
	addTradeSkill( L["Transmute: Arcanite"], 275, L["Vendor"] )
	addTradeSkill( L["Major Healing Potion"], 275, L["Vendor"] )
	addTradeSkill( L["Elixir of Brute Force"], 275, L["Elixir of Brute Force Obt"] )
	addTradeSkill( L["Transmute: Air to Fire"], 275, ARL_AddReputation1( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Transmute: Earth to Water"], 275, ARL_AddReputation1( BFAC["Friendly"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Transmute: Earth to Life"], 275, L["UWD"] )
	addTradeSkill( L["Transmute: Fire to Earth"], 275, L["Vendor"] )
	addTradeSkill( L["Transmute: Undeath to Water"], 275, L["UWD"] )
	addTradeSkill( L["Transmute: Water to Air"], 275, L["Vendor"] )
	addTradeSkill( L["Transmute: Water to Undeath"], 275, L["UWD"] )
	addTradeSkill( L["Transmute: Life to Earth"], 275, L["UWD"] )
	addTradeSkill( L["Mageblood Potion"], 275, ARL_AddReputation1( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Greater Dreamless Sleep Potion"], 275, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Greater Stoneshield Potion"], 280, L["UWD"] )
	addTradeSkill( L["Elixir of the Mongoose"], 280, L["Elixir of the Mongoose Obt"] )
	addTradeSkill( L["Purification Potion"], 285, L["UWD"] )
	addTradeSkill( L["Greater Arcane Elixir"], 285, L["UWD"] )
	addTradeSkill( L["Living Action Potion"], 285, ARL_AddReputation1( BFAC["Exalted"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Greater Fire Protection Potion"], 290, L["Greater Fire Protection Potion Obt"] )
	addTradeSkill( L["Greater Frost Protection Potion"], 290, L["Greater Frost Protection Potion Obt"] )
	addTradeSkill( L["Greater Nature Protection Potion"], 290, L["Greater Nature Protection Potion Obt"] )
	addTradeSkill( L["Greater Arcane Protection Potion"], 290, L["Greater Arcane Protection Potion Obt"] )
	addTradeSkill( L["Greater Shadow Protection Potion"], 290, L["Greater Shadow Protection Potion Obt"] )
	addTradeSkill( L["Major Troll's Blood Potion"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Major Mana Potion"], 295, L["Major Mana Potion Obt"] )
	addTradeSkill( L["Flask of Petrification"], 300, L["UWD"] )
	addTradeSkill( L["Flask of the Titans"], 300, L["Flask of the Titans Obt"] )
	addTradeSkill( L["Flask of Distilled Wisdom"], 300, L["Flask of Distilled Wisdom Obt"] )
	addTradeSkill( L["Flask of Supreme Power"], 300, L["Flask of Supreme Power Obt"] )
	addTradeSkill( L["Flask of Chromatic Resistance"], 300, L["Flask of Chromatic Resistance Obt"] )
	addTradeSkill( L["Major Rejuvenation Potion"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Transmute: Elemental Fire"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Gurubashi Mojo Madness"], 300, L["Gurubashi Mojo Madness Obt"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Adept's Elixir"], 300, L["Trainer"] )
	addTradeSkill( L["Onslaught Elixir"], 300, L["Trainer"] )
	addTradeSkill( L["Volatile Healing Potion"], 300, L["Trainer"] )
	addTradeSkill( L["Elixir of Camouflage"], 305, L["Vendor"] )
	addTradeSkill( L["Elixir of Major Strength"], 305, L["Trainer"] )
	addTradeSkill( L["Elixir of Healing Power"], 310, L["Trainer"] )
	addTradeSkill( L["Elixir of Major Fortitude"], 310, L["Trainer"] )
	addTradeSkill( L["Unstable Mana Potion"], 310, L["Trainer"] )
	addTradeSkill( L["Sneaking Potion"], 315, L["Vendor"] )
	addTradeSkill( L["Elixir of Mastery"], 315, L["Trainer"] )
	addTradeSkill( L["Elixir of Draenic Wisdom"], 320, L["Trainer"] )
	addTradeSkill( L["Elixir of Major Frost Power"], 320, L["Vendor"] )
	addTradeSkill( L["Insane Strength Potion"], 320, L["UWD"] )
	addTradeSkill( L["Earthen Elixir"], 320, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Elixir of the Searching Eye"], 325, L["UWD"] )
	addTradeSkill( L["Mercurial Stone"], 325, L["Trainer"] )
	addTradeSkill( L["Super Healing Potion"], 325, L["Trainer"] )
	addTradeSkill( L["Elixir of Major Agility"], 330, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Elixir of Ironskin"], 330, L["Vendor"], L["PVP"] )
	addTradeSkill( L["Shrouding Potion"], 335, ARL_AddReputation1( BFAC["Exalted"], BFAC["Sporeggar"] ), BFAC["Sporeggar"] )
	addTradeSkill( L["Fel Strength Elixir"], 335, L["Fel Strength Elixir Obt"] )
	addTradeSkill( L["Super Mana Potion"], 340, L["Vendor"] )
	addTradeSkill( L["Elixir of Major Firepower"], 345, ARL_AddReputation1(BFAC["Revered"], BFAC["The Scryers"]), BFAC["The Scryers"] )
	addTradeSkill( L["Elixir of Major Defense"], 345, L["Vendor"] )
	addTradeSkill( L["Fel Regeneration Potion"], 345, L["Fel Regeneration Potion Obt"] )
	addTradeSkill( L["Elixir of Major Shadow Power"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["Lower City"]), BFAC["Lower City"] )
	addTradeSkill( L["Major Dreamless Sleep Potion"], 350, L["Vendor"] )
	addTradeSkill( L["Heroic Potion"], 350, L["UWD"] )
	addTradeSkill( L["Haste Potion"], 350, L["UWD"] )
	addTradeSkill( L["Destruction Potion"], 350, L["UWD"] )
	addTradeSkill( L["Transmute: Primal Air to Fire"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Transmute: Primal Earth to Water"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["Sporeggar"] ), BFAC["Sporeggar"] )
	addTradeSkill( L["Transmute: Primal Fire to Earth"], 350, ARL_AddReputation2( BFAC["Revered"], BFAC["Kurenai"], BFAC["The Mag'har"] ), BFAC["The Mag'har"] )
	addTradeSkill( L["Transmute: Primal Water to Air"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Transmute: Primal Might"], 350, L["Vendor"] )
	addTradeSkill( L["Transmute: Earthstorm Diamond"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Transmute: Skyfire Diamond"], 350, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Alchemist's Stone"], 350, L["Trainer"] )
	addTradeSkill( L["Elixir of Major Mageblood"], 355, L["UWD"] )
	addTradeSkill( L["Major Arcane Protection Potion"], 360, L["Major Arcane Protection Potion Obt"] )
	addTradeSkill( L["Major Fire Protection Potion"], 360, L["Major Fire Protection Potion Obt"] )
	addTradeSkill( L["Major Frost Protection Potion"], 360, L["Major Frost Protection Potion Obt"] )
	addTradeSkill( L["Major Holy Protection Potion"], 360, L["Major Holy Protection Potion Obt"] )
	addTradeSkill( L["Major Nature Protection Potion"], 360, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Major Shadow Protection Potion"], 360, L["Major Shadow Protection Potion Obt"] )
	addTradeSkill( L["Fel Mana Potion"], 360, L["Fel Mana Potion Obt"] )
	addTradeSkill( L["Elixir of Empowerment"], 365, L["UWD"] )
	addTradeSkill( L["Ironshield Potion"], 365, L["Ironshield Potion Obt"] )
	addTradeSkill( L["Flask of Chromatic Wonder"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Violet Eye"] ), BFAC["The Violet Eye"] )

	-- Burning Crusade Discovery Recipes
	addTradeSkill( L["Transmute: Primal Fire to Mana"], 350, L["Discovery - Transmutes"], L["Discovery"] )
	addTradeSkill( L["Transmute: Primal Shadow to Water"], 350, L["Discovery - Transmutes"], L["Discovery"] )
	addTradeSkill( L["Transmute: Primal Life to Earth"], 350, L["Discovery - Transmutes"], L["Discovery"] )
	addTradeSkill( L["Transmute: Primal Earth to Life"], 350, L["Discovery - Transmutes"], L["Discovery"] )
	addTradeSkill( L["Transmute: Primal Mana to Fire"], 350, L["Discovery - Transmutes"], L["Discovery"] )
	addTradeSkill( L["Transmute: Primal Water to Shadow"], 350, L["Discovery - Transmutes"], L["Discovery"] )
	addTradeSkill( L["Flask of Fortification"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] )
	addTradeSkill( L["Flask of Mighty Restoration"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] )
	addTradeSkill( L["Flask of Relentless Assault"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] )
	addTradeSkill( L["Flask of Blinding Light"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] )
	addTradeSkill( L["Flask of Pure Death"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] )	
	addTradeSkill( L["Super Rejuvenation Potion"], 375, L["Discovery - Flasks/Potions"], L["Discovery"] )
	addTradeSkill( L["Cauldron of Major Arcane Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] )
	addTradeSkill( L["Cauldron of Major Fire Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] )
	addTradeSkill( L["Cauldron of Major Frost Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] )
	addTradeSkill( L["Cauldron of Major Nature Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] )
	addTradeSkill( L["Cauldron of Major Shadow Protection"], 375, L["Discovery - Protection Potions"], L["Discovery"] )

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Beast Training Abilities.  As of 2.2 there are 134 abilities.

local function ARL_InitBeastTraining()

	ARL_InitializeRecipeArray()

	addTradeSkill( L["Arcane Resistance (Rank 1)"], 20, L["Trainer"] )
	addTradeSkill( L["Arcane Resistance (Rank 2)"], 30, L["Trainer"] )
	addTradeSkill( L["Arcane Resistance (Rank 3)"], 40, L["Trainer"] )
	addTradeSkill( L["Arcane Resistance (Rank 4)"], 50, L["Trainer"] )
	addTradeSkill( L["Arcane Resistance (Rank 5)"], 60, L["Trainer"] )
	addTradeSkill( L["Avoidance (Rank 1)"], 30, L["Trainer"] )
	addTradeSkill( L["Avoidance (Rank 2)"], 60, L["Trainer"] )
	addTradeSkill( L["Cobra Reflexes ()"], 30, L["Trainer"] )
	addTradeSkill( L["Fire Resistance (Rank 1)"], 20, L["Trainer"] )
	addTradeSkill( L["Fire Resistance (Rank 2)"], 30, L["Trainer"] )
	addTradeSkill( L["Fire Resistance (Rank 3)"], 40, L["Trainer"] )
	addTradeSkill( L["Fire Resistance (Rank 4)"], 50, L["Trainer"] )
	addTradeSkill( L["Fire Resistance (Rank 5)"], 60, L["Trainer"] )
	addTradeSkill( L["Frost Resistance (Rank 1)"], 20, L["Trainer"] )
	addTradeSkill( L["Frost Resistance (Rank 2)"], 30, L["Trainer"] )
	addTradeSkill( L["Frost Resistance (Rank 3)"], 40, L["Trainer"] )
	addTradeSkill( L["Frost Resistance (Rank 4)"], 50, L["Trainer"] )
	addTradeSkill( L["Frost Resistance (Rank 5)"], 60, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 1)"], 10, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 2)"], 12, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 3)"], 18, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 4)"], 24, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 5)"], 30, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 6)"], 36, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 7)"], 42, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 8)"], 48, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 9)"], 54, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 10)"], 60, L["Trainer"] )
	addTradeSkill( L["Great Stamina (Rank 11)"], 70, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 1)"], 10, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 2)"], 12, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 3)"], 18, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 4)"], 24, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 5)"], 30, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 6)"], 36, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 7)"], 42, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 8)"], 48, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 9)"], 54, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 10)"], 60, L["Trainer"] )
	addTradeSkill( L["Natural Armor (Rank 11)"], 70, L["Trainer"] )
	addTradeSkill( L["Nature Resistance (Rank 1)"], 20, L["Trainer"] )
	addTradeSkill( L["Nature Resistance (Rank 2)"], 30, L["Trainer"] )
	addTradeSkill( L["Nature Resistance (Rank 3)"], 40, L["Trainer"] )
	addTradeSkill( L["Nature Resistance (Rank 4)"], 50, L["Trainer"] )
	addTradeSkill( L["Nature Resistance (Rank 5)"], 60, L["Trainer"] )
	addTradeSkill( L["Shadow Resistance (Rank 1)"], 20, L["Trainer"] )
	addTradeSkill( L["Shadow Resistance (Rank 2)"], 30, L["Trainer"] )
	addTradeSkill( L["Shadow Resistance (Rank 3)"], 40, L["Trainer"] )
	addTradeSkill( L["Shadow Resistance (Rank 4)"], 50, L["Trainer"] )
	addTradeSkill( L["Shadow Resistance (Rank 5)"], 60, L["Trainer"] )
	addTradeSkill( L["Bite (Rank 1)"], 10, L["Bite (Rank 1) Obt"] )
	addTradeSkill( L["Bite (Rank 2)"], 10, L["Bite (Rank 2) Obt"] )
	addTradeSkill( L["Bite (Rank 3)"], 16, L["Bite (Rank 3) Obt"] )
	addTradeSkill( L["Bite (Rank 4)"], 24, L["Bite (Rank 4) Obt"] )
	addTradeSkill( L["Bite (Rank 5)"], 32, L["Bite (Rank 5) Obt"] )
	addTradeSkill( L["Bite (Rank 6)"], 40, L["Bite (Rank 6) Obt"] )
	addTradeSkill( L["Bite (Rank 7)"], 48, L["Bite (Rank 7) Obt"] )
	addTradeSkill( L["Bite (Rank 8)"], 56, L["Bite (Rank 8) Obt"] )
	addTradeSkill( L["Bite (Rank 9)"], 64, L["Bite (Rank 9) Obt"] )
	addTradeSkill( L["Claw (Rank 1)"], 10, L["Claw (Rank 1) Obt"] )
	addTradeSkill( L["Claw (Rank 2)"], 10, L["Claw (Rank 2) Obt"] )
	addTradeSkill( L["Claw (Rank 3)"], 16, L["Claw (Rank 3) Obt"] )
	addTradeSkill( L["Claw (Rank 4)"], 24, L["Claw (Rank 4) Obt"] )
	addTradeSkill( L["Claw (Rank 5)"], 32, L["Claw (Rank 5) Obt"] )
	addTradeSkill( L["Claw (Rank 6)"], 40, L["Claw (Rank 6) Obt"] )
	addTradeSkill( L["Claw (Rank 7)"], 48, L["Claw (Rank 7) Obt"] )
	addTradeSkill( L["Claw (Rank 8)"], 56, L["Claw (Rank 8) Obt"] )
	addTradeSkill( L["Claw (Rank 9)"], 64, L["Claw (Rank 9) Obt"] )
	addTradeSkill( L["Charge (Rank 1)"], 10, L["Charge (Rank 1) Obt"] )
	addTradeSkill( L["Charge (Rank 2)"], 12, L["Charge (Rank 2) Obt"] )
	addTradeSkill( L["Charge (Rank 3)"], 24, L["Charge (Rank 3) Obt"] )
	--addTradeSkill( L["Charge (Rank 4)"], 36, L["Charge (Rank 4) Obt"] ) -- No charge rank 4 in the game
	addTradeSkill( L["Charge (Rank 5)"], 42, L["Charge (Rank 5) Obt"] )
	addTradeSkill( L["Charge (Rank 6)"], 60, L["Charge (Rank 6) Obt"] )
	addTradeSkill( L["Cower (Rank 1)"], 10, L["Cower (Rank 1) Obt"] )
	addTradeSkill( L["Cower (Rank 2)"], 15, L["Cower (Rank 2) Obt"] )
	addTradeSkill( L["Cower (Rank 3)"], 25, L["Cower (Rank 3) Obt"] )
	addTradeSkill( L["Cower (Rank 4)"], 35, L["Cower (Rank 4) Obt"] )
	addTradeSkill( L["Cower (Rank 5)"], 45, L["Cower (Rank 5) Obt"] )
	addTradeSkill( L["Cower (Rank 6)"], 55, L["Cower (Rank 6) Obt"] )
	addTradeSkill( L["Cower (Rank 7)"], 65, L["Cower (Rank 7) Obt"] )
	addTradeSkill( L["Dash (Rank 1)"], 30, L["Dash (Rank 1) Obt"] )
	addTradeSkill( L["Dash (Rank 2)"], 40, L["Dash (Rank 2) Obt"] )
	addTradeSkill( L["Dash (Rank 3)"], 50, L["Dash (Rank 3) Obt"] )
	addTradeSkill( L["Dive (Rank 1)"], 30, L["Dive (Rank 1) Obt"] )
	addTradeSkill( L["Dive (Rank 2)"], 40, L["Dive (Rank 2) Obt"] )
	addTradeSkill( L["Dive (Rank 3)"], 50, L["Dive (Rank 3) Obt"] )
	addTradeSkill( L["Fire Breath (Rank 1)"], 1, L["Fire Breath (Rank 1) Obt"] )
	addTradeSkill( L["Fire Breath (Rank 2)"], 60, L["Fire Breath (Rank 2) Obt"] )
	addTradeSkill( L["Furious Howl (Rank 1)"], 10, L["Furious Howl (Rank 1) Obt"] )
	addTradeSkill( L["Furious Howl (Rank 2)"], 24, L["Furious Howl (Rank 2) Obt"] )
	addTradeSkill( L["Furious Howl (Rank 3)"], 40, L["Furious Howl (Rank 3) Obt"] )
	addTradeSkill( L["Furious Howl (Rank 4)"], 56, L["Furious Howl (Rank 4) Obt"] )
	addTradeSkill( L["Gore (Rank 1)"], 1, L["Gore (Rank 1) Obt"] )
	addTradeSkill( L["Gore (Rank 2)"], 8, L["Gore (Rank 2) Obt"] )
	addTradeSkill( L["Gore (Rank 3)"], 16, L["Gore (Rank 3) Obt"] )
	addTradeSkill( L["Gore (Rank 4)"], 24, L["Gore (Rank 4) Obt"] )
	--addTradeSkill( L["Gore (Rank 5)"], 32, L["Gore (Rank 5) Obt"] ) -- Not in game
	--addTradeSkill( L["Gore (Rank 6)"], 40, L["Gore (Rank 6) Obt"] ) -- Not in game
	addTradeSkill( L["Gore (Rank 7)"], 48, L["Gore (Rank 7) Obt"] )
	addTradeSkill( L["Gore (Rank 8)"], 56, L["Gore (Rank 8) Obt"] )
	addTradeSkill( L["Gore (Rank 9)"], 63, L["Gore (Rank 9) Obt"] )
	addTradeSkill( L["Growl (Rank 1)"], 10, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 2)"], 10, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 3)"], 20, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 4)"], 30, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 5)"], 40, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 6)"], 50, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 7)"], 60, L["Trainer"] )
	addTradeSkill( L["Growl (Rank 8)"], 70, L["Trainer"] )
	addTradeSkill( L["Lightning Breath (Rank 1)"], 1, L["Lightning Breath (Rank 1) Obt"] )
	addTradeSkill( L["Lightning Breath (Rank 2)"], 12, L["Lightning Breath (Rank 2) Obt"] )
	addTradeSkill( L["Lightning Breath (Rank 3)"], 24, L["Lightning Breath (Rank 3) Obt"])
	addTradeSkill( L["Lightning Breath (Rank 4)"], 36, L["Lightning Breath (Rank 4) Obt"] )
	addTradeSkill( L["Lightning Breath (Rank 5)"], 48, L["Lightning Breath (Rank 5) Obt"] )
	addTradeSkill( L["Lightning Breath (Rank 6)"], 60, L["Lightning Breath (Rank 6) Obt"] )
	addTradeSkill( L["Poison Spit (Rank 1)"], 15, L["Poison Spit (Rank 1) Obt"] )
	addTradeSkill( L["Poison Spit (Rank 2)"], 45, L["Poison Spit (Rank 2) Obt"])
	addTradeSkill( L["Poison Spit (Rank 3)"], 60, L["Poison Spit (Rank 3) Obt"])	
	addTradeSkill( L["Prowl (Rank 1)"], 30, L["Prowl (Rank 1) Obt"] )
	addTradeSkill( L["Prowl (Rank 2)"], 40, L["Prowl (Rank 2) Obt"] )
	addTradeSkill( L["Prowl (Rank 3)"], 50, L["Prowl (Rank 3) Obt"] )
	addTradeSkill( L["Scorpid Poison (Rank 1)"], 10, L["Scorpid Poison (Rank 1) Obt"] )
	addTradeSkill( L["Scorpid Poison (Rank 2)"], 24, L["Scorpid Poison (Rank 2) Obt"] )
	addTradeSkill( L["Scorpid Poison (Rank 3)"], 40, L["Scorpid Poison (Rank 3) Obt"] )
	addTradeSkill( L["Scorpid Poison (Rank 4)"], 56, L["Scorpid Poison (Rank 4) Obt"] )
	addTradeSkill( L["Scorpid Poison (Rank 5)"], 64, L["Scorpid Poison (Rank 5) Obt"] )
	addTradeSkill( L["Screech (Rank 1)"], 10, L["Screech (Rank 1) Obt"] )
	addTradeSkill( L["Screech (Rank 2)"], 24, L["Screech (Rank 2) Obt"] )
	addTradeSkill( L["Screech (Rank 3)"], 40, L["Screech (Rank 3) Obt"] )
	addTradeSkill( L["Screech (Rank 4)"], 56, L["Screech (Rank 4) Obt"] )
	addTradeSkill( L["Screech (Rank 5)"], 64, L["Screech (Rank 5) Obt"] )
	addTradeSkill( L["Shell Shield (Rank 1)"], 20, L["Shell Shield (Rank 1) Obt"] )
	addTradeSkill( L["Thunderstomp (Rank 1)"], 30, L["Thunderstomp (Rank 1) Obt"] )
	addTradeSkill( L["Thunderstomp (Rank 2)"], 40, L["Thunderstomp (Rank 2) Obt"] )
	addTradeSkill( L["Thunderstomp (Rank 3)"], 50, L["Thunderstomp (Rank 3) Obt"] )
	addTradeSkill( L["Warp (Rank 1)"], 60, L["Warp (Rank 1) Obt"] )

end

-- Initializes the array adding all Blacksmithing recipes.  As of 2.2 there are 355 recipes.

local function ARL_InitBlackSmith()

	ARL_InitializeRecipeArray()

	-- Original Game Recipes
	addTradeSkill( L["Rough Sharpening Stone"], 1, L["Trainer"] )
	addTradeSkill( L["Copper Bracers"], 1, L["Trainer"] )
	addTradeSkill( L["Rough Copper Vest"], 1, L["Trainer"] )
	addTradeSkill( L["Copper Chain Pants"], 1, L["Trainer"] )
	addTradeSkill( L["Copper Mace"], 15, L["Trainer"] )
	addTradeSkill( L["Copper Chain Boots"], 20, L["Trainer"] )
	addTradeSkill( L["Copper Axe"], 20, L["Trainer"] )
	addTradeSkill( L["Rough Weightstone"], 25, L["Trainer"] )
	addTradeSkill( L["Rough Grinding Stone"], 25, L["Trainer"] )
	addTradeSkill( L["Copper Shortsword"], 25, L["Trainer"] )
	addTradeSkill( L["Copper Dagger"], 30, L["Trainer"] )
	addTradeSkill( L["Copper Claymore"], 30, L["Trainer"] )
	addTradeSkill( L["Copper Battle Axe"], 35, L["Trainer"] )
	addTradeSkill( L["Copper Chain Vest"], 35, L["Copper Chain Vest Obt"] )
	addTradeSkill( L["Copper Chain Belt"], 35, L["Trainer"] )
	--addTradeSkill( L["Heavy Copper Longsword"], 35, L["Unknown"] )
	addTradeSkill( L["Runed Copper Gauntlets"], 40, L["Trainer"] )
	addTradeSkill( L["Runed Copper Pants"], 45, L["Trainer"] )
	addTradeSkill( L["Gemmed Copper Gauntlets"], 60, L["UWD"] )
	addTradeSkill( L["Coarse Weightstone"], 65, L["Trainer"] )
	addTradeSkill( L["Heavy Copper Maul"], 65, L["Trainer"] )
	addTradeSkill( L["Coarse Sharpening Stone"], 65, L["Trainer"] )
	addTradeSkill( L["Coarse Grinding Stone"], 75, L["Trainer"] )
	addTradeSkill( L["Runed Copper Breastplate"], 80, L["UWD"] )
	addTradeSkill( L["Runed Copper Bracers"], 90, L["Trainer"] )
	addTradeSkill( L["Thick War Axe"], 90, L["Trainer"] )
	addTradeSkill( L["Runed Copper Belt"], 90, L["Trainer"] )
	addTradeSkill( L["Heavy Copper Broadsword"], 95, L["Trainer"] )
	addTradeSkill( L["Rough Bronze Boots"], 95, L["Trainer"] )
	addTradeSkill( L["Big Bronze Knife"], 100, L["Trainer"] )
	addTradeSkill( L["Silver Rod"], 100, L["Trainer"] )
	addTradeSkill( L["Ironforge Breastplate"], 100, L["Ironforge Breastplate Obt"], BFAC["Alliance"])
	addTradeSkill( L["Silver Skeleton Key"], 100, L["Trainer"] )
	addTradeSkill( L["Thick Bronze Darts"], 100, L["Trainer"] )
	addTradeSkill( L["Rough Bronze Leggings"], 105, L["Trainer"] )
	addTradeSkill( L["Rough Bronze Cuirass"], 105, L["Trainer"] )
	addTradeSkill( L["Rough Bronze Shoulders"], 110, L["Trainer"] )
	addTradeSkill( L["Bronze Mace"], 110, L["Trainer"] )
	addTradeSkill( L["Pearl-handled Dagger"], 115, L["Trainer"] )
	addTradeSkill( L["Bronze Axe"], 115, L["Trainer"] )
	addTradeSkill( L["Bronze Shortsword"], 120, L["Trainer"] )
	addTradeSkill( L["Patterned Bronze Bracers"], 120, L["Trainer"] )
	addTradeSkill( L["Heavy Weightstone"], 125, L["Trainer"] )
	addTradeSkill( L["Deadly Bronze Poniard"], 125, L["UWD"] )
	addTradeSkill( L["Silvered Bronze Shoulders"], 125, L["UWD"] )
	addTradeSkill( L["Heavy Grinding Stone"], 125, L["Trainer"] )
	addTradeSkill( L["Bronze Warhammer"], 125, L["Trainer"] )
	addTradeSkill( L["Heavy Sharpening Stone"], 125, L["Trainer"] )
	addTradeSkill( L["Heavy Bronze Mace"], 130, L["Trainer"] )
	addTradeSkill( L["Silvered Bronze Boots"], 130, L["Trainer"] )
	addTradeSkill( L["Silvered Bronze Breastplate"], 130, L["UWD"] )
	addTradeSkill( L["Bronze Greatsword"], 130, L["Trainer"] )
	addTradeSkill( L["Silvered Bronze Gauntlets"], 135, L["Trainer"] )
	addTradeSkill( L["Bronze Battle Axe"], 135, L["Trainer"] )
	addTradeSkill( L["Iridescent Hammer"], 140, L["UWD"] )
	addTradeSkill( L["Mighty Iron Hammer"], 145, L["UWD"] )
	addTradeSkill( L["Green Iron Boots"], 145, L["UWD"] )
	addTradeSkill( L["Shining Silver Breastplate"], 145, L["Trainer"] )
	addTradeSkill( L["Green Iron Gauntlets"], 150, L["UWD"] )
	addTradeSkill( L["Iron Shield Spike"], 150, L["UWD"] )
	addTradeSkill( L["Iron Buckle"], 150, L["Trainer"] )
	addTradeSkill( L["Golden Rod"], 150, L["Trainer"] )
	addTradeSkill( L["Golden Skeleton Key"], 150, L["Trainer"] )
	addTradeSkill( L["Solid Iron Maul"], 155, L["Vendor"] )
	addTradeSkill( L["Green Iron Leggings"], 155, L["Trainer"] )
	addTradeSkill( L["Silvered Bronze Leggings"], 155, L["UWD"] )
	addTradeSkill( L["Hardened Iron Shortsword"], 160, L["Vendor"] )
	addTradeSkill( L["Green Iron Shoulders"], 160, L["UWD"] )
	addTradeSkill( L["Barbaric Iron Shoulders"], 160, L["Barbaric Iron Shoulders Obt"], BFAC["Horde"] )
	addTradeSkill( L["Barbaric Iron Breastplate"], 160, L["Barbaric Iron Breastplate Obt"], BFAC["Horde"] )
	addTradeSkill( L["Green Iron Bracers"], 165, L["Trainer"] )
	addTradeSkill( L["Iron Counterweight"], 165, L["UWD"] )
	addTradeSkill( L["Golden Iron Destroyer"], 170, L["UWD"] )
	addTradeSkill( L["Green Iron Helm"], 170, L["Trainer"] )
	addTradeSkill( L["Golden Scale Leggings"], 170, L["UWD"] )
	addTradeSkill( L["Jade Serpentblade"], 175, L["UWD"] )
	addTradeSkill( L["Golden Scale Shoulders"], 175, L["UWD"] )
	addTradeSkill( L["Barbaric Iron Helm"], 175, L["Barbaric Iron Helm Obt"], BFAC["Horde"] )
	addTradeSkill( L["Moonsteel Broadsword"], 180, L["Vendor"] )
	addTradeSkill( L["Green Iron Hauberk"], 180, L["Trainer"] )
	addTradeSkill( L["Barbaric Iron Boots"], 180, L["Barbaric Iron Boots Obt"], BFAC["Horde"] )
	addTradeSkill( L["Glinting Steel Dagger"], 180, L["Trainer"] )
	addTradeSkill( L["Massive Iron Axe"], 185, L["Vendor"] )
	addTradeSkill( L["Polished Steel Boots"], 185, L["UWD"] )
	addTradeSkill( L["Golden Scale Bracers"], 185, L["Trainer"] )
	addTradeSkill( L["Barbaric Iron Gloves"], 185, L["Barbaric Iron Gloves Obt"], BFAC["Horde"] )
	addTradeSkill( L["Golden Scale Coif"], 190, L["Vendor"] )
	addTradeSkill( L["Steel Weapon Chain"], 190, L["UWD"] )
	addTradeSkill( L["Searing Golden Blade"], 190, L["UWD"] )
	addTradeSkill( L["Edge of Winter"], 190, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Golden Scale Cuirass"], 195, L["UWD"] )
	addTradeSkill( L["Frost Tiger Blade"], 200, L["UWD"] )
	addTradeSkill( L["Shadow Crescent Axe"], 200, L["UWD"] )
	addTradeSkill( L["Golden Scale Boots"], 200, L["UWD"] )
	addTradeSkill( L["Steel Breastplate"], 200, L["Trainer"] )
	addTradeSkill( L["Solid Sharpening Stone"], 200, L["Trainer"] )
	addTradeSkill( L["Solid Weightstone"], 200, L["Trainer"] )
	addTradeSkill( L["Solid Grinding Stone"], 200, L["Trainer"] )
	addTradeSkill( L["Inlaid Mithril Cylinder"], 200, L["Inlaid Mithril Cylinder Obt"] )
	addTradeSkill( L["Truesilver Rod"], 200, L["Trainer"] )
	addTradeSkill( L["Truesilver Skeleton Key"], 200, L["Trainer"] )
	addTradeSkill( L["Whirling Steel Axes"], 200, L["Trainer"] )
	addTradeSkill( L["Heavy Mithril Shoulder"], 205, L["Trainer"] )
	addTradeSkill( L["Heavy Mithril Gauntlet"], 205, L["Trainer"] )
	addTradeSkill( L["Golden Scale Gauntlets"], 205, L["Golden Scale Gauntlets Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Mithril Scale Pants"], 210, L["Trainer"] )
	addTradeSkill( L["Heavy Mithril Pants"], 210, L["UWD"] )
	addTradeSkill( L["Heavy Mithril Axe"], 210, L["Trainer"] )
	addTradeSkill( L["Steel Plate Helm"], 215, L["Trainer"] )
	addTradeSkill( L["Mithril Scale Bracers"], 215, L["Vendor"] )
	addTradeSkill( L["Mithril Shield Spike"], 215, L["UWD"] )
	addTradeSkill( L["Ornate Mithril Pants"], 220, L["Ornate Mithril Pants Obt"] )
	addTradeSkill( L["Ornate Mithril Gloves"], 220, L["Ornate Mithril Gloves Obt"] )
	addTradeSkill( L["Blue Glittering Axe"], 220, L["UWD"] )
	addTradeSkill( L["Ornate Mithril Shoulder"], 225, L["Ornate Mithril Shoulder Obt"] )
	addTradeSkill( L["Wicked Mithril Blade"], 225, L["UWD"] )
	addTradeSkill( L["Heavy Mithril Breastplate"], 230, L["Trainer"] )
	addTradeSkill( L["Mithril Coif"], 230, L["Trainer"] )
	addTradeSkill( L["Big Black Mace"], 230, L["Trainer"] )
	addTradeSkill( L["Mithril Spurs"], 235, L["UWD"] )
	addTradeSkill( L["Mithril Scale Shoulders"], 235, L["UWD"] )
	addTradeSkill( L["Heavy Mithril Boots"], 235, L["Trainer"] )
	addTradeSkill( L["Ornate Mithril Breastplate"], 235, L["Trainer"] )
	addTradeSkill( L["Ornate Mithril Boots"], 240, L["Trainer"] )
	addTradeSkill( L["Dazzling Mithril Rapier"], 240, L["UWD"] )
	addTradeSkill( L["Heavy Mithril Helm"], 245, L["UWD"] )
	addTradeSkill( L["Ornate Mithril Helm"], 245, L["Ornate Mithril Helm Obt"] )
	addTradeSkill( L["Runed Mithril Hammer"], 245, L["UWD"] )
	addTradeSkill( L["Dense Sharpening Stone"], 250, L["Trainer"] )
	addTradeSkill( L["Dense Weightstone"], 250, L["Trainer"] )
	addTradeSkill( L["Dense Grinding Stone"], 250, L["Trainer"] )
	addTradeSkill( L["Thorium Armor"], 250, L["UWD"] )
	addTradeSkill( L["Thorium Belt"], 250, L["UWD"] )
	addTradeSkill( L["Orcish War Leggings"], 210, L["Orcish War Leggings Obt"], BFAC["Horde"] )
	addTradeSkill( L["Ebon Shiv"], 255, L["Vendor"] )
	addTradeSkill( L["Thorium Bracers"], 255, L["UWD"] )
	addTradeSkill( L["Radiant Belt"], 260, L["UWD"] )
	addTradeSkill( L["Imperial Plate Shoulders"], 265, L["Imperial Plate Shoulders Obt"] )
	addTradeSkill( L["Imperial Plate Belt"], 265, L["Imperial Plate Belt Obt"] )
	addTradeSkill( L["Dark Iron Mail"], 270, L["Blacksmithing Plans"] )
	addTradeSkill( L["Radiant Breastplate"], 270, L["UWD"] )
	addTradeSkill( L["Imperial Plate Bracers"], 270, L["Imperial Plate Bracers Obt"] )
	addTradeSkill( L["Thorium Shield Spike"], 275, L["UWD"] )
	addTradeSkill( L["Ornate Thorium Handaxe"], 275, L["Vendor"] )
	addTradeSkill( L["Arcanite Skeleton Key"], 275, L["Trainer"] )
	addTradeSkill( L["Arcanite Rod"], 275, L["Trainer"] )
	addTradeSkill( L["Dark Iron Shoulders"], 280, L["Blacksmithing Plans"] )
	addTradeSkill( L["Thorium Boots"], 280, L["UWD"] )
	addTradeSkill( L["Thorium Helm"], 280, L["UWD"] )
	addTradeSkill( L["Huge Thorium Battleaxe"], 280, L["Vendor"] )
	addTradeSkill( L["Radiant Gloves"], 285, L["UWD"] )
	addTradeSkill( L["Radiant Boots"], 290, L["UWD"] )
	addTradeSkill( L["Volcanic Hammer"], 290, L["Volcanic Hammer Obt"] )
	addTradeSkill( L["Heavy Timbermaw Belt"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Girdle of the Dawn"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Imperial Plate Boots"], 295, L["Imperial Plate Boots Obt"] )
	addTradeSkill( L["Imperial Plate Helm"], 295, L["Imperial Plate Helm Obt"] )
	addTradeSkill( L["Radiant Circlet"], 295, L["UWD"] )
	addTradeSkill( L["Thorium Leggings"], 300, L["UWD"] )
	addTradeSkill( L["Imperial Plate Chest"], 300, L["Imperial Plate Chest Obt"] )
	addTradeSkill( L["Runic Plate Shoulders"], 300, L["Runic Plate Shoulders Obt"] )
	addTradeSkill( L["Runic Plate Boots"], 300, L["Runic Plate Boots Obt"] )
	addTradeSkill( L["Radiant Leggings"], 300, L["UWD"] )
	addTradeSkill( L["Runic Plate Helm"], 300, L["Runic Plate Helm Obt"] )
	addTradeSkill( L["Imperial Plate Leggings"], 300, L["Imperial Plate Leggings Obt"] )
	addTradeSkill( L["Runic Breastplate"], 300, L["Runic Breastplate Obt"] )
	addTradeSkill( L["Runic Plate Leggings"], 300, L["Runic Plate Leggings"] )
	addTradeSkill( L["Sulfuron Hammer"], 300, L["Sulfuron Hammer"], L["Raid"] )
	addTradeSkill( L["Elemental Sharpening Stone"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Heavy Timbermaw Boots"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Gloves of the Dawn"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Bloodsoul Breastplate"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Bloodsoul Gauntlets"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Bloodsoul Shoulders"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Darksoul Breastplate"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Darksoul Leggings"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Darksoul Shoulders"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Darkrune Breastplate"], 300, L["TrueBelieverQuest"] )
	addTradeSkill( L["Darkrune Gauntlets"], 300, L["TrueBelieverQuest"] )
	addTradeSkill( L["Darkrune Helm"], 300, L["TrueBelieverQuest"] )
	addTradeSkill( L["Heavy Obsidian Belt"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Light Obsidian Belt"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Jagged Obsidian Shield"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Black Grasp of the Destroyer"], 300, L["Black Grasp of the Destroyer Obt"], L["Raid"] )
	addTradeSkill( L["Obsidian Mail Tunic"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Thick Obsidian Breastplate"], 300, L["Thick Obsidian Breastplate Obt"], L["Raid"] )
	addTradeSkill( L["Ironvine Breastplate"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Ironvine Gloves"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Ironvine Belt"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Enchanted Thorium Blades"], 300, L["Trainer"] )
	addTradeSkill( L["The Shatterer"], 235 , L["Trainer"] )
	addTradeSkill( L["Phantom Blade"], 245, L["Trainer"] )
	addTradeSkill( L["Blight"], 250, L["Trainer"] )
	addTradeSkill( L["Truesilver Champion"], 260, L["Trainer"] )
	addTradeSkill( L["Dark Iron Sunderer"], 275, L["Dark Iron Sunderer Obt"] )
	addTradeSkill( L["Heartseeker"], 300, L["Heartseeker Obt"] )
	addTradeSkill( L["Black Amnesty"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Blackfury"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
  	addTradeSkill( L["Truesilver Gauntlets"], 225, L["Trainer"] )
	addTradeSkill( L["Truesilver Breastplate"], 245, L["Trainer"] )
	addTradeSkill( L["Wildthorn Mail"], 270, L["UWD"] )
	addTradeSkill( L["Dark Iron Plate"], 285, L["Dark Iron Plate Obt"] )
	addTradeSkill( L["Demon Forged Breastplate"], 285, L["Demon Forged Breastplate Obt"] )
	addTradeSkill( L["Fiery Plate Gauntlets"], 290, L["Fiery Plate Gauntlets Obt"] )
	addTradeSkill( L["Dawnbringer Shoulders"], 290, L["UWD"] )
	addTradeSkill( L["Storm Gauntlets"], 295, L["Vendor"] )
	addTradeSkill( L["Dark Iron Bracers"], 295, ARL_AddReputation1( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Fiery Chain Girdle"], 295, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Whitesoul Helm"], 300, L["UWD"] )
	addTradeSkill( L["Helm of the Great Chief"], 300, L["RWD"] )
	addTradeSkill( L["Lionheart Helm"], 300, L["EWD"] )
	addTradeSkill( L["Stronghold Gauntlets"], 300, L["EWD"] )
	addTradeSkill( L["Enchanted Thorium Helm"], 300, L["Enchanted Thorium Helm Obt"] )
	addTradeSkill( L["Enchanted Thorium Leggings"], 300, L["Enchanted Thorium Leggings Obt"] )
	addTradeSkill( L["Enchanted Thorium Breastplate"], 300, L["Enchanted Thorium Breastplate Obt"] )
	addTradeSkill( L["Invulnerable Mail"], 300, L["Invulnerable Mail Obt"] )
	addTradeSkill( L["Dark Iron Leggings"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Fiery Chain Shoulders"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Dark Iron Helm"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Dark Iron Gauntlets"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Dark Iron Boots"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Titanic Leggings"], 300, L["EWD"] )
	addTradeSkill( L["Arcanite Champion"], 300, L["Arcanite Champion Obt"] )
	addTradeSkill( L["Frostguard"], 300, L["Frostguard Obt"] )
	addTradeSkill( L["Dark Iron Reaver"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Blackguard"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Sageblade"], 300, L["EWD"] )
	addTradeSkill( L["Corruption"], 290, L["Blacksmithing Plans"] )
	addTradeSkill( L["Serenity"], 285, L["Blacksmithing Plans"] )
	addTradeSkill( L["Hammer of the Titans"], 300, L["Hammer of the Titans Obt"] )
	addTradeSkill( L["Masterwork Stormhammer"], 300, L["Masterwork Stormhammer Obt"] )
	addTradeSkill( L["Ebon Hand"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Persuader"], 300, L["EWD"] )
	addTradeSkill( L["Annihilator"], 300, L["Annihilator Obt"] )
	addTradeSkill( L["Arcanite Reaper"], 300, L["Arcanite Reaper Obt"] )
	addTradeSkill( L["Dark Iron Destroyer"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Nightfall"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Icebane Bracers"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icebane Gauntlets"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icebane Breastplate"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Argent Dawn"] ), L["Raid"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Fel Sharpening Stone"], 300, L["Trainer"] )
	addTradeSkill( L["Fel Weightstone"], 300, L["Trainer"] )
	addTradeSkill( L["Fel Iron Rod"], 300, L["Trainer"] )
	addTradeSkill( L["Fel Iron Chain Coif"], 300, L["Trainer"] )
	addTradeSkill( L["Fel Iron Plate Gloves"], 300, L["Trainer"] )
	addTradeSkill( L["Fel Iron Plate Belt"], 305, L["Trainer"] )
	addTradeSkill( L["Fel Iron Hatchet"], 310, L["Trainer"] )
	addTradeSkill( L["Fel Iron Chain Gloves"], 310, L["Trainer"] )
	addTradeSkill( L["Fel Iron Plate Boots"], 315, L["Trainer"] )
	addTradeSkill( L["Fel Iron Plate Pants"], 315, L["Trainer"] )
	addTradeSkill( L["Fel Iron Chain Bracers"], 315, L["Trainer"] )
	addTradeSkill( L["Fel Iron Hammer"], 315, L["Trainer"] )
	addTradeSkill( L["Fel Iron Greatsword"], 320, L["Trainer"] )
	addTradeSkill( L["Fel Iron Chain Tunic"], 320, L["Trainer"] )
	addTradeSkill( L["Adamantite Maul"], 325, L["Vendor"] )
	addTradeSkill( L["Fel Iron Breastplate"], 325, L["Trainer"] )
	addTradeSkill( L["Lesser Rune of Warding"], 325, L["Trainer"] )
	addTradeSkill( L["Adamantite Cleaver"], 330, L["Vendor"] )
	addTradeSkill( L["Adamantite Dagger"], 330, L["Vendor"] )
	addTradeSkill( L["Adamantite Rapier"], 335, L["Vendor"] )
	addTradeSkill( L["Adamantite Plate Bracers"], 335, L["Vendor"] )
	addTradeSkill( L["Adamantite Plate Gloves"], 335, L["Vendor"] )
	addTradeSkill( L["Lesser Ward of Shielding"], 340, L["Vendor"] )
	addTradeSkill( L["Adamantite Breastplate"], 340, L["Vendor"] )
	addTradeSkill( L["Felsteel Whisper Knives"], 350, L["Trainer"] )
	addTradeSkill( L["Adamantite Sharpening Stone"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Greater Rune of Warding"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Adamantite Rod"], 350, L["Vendor"] )
	addTradeSkill( L["Adamantite Weightstone"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Flamebane Bracers"], 350, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Enchanted Adamantite Belt"], 355, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Enchanted Adamantite Boots"], 355, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Flamebane Helm"], 355, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Enchanted Adamantite Breastplate"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Flamebane Gloves"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Felsteel Gloves"], 360, L["Felsteel Gloves Obt"] )
	addTradeSkill( L["Felsteel Leggings"], 360, L["Felsteel Leggings Obt"] )
	addTradeSkill( L["Khorium Belt"], 360, L["Khorium Belt Obt"] )
	addTradeSkill( L["Khorium Pants"], 360, L["Khorium Pants Obt"] )
	addTradeSkill( L["Felsteel Shield Spike"], 360, ARL_AddReputation2( BFAC["Exalted"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Enchanted Adamantite Leggings"], 365, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Flamebane Breastplate"], 365, ARL_AddReputation1( BFAC["Revered"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Felsteel Helm"], 365, L["Felsteel Helm Obt"] )
	addTradeSkill( L["Gauntlets of the Iron Tower"], 365, L["EWD"] )
	addTradeSkill( L["Khorium Boots"], 365, L["Khorium Boots Obt"] )
	addTradeSkill( L["Ragesteel Gloves"], 365, L["Ragesteel Gloves Obt"] )
	addTradeSkill( L["Felfury Gauntlets"], 365, L["EWD"] )
	addTradeSkill( L["Steelgrip Gauntlets"], 365, L["EWD"] )
	addTradeSkill( L["Storm Helm"], 365, L["EWD"] )
	addTradeSkill( L["Helm of the Stalwart Defender"], 365, L["EWD"] )
	addTradeSkill( L["Oathkeeper's Helm"], 365, L["EWD"] )
	addTradeSkill( L["Black Felsteel Bracers"], 365, L["EWD"] )
	addTradeSkill( L["Bracers of the Green Fortress"], 365, L["EWD"] )
	addTradeSkill( L["Blessed Bracers"], 365, L["EWD"] )
	addTradeSkill( L["Felsteel Longblade"], 365, L["EWD"] )
	addTradeSkill( L["Khorium Champion"], 365, L["EWD"] )
	addTradeSkill( L["Fel Edged Battleaxe"], 365, L["EWD"] )
	addTradeSkill( L["Felsteel Reaper"], 365, L["EWD"] )
	addTradeSkill( L["Runic Hammer"], 365, L["EWD"] )
	addTradeSkill( L["Fel Hardened Maul"], 365, L["EWD"] )
	addTradeSkill( L["Eternium Runed Blade"], 365, L["EWD"] )
	addTradeSkill( L["Dirge"], 365, L["EWD"] )
	addTradeSkill( L["Hand of Eternity"], 365, L["EWD"] )
	addTradeSkill( L["Ragesteel Helm"], 365, L["Ragesteel Helm Obt"] )
	addTradeSkill( L["Ragesteel Breastplate"], 370, L["Ragesteel Breastplate Obt"] )
	addTradeSkill( L["Swiftsteel Gloves"], 370, L["Swiftsteel Gloves Obt"] )
 	addTradeSkill( L["Earthpeace Breastplate"], 370, L["Earthpeace Breastplate Obt"] )
	addTradeSkill( L["Greater Ward of Shielding"], 375, L["Greater Ward of Shielding Obt"] )
	addTradeSkill( L["Eternium Rod"], 375, L["Vendor"] )
	addTradeSkill( L["Wildguard Breastplate"], 375, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Wildguard Leggings"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Wildguard Helm"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Iceguard Breastplate"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Violet Eye"] ), L["Raid"] )
	addTradeSkill( L["Iceguard Leggings"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["The Violet Eye"] ), L["Raid"] )
	addTradeSkill( L["Iceguard Helm"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Violet Eye"] ), L["Raid"] )
	addTradeSkill( L["Ragesteel Shoulders"], 365, L["Ragesteel Shoulders Obt"])
	addTradeSkill( L["Red Havoc Boots"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Belt of the Guardian"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Red Belt of Battle"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Boots of the Protector"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Dawnsteel Bracers"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Dawnsteel Shoulders"], 375, L["BT/HYJALBoE"], L["Raid"] )
	addTradeSkill( L["Swiftsteel Bracers"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Swiftsteel Shoulders"], 375, L["BT/HYJALBoE"], L["Raid"] )
 	addTradeSkill( L["Shadesteel Bracers"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Shadesteel Girdle"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Shadesteel Greaves"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Shadesteel Sabots"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	--addTradeSkill( L["Hammer of Righteous Might"], 375, L["Unknown"] )  2.3 item
	--addTradeSkill( L["Adamantite Weapon Chain"], 375, L["Unknown"])  2.3 item

	-- Wrath of the Litch King Recipes

	-- Weaponsmith
	addTradeSkill( L["Light Earthforged Blade"], 260, L["Trainer"], BTS["Weaponsmith"] )
	addTradeSkill( L["Light Emberforged Hammer"], 260, L["Trainer"], BTS["Weaponsmith"] )
	addTradeSkill( L["Light Skyforged Axe"], 260, L["Trainer"], BTS["Weaponsmith"] )
	addTradeSkill( L["Dark Iron Pulverizer"], 265, L["Dark Iron Pulverizer Obt"], BTS["Weaponsmith"] )

	-- Armorsmith
	addTradeSkill( L["Earthforged Leggings"], 260, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Windforged Leggings"], 260, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Heavy Earthforged Breastplate"], 330, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Stormforged Hauberk"], 330, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Nether Chain Shirt"], 350, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Breastplate of Kings"], 350, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Twisting Nether Chain Shirt"], 375, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Embrace of the Twisting Nether"], 375, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Bulwark of Kings"], 375, L["Trainer"], BTS["Armorsmith"] )
	addTradeSkill( L["Bulwark of the Ancient Kings"], 375, L["Trainer"], BTS["Armorsmith"] )
	
	-- Master Swordsmith
	addTradeSkill( L["Blazing Rapier"], 280, L["Blazing Rapier Obt"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Windforged Rapier"], 330, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Stoneforged Claymore"], 330, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Fireguard"], 350, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Lionheart Blade"], 350, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Blazefury"], 375, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Blazeguard"], 375, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Lionheart Champion"], 375, L["Trainer"], BTS["Master Swordsmith"] )
	addTradeSkill( L["Lionheart Executioner"], 375, L["Trainer"], BTS["Master Swordsmith"] )

	-- Master Hammersmith
	addTradeSkill( L["Enchanted Battlehammer"], 280, L["Enchanted Battlehammer Obt"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Great Earthforged Hammer"], 330, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Lavaforged Hammer"], 330, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Drakefist Hammer"], 350, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Thunder"], 350, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Deep Thunder"], 375, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Dragonmaw"], 375, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Dragonstrike"], 375, L["Trainer"], BTS["Master Hammersmith"] )
	addTradeSkill( L["Stormherald"], 375, L["Trainer"], BTS["Master Hammersmith"] )

	-- Master Axesmith
	addTradeSkill( L["Dawn's Edge"], 275, L["Dawn's Edge Obt"], BTS["Master Axesmith"] )
	addTradeSkill( L["Skyforged Great Axe"], 330, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["Stormforged Axe"], 330, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["The Planar Edge"], 350, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["Lunar Crescent"], 350, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["Black Planar Edge"], 375, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["Bloodmoon"], 375, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["Mooncleaver"], 375, L["Trainer"], BTS["Master Axesmith"] )
	addTradeSkill( L["Wicked Edge of the Planes"], 375, L["Trainer"], BTS["Master Axesmith"] )
	
end

-- Initializes the array adding all Cooking recipes.  As of 2.2 there are 106 recipes.

local function ARL_InitCooking()

	ARL_InitializeRecipeArray()

	addTradeSkill( L["Brilliant Smallfish"], 1, L["Vendor"] )
	addTradeSkill( L["Crispy Bat Wing"], 1, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Charred Wolf Meat"], 1, L["Trainer"] )
	addTradeSkill( L["Gingerbread Cookie"], 1, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Herb Baked Egg"], 1, L["Trainer"] )
	addTradeSkill( L["Lynx Steak"], 1, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Roasted Boar Meat"], 1, L["Trainer"] )
	addTradeSkill( L["Slitherskin Mackerel"], 1, L["Vendor"] )
	addTradeSkill( L["Spice Bread"], 1, L["Trainer"] )
	addTradeSkill( L["Roasted Moongraze Tenderloin"], 1, L["Roasted Moongraze Tenderloin Obt"], BFAC["Alliance"])
	addTradeSkill( L["Kaldorei Spider Kabob"], 10, L["Kaldorei Spider Kabob Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Spiced Wolf Meat"], 10, L["Trainer"] )
	addTradeSkill( L["Scorpid Surprise"], 20, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Beer Basted Boar Ribs"], 25, L["Beer Basted Boar Ribs Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Roasted Kodo Meat"], 35, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Egg Nog"], 35, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Smoked Bear Meat"], 40, L["Vendor"], BFAC["Alliance"])
	addTradeSkill( L["Fillet of Frenzy"], 50, L["Vendor"], BFAC["Alliance"] )
	addTradeSkill( L["Strider Stew"], 50, L["Strider Stew Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Boiled Clams"], 50, L["Trainer"] )
	addTradeSkill( L["Longjaw Mud Snapper"], 50, L["Vendor"] )
	addTradeSkill( L["Loch Frenzy Delight"], 50, L["Vendor"], BFAC["Alliance"] )
	addTradeSkill( L["Rainbow Fin Albacore"], 50, L["Vendor"] )
	addTradeSkill( L["Coyote Steak"], 50, L["Trainer"] )
	addTradeSkill( L["Goretusk Liver Pie"], 50, L["Goretusk Liver Pie Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Bat Bites"], 50, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Blood Sausage"], 60, L["Blood Sausage Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Thistle Tea"], 60, L["Thistle Tea Obt"], BCLASS["Rogue"])
	addTradeSkill( L["Crunchy Spider Surprise"], 60, L["Crunchy Spider Surprise Obt"] )
	addTradeSkill( L["Westfall Stew"], 75, L["Westfall Stew Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Crab Cake"], 75, L["Trainer"] )
	addTradeSkill( L["Crocolisk Steak"], 80, L["Crocolisk Steak Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Smoked Sagefish"], 80, L["Vendor"] )
	addTradeSkill( L["Dry Pork Ribs"], 80, L["Trainer"] )
	addTradeSkill( L["Savory Deviate Delight"], 85, L["Savory Deviate Delight Obt"] )
	addTradeSkill( L["Cooked Crab Claw"], 85, L["Vendor"], BFAC["Alliance"] )
	addTradeSkill( L["Murloc Fin Soup"], 90, L["Murloc Fin Soup Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Dig Rat Stew"], 90, L["Dig Rat Stew Obt"], BFAC["Horde"] )
	addTradeSkill( L["Clam Chowder"], 90, L["Vendor"], BFAC["Alliance"] )
	addTradeSkill( L["Crispy Lizard Tail"], 100, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Bristle Whisker Catfish"], 100, L["Vendor"] )
	addTradeSkill( L["Redridge Goulash"], 100, L["Redridge Goulash Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Seasoned Wolf Kabob"], 100, L["Seasoned Wolf Kabob Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Gooey Spider Cake"], 110, L["Gooey Spider Cake Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Big Bear Steak"], 110, L["Big Bear Steak Obt"] )
	addTradeSkill( L["Lean Venison"], 110, L["Vendor"] )
	addTradeSkill( L["Succulent Pork Ribs"], 110, L["Vendor"], BFAC["Alliance"] )
	addTradeSkill( L["Crocolisk Gumbo"], 120, L["Crocolisk Gumbo Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Hot Lion Chops"], 125, L["Hot Lion Chops Obt"] )
	addTradeSkill( L["Goblin Deviled Clams"], 125, L["Trainer"] )
	addTradeSkill( L["Lean Wolf Steak"], 125, L["Vendor"] )
	addTradeSkill( L["Curiously Tasty Omelet"], 130, L["Curiously Tasty Omelet Obt"] )
	addTradeSkill( L["Tasty Lion Steak"], 150, L["Tasty Lion Steak Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Heavy Crocolisk Stew"], 150, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Soothing Turtle Bisque"], 175, L["Soothing Turtle Bisque Obt"] )
	addTradeSkill( L["Barbecued Buzzard Wing"], 175, L["Barbecued Buzzard Wing Obt"] )
	addTradeSkill( L["Giant Clam Scorcho"], 175, L["Vendor"] )
	addTradeSkill( L["Rockscale Cod"], 175, L["Vendor"] )
	addTradeSkill( L["Roast Raptor"], 175, L["Vendor"] )
	addTradeSkill( L["Hot Wolf Ribs"], 175, L["Vendor"] )
	addTradeSkill( L["Jungle Stew"], 175, L["Vendor"] )
	addTradeSkill( L["Carrion Surprise"], 175, L["Vendor"] )
	addTradeSkill( L["Mystery Stew"], 175, L["Vendor"] )
	addTradeSkill( L["Mithril Headed Trout"], 175, L["Vendor"] )
	addTradeSkill( L["Sagefish Delight"], 175, L["Vendor"] )
	addTradeSkill( L["Goldthorn Tea"], 175, L["Goldthorn Tea Obt"] )
	addTradeSkill( L["Dragonbreath Chili"], 200, L["Vendor"] )
	addTradeSkill( L["Heavy Kodo Stew"], 200, L["Vendor"] )
	addTradeSkill( L["Spider Sausage"], 200, L["Trainer"] )
	addTradeSkill( L["Spiced Chili Crab"], 225, L["Vendor"] )
	addTradeSkill( L["Monster Omelet"], 225, L["Vendor"] )
	addTradeSkill( L["Cooked Glossy Mightfish"], 225, L["Vendor"] )
	addTradeSkill( L["Spotted Yellowtail"], 225, L["Vendor"] )
	addTradeSkill( L["Filet of Redgill"], 225, L["Vendor"] )
	addTradeSkill( L["Undermine Clam Chowder"], 225, L["Vendor"] )
	addTradeSkill( L["Tender Wolf Steak"], 225, L["Vendor"] )
	addTradeSkill( L["Grilled Squid"], 240, L["Vendor"] )
	addTradeSkill( L["Hot Smoked Bass"], 240, L["Vendor"] )
	addTradeSkill( L["Nightfin Soup"], 250, L["Vendor"] )
	addTradeSkill( L["Poached Sunscale Salmon"], 250, L["Vendor"] )
	addTradeSkill( L["Lobster Stew"], 275, L["Vendor"] )
	addTradeSkill( L["Mightfish Steak"], 275, L["Vendor"] )
	addTradeSkill( L["Baked Salmon"], 275, L["Vendor"] )
	addTradeSkill( L["Runn Tum Tuber Surprise"], 275, L["Runn Tum Tuber Surprise Obt"] )
	addTradeSkill( L["Smoked Desert Dumplings"], 285, L["Smoked Desert Dumplings Obt"] )
	addTradeSkill( L["Dirge's Kickin' Chimaerok Chops"], 300, L["Dirge's Kickin' Chimaerok Chops Obt"], L["Raid"] )
	
	-- Burning Crusade Recipes
	--addTradeSkill( L["Delicious Chocolate Cake"], 325, L["Cooking Daily"] )
	addTradeSkill( L["Buzzard Bites"], 300, L["Buzzard Bites Obt"] )
	addTradeSkill( L["Ravager Dog"], 300, L["Vendor"] )
	addTradeSkill( L["Blackened Trout"], 300, L["Vendor"] )
	addTradeSkill( L["Feltail Delight"], 300, L["Vendor"] )
	--addTradeSkill( L["Kibler's Bits"], 300, L["Cooking Daily"] )
	--addTradeSkill( L["Broiled Bloodfin"], 300, L["Cooking Daily"] )
	--addTradeSkill( L["Stormchops"], 300, L["Cooking Daily"] )
	addTradeSkill( L["Clam Bar"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Sporeggar"] ), BFAC["Sporeggar"] )
	addTradeSkill( L["Sporeling Snack"], 310, ARL_AddReputation1( BFAC["Friendly"], BFAC["Sporeggar"] ), BFAC["Sporeggar"] )
	addTradeSkill( L["Blackened Sporefish"], 310, L["Vendor"] )
	addTradeSkill( L["Blackened Basilisk"], 310, L["Vendor"] )
	addTradeSkill( L["Stewed Trout"], 310, L["Stewed Trout Obt"] )
	addTradeSkill( L["Grilled Mudfish"], 320, L["Vendor"] )
	addTradeSkill( L["Poached Bluefish"], 320, L["Vendor"] )
	addTradeSkill( L["Roasted Clefthoof"], 325, L["Vendor"] )
	addTradeSkill( L["Warp Burger"], 325, L["Vendor"] )
	addTradeSkill( L["Talbuk Steak"], 325, L["Vendor"] )
	--addTradeSkill( L["Spicy Hot Talbuk"], 325, L["Cooking Daily"] )
	--addTradeSkill( L["Skullfish Soup"], 325, L["Cooking Daily"] )
	addTradeSkill( L["Golden Fish Sticks"], 325, L["Vendor"] )
	addTradeSkill( L["Crunchy Serpent"], 335, L["Crunchy Serpent Obt"] )
	addTradeSkill( L["Mok'Nathal Shortribs"], 335, L["Mok'Nathal Shortribs Obt"] )
	addTradeSkill( L["Spicy Crawdad"], 350, L["Vendor"] )
	addTradeSkill( L["Fisherman's Feast"], 350, L["Fisherman's Feast Obt"] )
	addTradeSkill( L["Hot Buttered Trout"], 350, L["Hot Buttered Trout Obt"] )
  
end

-- Initializes the array adding all Enchanting recipes.  As of 2.2 there are 215 recipes.

local function ARL_InitEnchanting()

	ARL_InitializeRecipeArray()

	-- Original Game Recipes
	addTradeSkill( L["Enchant Bracer - Minor Health"], 1, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Minor Deflection"], 1, L["Trainer"] )
	addTradeSkill( L["Runed Copper Rod"], 1, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Minor Health"], 15, L["Trainer"] )
	addTradeSkill( L["Lesser Magic Wand"], 15, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Minor Mana"], 20, L["Vendor"] )
	addTradeSkill( L["Enchant Chest - Minor Absorption"], 40, L["Trainer"] )
	addTradeSkill( L["Enchant Cloak - Minor Resistance"], 45, L["Trainer"] )
	addTradeSkill( L["Minor Wizard Oil"], 45, L["Vendor"] )
	addTradeSkill( L["Enchant Bracer - Minor Stamina"], 50, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Lesser Health"], 60, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Minor Spirit"], 60, L["UWD"] )
	addTradeSkill( L["Enchant Cloak - Minor Protection"], 70, L["Trainer"] )
	addTradeSkill( L["Greater Magic Wand"], 70, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Lesser Mana"], 80, L["Vendor"])
	addTradeSkill( L["Enchant Bracer - Minor Agility"], 80, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Minor Strength"], 80, L["UWD"]  )
	addTradeSkill( L["Enchant Weapon - Minor Beastslayer"], 90, L["UWD"]  )
	addTradeSkill( L["Enchant Weapon - Minor Striking"], 90, L["Trainer"] )
	addTradeSkill( L["Enchant 2H Weapon - Minor Impact"], 100, L["Trainer"] )
	addTradeSkill( L["Enchant 2H Weapon - Lesser Intellect"], 100, L["Vendor"] )
	addTradeSkill( L["Runed Silver Rod"], 100, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Minor Stamina"], 105, L["Trainer"] )
	addTradeSkill( L["Enchant 2H Weapon - Lesser Spirit"], 110, L["UWD"] )
	addTradeSkill( L["Enchant Cloak - Minor Agility"], 110, L["Vendor"] )
	addTradeSkill( L["Enchant Cloak - Lesser Protection"], 115, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Lesser Protection"], 115, L["UWD"] )
	addTradeSkill( L["Enchant Chest - Health"], 120, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Lesser Spirit"], 120, L["UWD"] )
	addTradeSkill( L["Enchant Cloak - Lesser Fire Resistance"], 125, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Minor Stamina"], 125, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Minor Agility"], 125, L["Vendor"]) 
	addTradeSkill( L["Enchant Bracer - Lesser Stamina"], 130, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Lesser Spirit"], 130, L["Trainer"] )
	addTradeSkill( L["Enchant Cloak - Lesser Shadow Resistance"], 135, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Lesser Striking"], 140, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Lesser Strength"], 140, L["Vendor"] )
	addTradeSkill( L["Enchant Chest - Lesser Absorption"], 140, L["Trainer"] )
	addTradeSkill( L["Enchant 2H Weapon - Lesser Impact"], 145, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Mana"], 145, L["Trainer"] )
	addTradeSkill( L["Enchant Gloves - Mining"], 145, L["Enchant Gloves - Mining Obt"] )
	addTradeSkill( L["Enchant Gloves - Herbalism"], 145, L["Enchant Gloves - Herbalism Obt"] )
	addTradeSkill( L["Enchant Gloves - Fishing"], 145, L["Enchant Gloves - Fishing Obt"] )
	addTradeSkill( L["Enchant Chest - Minor Stats"], 150, L["Trainer"] )
	addTradeSkill( L["Runed Golden Rod"], 150, L["Trainer"] )
	addTradeSkill( L["Lesser Mystic Wand"], 155, L["Trainer"] )
	addTradeSkill( L["Minor Mana Oil"], 150, L["Vendor"] )
	addTradeSkill( L["Enchant Bracer - Lesser Intellect"], 150, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Lesser Stamina"], 155, L["Trainer"] )
	addTradeSkill( L["Enchant Cloak - Defense"], 155, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Lesser Agility"], 160, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Greater Health"], 160, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Spirit"], 165, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Lesser Stamina"], 170, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Lesser Deflection"], 170, L["Vendor"] )
	addTradeSkill( L["Enchant Bracer - Stamina"], 170, L["Trainer"] )
	addTradeSkill( L["Enchant Weapon - Lesser Beastslayer"], 175, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Lesser Elemental Slayer"], 175, L["UWD"] )
	addTradeSkill( L["Enchant Cloak - Fire Resistance"], 175, L["Trainer"] )
	addTradeSkill( L["Greater Mystic Wand"], 175, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Spirit"], 180, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Strength"], 180, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Greater Mana"], 185, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Lesser Spirit"], 190, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Winter's Might"], 190, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Enchant Shield - Lesser Block"], 195, L["UWD"]  )
	addTradeSkill( L["Enchant Weapon - Striking"], 195, L["Trainer"] )
	addTradeSkill( L["Enchant 2H Weapon - Impact"], 200, L["Trainer"] )
	addTradeSkill( L["Enchant Gloves - Skinning"], 200, L["Enchant Gloves - Skinning Obt"] )
	addTradeSkill( L["Enchant Chest - Lesser Stats"], 200, L["Trainer"] )
	addTradeSkill( L["Runed Truesilver Rod"], 200, L["Trainer"] )
	addTradeSkill( L["Lesser Wizard Oil"], 200, L["Vendor"] )
	addTradeSkill( L["Enchant Cloak - Greater Defense"], 205, L["Trainer"] )
	addTradeSkill( L["Enchant Cloak - Resistance"], 205, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Stamina"], 210, L["UWD"] )
	addTradeSkill( L["Enchant Bracer - Intellect"], 210, L["Trainer"] )
	addTradeSkill( L["Enchant Gloves - Agility"], 210, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Stamina"], 215, L["Trainer"] )
	addTradeSkill( L["Enchant Gloves - Advanced Mining"], 215, L["Enchant Gloves - Advanced Mining Obt"] )
	addTradeSkill( L["Enchant Bracer - Greater Spirit"], 220, L["UWD"] )
	addTradeSkill( L["Enchant Chest - Superior Health"], 220, L["Trainer"] )
	addTradeSkill( L["Enchant Gloves - Advanced Herbalism"], 225, L["Enchant Gloves - Advanced Herbalism Obt"] )
	addTradeSkill( L["Enchant Cloak - Lesser Agility"], 225, L["Enchant Cloak - Lesser Agility Obt"] )
	addTradeSkill( L["Enchant Gloves - Strength"], 225, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Minor Speed"], 225, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Greater Spirit"], 230, L["Trainer"] )
	addTradeSkill( L["Enchant Weapon - Demonslaying"], 230, L["UWD"] )
	addTradeSkill( L["Enchant Chest - Superior Mana"], 230, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Deflection"], 235, L["Vendor"] )
	addTradeSkill( L["Enchant Shield - Frost Resistance"], 235, L["UWD"] )
	addTradeSkill( L["Enchant Boots - Agility"], 235, L["Trainer"] )
	addTradeSkill( L["Enchant 2H Weapon - Greater Impact"], 240, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Greater Strength"], 240, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Stats"], 245, L["Trainer"] )
	addTradeSkill( L["Enchant Weapon - Greater Striking"], 245, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Greater Stamina"], 245, L["UWD"] )
	addTradeSkill( L["Enchant Gloves - Riding Skill"], 250, L["UWD"] )
	addTradeSkill( L["Enchant Gloves - Minor Haste"], 250, L["Trainer"] )
	addTradeSkill( L["Enchanted Leather"], 250, L["Trainer"] )
	addTradeSkill( L["Enchanted Thorium"], 250, L["Trainer"] )
	addTradeSkill( L["Lesser Mana Oil"], 250, L["Vendor"] )
	addTradeSkill( L["Enchant Bracer - Greater Intellect"], 255, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Greater Stamina"], 255, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Fiery Weapon"], 265, L["Enchant Weapon - Fiery Weapon Obt"] )
	addTradeSkill( L["Smoking Heart of the Mountain"], 265, L["Smoking Heart of the Mountain Obt"] )
	addTradeSkill( L["Enchant Cloak - Greater Resistance"], 265, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Greater Stamina"], 265, L["Vendor"] )
	addTradeSkill( L["Enchant Bracer - Superior Spirit"], 270, L["Trainer"] )
	addTradeSkill( L["Enchant Gloves - Greater Agility"], 270, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Spirit"], 275, L["UWD"] )
	addTradeSkill( L["Enchant Chest - Major Health"], 275, L["Vendor"] )
	addTradeSkill( L["Wizard Oil"], 275, L["Vendor"] )
	addTradeSkill( L["Enchant Shield - Superior Spirit"], 280, L["Trainer"] )
	addTradeSkill( L["Enchant Weapon - Icy Chill"], 285, L["Enchant Weapon - Icy Chill Obt"] )
	addTradeSkill( L["Enchant Cloak - Superior Defense"], 285, L["Vendor"] )
	addTradeSkill( L["Enchant Chest - Major Mana"], 290, L["Trainer"] )
	addTradeSkill( L["Runed Arcanite Rod"], 290, L["Vendor"] )
	addTradeSkill( L["Enchant Weapon - Strength"], 290, ARL_AddReputation1( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Enchant Weapon - Agility"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Enchant Bracer - Mana Regeneration"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Enchant 2H Weapon - Agility"], 290, ARL_AddReputation1( BFAC["Friendly"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Enchant Gloves - Greater Strength"], 295, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Greater Agility"], 295, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Superior Strength"], 295, L["Enchant Bracer - Superior Strength Obt"] )
	addTradeSkill( L["Enchant 2H Weapon - Superior Impact"], 295, L["Enchant 2H Weapon - Superior Impact Obt"] )
	addTradeSkill( L["Enchant Weapon - Unholy Weapon"], 295, L["Enchant Weapon - Unholy Weapon Obt"] )
	addTradeSkill( L["Enchant 2H Weapon - Major Intellect"], 300, L["Enchant 2H Weapon - Major Intellect Obt"] )
	addTradeSkill( L["Enchant Weapon - Superior Striking"], 300, L["Enchant Weapon - Superior Striking Obt"] )
	addTradeSkill( L["Enchant Bracer - Superior Stamina"], 300, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Crusader"], 300, L["Enchant Weapon - Crusader Obt"] )
	addTradeSkill( L["Enchant Chest - Greater Stats"], 300, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Lifestealing"], 300, L["Enchant Weapon - Lifestealing Obt"] )
	addTradeSkill( L["Enchant 2H Weapon - Major Spirit"], 300, L["Enchant 2H Weapon - Major Spirit Obt"] )
	addTradeSkill( L["Enchant Weapon - Spell Power"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Enchant Weapon - Healing Power"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Enchant Bracer - Healing Power"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Enchant Weapon - Mighty Spirit"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Enchant Weapon - Mighty Intellect"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Enchant Gloves - Shadow Power"], 300, L["AQ20/AQ40"], L["Raid"] )
	addTradeSkill( L["Enchant Gloves - Frost Power"], 300, L["AQ20/AQ40"], L["Raid"] )
	addTradeSkill( L["Enchant Gloves - Fire Power"], 300, L["AQ20/AQ40"], L["Raid"] )
	addTradeSkill( L["Enchant Gloves - Healing Power"], 300, L["AQ20/AQ40"], L["Raid"] )
	addTradeSkill( L["Enchant Cloak - Greater Fire Resistance"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Enchant Cloak - Greater Nature Resistance"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Brilliant Wizard Oil"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Brilliant Mana Oil"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Enchant Gloves - Superior Agility"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Enchant Gloves - Threat"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Enchant Cloak - Stealth"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Enchant Cloak - Subtlety"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Enchant Cloak - Dodge"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Lower City"] ), BFAC["Lower City"] )
	addTradeSkill( L["Runed Fel Iron Rod"], 300, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Restore Mana Prime"], 300, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Assault"], 300, L["Trainer"] )
	addTradeSkill( L["Enchant Boots - Vitality"], 305, L["UWD"] )
	addTradeSkill( L["Enchant Gloves - Blasting"], 305, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Brawn"], 305, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Major Intellect"], 305, L["Trainer"] )
	addTradeSkill( L["Superior Mana Oil"], 310, L["Vendor"] )
	addTradeSkill( L["Enchant Gloves - Assault"], 310, L["Trainer"] )
	addTradeSkill( L["Enchant Shield - Tough Shield"], 310, L["Trainer"] )
	addTradeSkill( L["Enchant Cloak - Greater Agility"], 310, L["Trainer"] )
	addTradeSkill( L["Enchant Cloak - Major Armor"], 310, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Stats"], 315, L["Trainer"] )
	addTradeSkill( L["Enchant Chest - Exceptional Health"], 315, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Major Defense"], 320, L["Enchant Bracer - Major Defense Obt"] )
	addTradeSkill( L["Enchant Boots - Fortitude"], 320, L["Enchant Boots - Fortitude Obt"] )
	addTradeSkill( L["Enchant Chest - Major Spirit"], 320, L["Trainer"] )
	addTradeSkill( L["Prismatic Sphere"], 325, L["Trainer"] )
	addTradeSkill( L["Enchant Bracer - Superior Healing"], 325, ARL_AddReputation2( BFAC["Friendly"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Enchant Shield - Intellect"], 325, L["Vendor"] )
	addTradeSkill( L["Enchant Cloak - Spell Penetration"], 325, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Enchant Shield - Major Stamina"], 325, L["Vendor"] )
	addTradeSkill( L["Enchant Cloak - Major Resistance"], 330, L["UWD"] )
	addTradeSkill( L["Large Prismatic Shard"], 325, L["Vendor"] )
	addTradeSkill( L["Enchant Bracer - Restore Mana Prime"], 335, L["UWD"] )
	addTradeSkill( L["Superior Wizard Oil"], 340, L["Vendor"] )
	addTradeSkill( L["Enchant Shield - Shield Block"], 340, L["UWD"] )
	addTradeSkill( L["Enchant Boots - Dexterity"], 340, L["Enchant Boots - Dexterity Obt"] )
	addTradeSkill( L["Enchant Weapon - Major Intellect"], 340, L["Enchant Weapon - Major Intellect Obt"] )
	addTradeSkill( L["Enchant Gloves - Major Strength"], 340, L["Trainer"] )
	addTradeSkill( L["Enchant Weapon - Major Striking"], 340, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Enchant Chest - Exceptional Stats"], 345, ARL_AddReputation2( BFAC["Revered"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Enchant Chest - Major Resilience"], 345, L["UWD"] )
	addTradeSkill( L["Enchant Bracer - Fortitude"], 350, L["Enchant Bracer - Fortitude Obt"] )
	addTradeSkill( L["Enchant 2H Weapon - Savagery"], 350, L["Enchant 2H Weapon - Savagery Obt"] )
	addTradeSkill( L["Enchant Weapon - Potency"], 350, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Major Spellpower"], 350, L["Enchant Weapon - Major Spellpower Obt"] )
	addTradeSkill( L["Void Sphere"], 350, L["Trainer"] )
	addTradeSkill( L["Nexus Transformation"], 350, L["Trainer"] )
	addTradeSkill( L["Small Prismatic Shard"], 350, L["Trainer"] )
	addTradeSkill( L["Runed Adamantite Rod"], 350, L["Vendor"] )
	addTradeSkill( L["Enchant Gloves - Major Healing"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Enchant Weapon - Greater Agility"], 350, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Violet Eye"] ), BFAC["The Violet Eye"] )
	addTradeSkill( L["Enchant Cloak - Greater Arcane Resistance"], 350, L["Enchant Cloak - Greater Arcane Resistance Obt"] )
	addTradeSkill( L["Enchant Cloak - Greater Shadow Resistance"], 350, L["Enchant Cloak - Greater Shadow Resistance Obt"] )
	addTradeSkill( L["Enchant Weapon - Major Healing"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Enchant Bracer - Spellpower"], 360, L["Enchant Bracer - Spellpower Obt"] )
	addTradeSkill( L["Enchant Ring - Striking"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Consortium"] ), L["Raid"] )
	addTradeSkill( L["Enchant Ring - Spellpower"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Enchant Shield - Resistance"], 360, L["UWD"] )
	addTradeSkill( L["Enchant 2H Weapon - Major Agility"], 360, L["Enchant 2H Weapon - Major Agility Obt"] )
	addTradeSkill( L["Enchant Weapon - Spellsurge"], 360, L["UWD"] )
	addTradeSkill( L["Enchant Weapon - Battlemaster"], 360, L["UWD"] )
	addTradeSkill( L["Enchant Gloves - Spell Strike"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Enchant Gloves - Major Spellpower"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Enchant Boots - Cat's Swiftness"], 360, L["UWD"] )
	addTradeSkill( L["Enchant Boots - Boar's Speed"], 360, L["UWD"] )
	addTradeSkill( L["Enchant Ring - Healing Power"], 370, ARL_AddReputation1( BFAC["Revered"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Enchant Boots - Surefooted"], 370, L["Enchant Boots - Surefooted Obt"], L["Raid"] )
	addTradeSkill( L["Runed Eternium Rod"], 375, L["Vendor"] )
	addTradeSkill( L["Enchant Ring - Stats"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Enchant Weapon - Sunfire"], 375, L["Enchant Weapon - Sunfire Obt"], L["Raid"] )
	addTradeSkill( L["Enchant Weapon - Soulfrost"], 375, L["Enchant Weapon - Soulfrost Obt"], L["Raid"] )
	addTradeSkill( L["Enchant Weapon - Mongoose"], 375, L["Enchant Weapon - Mongoose Obt"], L["Raid"] )
	--addTradeSkill( L["Enchant Weapon - Executioner"], 375, L["ZA"], L["Raid"] )

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Engineering recipes.  As of 2.2 there are 220 recipes.

local function ARL_InitEngineering()

	ARL_InitializeRecipeArray()

	addTradeSkill( L["Rough Blasting Powder"], 1, L["Trainer"] )
	addTradeSkill( L["Rough Dynamite"], 1, L["Trainer"] )
	addTradeSkill( L["Crafted Light Shot"], 1, L["Trainer"] )
	addTradeSkill( L["Handful of Copper Bolts"], 30, L["Trainer"] )
	addTradeSkill( L["Rough Copper Bomb"], 30, L["Trainer"] )
	addTradeSkill( L["Copper Tube"], 50, L["Trainer"] )
	addTradeSkill( L["Rough Boomstick"], 50, L["Trainer"] )
	addTradeSkill( L["Arclight Spanner"], 50, L["Trainer"] )
	addTradeSkill( L["Crude Scope"], 60, L["Trainer"] )
	addTradeSkill( L["Copper Modulator"], 65, L["Trainer"] )
	addTradeSkill( L["Mechanical Squirrel"], 75, L["UWD"] )
	addTradeSkill( L["Coarse Blasting Powder"], 75, L["Trainer"] )
	addTradeSkill( L["Crafted Heavy Shot"], 75, L["Trainer"] )
	addTradeSkill( L["Coarse Dynamite"], 75, L["Trainer"] )
	addTradeSkill( L["Target Dummy"], 85, L["Trainer"] )
	addTradeSkill( L["Silver Contact"], 90, L["Trainer"] )
	addTradeSkill( L["Small Seaforium Charge"], 100, L["UWD"] )
	addTradeSkill( L["Flying Tiger Goggles"], 100, L["Trainer"] )
	addTradeSkill( L["Practice Lock"], 100, L["Trainer"] )
	addTradeSkill( L["EZ-Thro Dynamite"], 100, L["UWD"] )
	addTradeSkill( L["Deadly Blunderbuss"], 105, L["Trainer"] )
	addTradeSkill( L["Large Copper Bomb"], 105, L["Trainer"] )
	addTradeSkill( L["Bronze Tube"], 105, L["Trainer"] )
	addTradeSkill( L["Standard Scope"], 110, L["Trainer"] )
	addTradeSkill( L["Lovingly Crafted Boomstick"], 120, L["Vendor"] )
	addTradeSkill( L["Shadow Goggles"], 120, L["UWD"] )
	addTradeSkill( L["Small Bronze Bomb"], 120, L["Trainer"] )
	addTradeSkill( L["Whirring Bronze Gizmo"], 125, L["Trainer"] )
	addTradeSkill( L["Flame Deflector"], 125, L["Flame Detector Obt"] )
	addTradeSkill( L["Heavy Blasting Powder"], 125, L["Trainer"] )
	addTradeSkill( L["Heavy Dynamite"], 125, L["Trainer"] )
	addTradeSkill( L["Crafted Solid Shot"], 125, L["Trainer"] )
	addTradeSkill( L["Gnomish Universal Remote"], 125, L["Vendor"] )
	addTradeSkill( L["Small Blue Rocket"], 125, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Small Green Rocket"], 125, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Small Red Rocket"], 125, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Silver-plated Shotgun"], 130, L["Trainer"] )
	addTradeSkill( L["Ornate Spyglass"], 135, L["Trainer"] )
	addTradeSkill( L["Big Bronze Bomb"], 140, L["Trainer"] )
	addTradeSkill( L["Minor Recombobulator"], 140, L["Vendor"] )
	addTradeSkill( L["Bronze Framework"], 140, L["Trainer"] )
	addTradeSkill( L["Moonsight Rifle"], 145, L["UWD"] )
	addTradeSkill( L["Explosive Sheep"], 150, L["Trainer"] )
	addTradeSkill( L["Green Tinted Goggles"], 150, L["Trainer"] )
	addTradeSkill( L["Aquadynamic Fish Attractor"], 150, L["Trainer"] )
	addTradeSkill( L["Gold Power Core"], 150, L["Trainer"] )
	addTradeSkill( L["Red Firework"], 150, L["Vendor"] )
	addTradeSkill( L["Green Firework"], 150, L["Vendor"] )
	addTradeSkill( L["Blue Firework"], 150, L["Vendor"] )
	addTradeSkill( L["Ice Deflector"], 155, L["Vendor"] )
	addTradeSkill( L["Iron Strut"], 160, L["Trainer"] )
	addTradeSkill( L["Discombobulator Ray"], 160, L["Discombobulator Ray Obt"] )
	addTradeSkill( L["Portable Bronze Mortar"], 165, L["UWD"] )
	addTradeSkill( L["Goblin Jumper Cables"], 165, L["Vendor"] )
	addTradeSkill( L["Gyrochronatom"], 170, L["Trainer"] )
	addTradeSkill( L["Iron Grenade"], 175, L["Trainer"] )
	addTradeSkill( L["Compact Harvest Reaper Kit"], 175, L["Trainer"] )
	addTradeSkill( L["Solid Blasting Powder"], 175, L["Trainer"] )
	addTradeSkill( L["Solid Dynamite"], 175, L["Trainer"] )
	addTradeSkill( L["Bright-Eye Goggles"], 175, L["UWD"] )
	addTradeSkill( L["Gyromatic Micro-Adjustor"], 175, L["Trainer"] )
	addTradeSkill( L["Large Blue Rocket"], 175, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Large Green Rocket"], 175, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Large Red Rocket"], 175, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Accurate Scope"], 180, L["Vendor"] )
	addTradeSkill( L["Advanced Target Dummy"], 185, L["Trainer"] )
	addTradeSkill( L["Craftsman's Monocle"], 185, L["UWD"]  )
	addTradeSkill( L["Flash Bomb"], 185, L["Flash Bomb Obt"] )
	addTradeSkill( L["Big Iron Bomb"], 190, L["Trainer"] )
	addTradeSkill( L["SnowMaster 9000"], 190, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Goblin Land Mine"], 195, L["UWD"] )
	addTradeSkill( L["Mithril Tube"], 195, L["Trainer"] )
	addTradeSkill( L["Mechanical Dragonling"], 200, L["Vendor"] )
	addTradeSkill( L["Gnomish Cloaking Device"], 200, L["Vendor"] )
	addTradeSkill( L["Large Seaforium Charge"], 200, L["UWD"] )
	addTradeSkill( L["Unstable Trigger"], 200, L["Trainer"] )
	addTradeSkill( L["Mechanical Repair Kit"], 200, L["Trainer"] )
	addTradeSkill( L["EZ-Thro Dynamite II"], 200, L["Vendor"] )
	addTradeSkill( L["Fire Goggles"], 205, L["Trainer"] )
	addTradeSkill( L["Mithril Blunderbuss"], 205, L["Trainer"] )
	addTradeSkill( L["Hi-Impact Mithril Slugs"], 210, L["Trainer"] )
	addTradeSkill( L["Deadly Scope"], 210, L["Vendor"] )
	addTradeSkill( L["Mithril Casing"], 215, L["Trainer"] )
	addTradeSkill( L["Mithril Frag Bomb"], 215, L["Trainer"] )
	addTradeSkill( L["Catseye Ultra Goggles"], 220, L["UWD"] )
	addTradeSkill( L["Mithril Heavy-bore Rifle"], 220, L["UWD"] )
	addTradeSkill( L["Goblin Rocket Boots"], 225, L["Trainer"] )
	addTradeSkill( L["Spellpower Goggles Xtreme"], 225, L["UWD"] )
	addTradeSkill( L["Parachute Cloak"], 225, L["UWD"] )
	addTradeSkill( L["Blue Rocket Cluster"], 225, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Green Rocket Cluster"], 225, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Red Rocket Cluster"], 225, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Firework Launcher"], 225, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Deepdive Helmet"], 230, L["Vendor"] )
	addTradeSkill( L["Rose Colored Goggles"], 230, L["Trainer"] )
	addTradeSkill( L["Hi-Explosive Bomb"], 235, L["Trainer"] )
	addTradeSkill( L["Sniper Scope"], 240, L["UWD"] )
	addTradeSkill( L["Mithril Gyro-Shot"], 245, L["Trainer"] )
	addTradeSkill( L["Green Lens"], 245, L["Trainer"] )
	addTradeSkill( L["Mithril Mechanical Dragonling"], 250, L["Vendor"] )
	addTradeSkill( L["Salt Shaker"], 250, L["Trainer"] )
	addTradeSkill( L["Dense Blasting Powder"], 250, L["Trainer"] )
	addTradeSkill( L["Dense Dynamite"], 250, L["Trainer"] )
	addTradeSkill( L["Snake Burst Firework"], 250, L["Vendor"] )
	addTradeSkill( L["Tranquil Mechanical Yeti"], 250, L["Trainer"] )
	addTradeSkill( L["Thorium Grenade"], 260, L["Vendor"] )
	addTradeSkill( L["Thorium Rifle"], 260, L["UWD"] )
	addTradeSkill( L["Thorium Widget"], 260, L["Vendor"] )
	addTradeSkill( L["Truesilver Transformer"], 260, L["Vendor"] )
	addTradeSkill( L["Gyrofreeze Ice Reflector"], 260, L["Vendor"] )
	addTradeSkill( L["Lifelike Mechanical Toad"], 265, L["UWD"] )
	addTradeSkill( L["Spellpower Goggles Xtreme Plus"], 270, L["Spellpower Goggles Xtreme Plus Obt"] )
	addTradeSkill( L["Dark Iron Rifle"], 275, L["Dark Iron Rifle Obt"] )
	addTradeSkill( L["Masterwork Target Dummy"], 275, L["Vendor"] )
	addTradeSkill( L["Thorium Tube"], 275, L["Vendor"] )
	addTradeSkill( L["Major Recombobulator"], 275, L["DMCACHE"] )
	addTradeSkill( L["Powerful Seaforium Charge"], 275, L["Vendor"] )
	addTradeSkill( L["Large Blue Rocket Cluster"], 275, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Large Green Rocket Cluster"], 275, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Large Red Rocket Cluster"], 275, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Firework Cluster Launcher"], 275, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Fused Wiring"], 275, L["Vendor"] )
	addTradeSkill( L["Steam Tonk Controller"], 275, L["Steam Tonk Controller Obt"] )
	addTradeSkill( L["Delicate Arcanite Converter"], 285, L["Vendor"] )
	addTradeSkill( L["Dark Iron Bomb"], 285, L["Dark Iron Bomb Obt"] )
	addTradeSkill( L["Thorium Shells"], 285, L["UWD"] )
	addTradeSkill( L["Voice Amplification Modulator"], 290, L["Voice Amplification Modulator Obt"] )
	addTradeSkill( L["Master Engineer's Goggles"], 290, L["Master Engineer's Goggles Obt"] )
	addTradeSkill( L["Hyper-Radiant Flame Reflector"], 290, L["Hyper-Radiant Flame Reflector Pbt"] )
	addTradeSkill( L["Arcane Bomb"], 300, L["UWD"] )
	addTradeSkill( L["Arcanite Dragonling"], 300, L["Arcanite Dragonling Obt"] )
	addTradeSkill( L["Flawless Arcanite Rifle"], 300, L["Flawless Arcanite Rifle Obt"] )
	addTradeSkill( L["Field Repair Bot 74A"], 300, L["Field Repair Bot 74A Obt"] )
	addTradeSkill( L["Biznicks 247x128 Accurascope"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Core Marksman Rifle"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Force Reactive Disk"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Ultra-Flash Shadow Reflector"], 300, L["Ultra-Flash Shadow Reflector Obt"] )
	addTradeSkill( L["Bloodvine Goggles"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Bloodvine Lens"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Fel Iron Bomb"], 300, L["Trainer"] )
	addTradeSkill( L["Fel Iron Casing"], 300, L["Trainer"] )
	addTradeSkill( L["Elemental Blasting Powder"], 300, L["Trainer"] )
	addTradeSkill( L["Handful of Fel Iron Bolts"], 300, L["Trainer"] )
	addTradeSkill( L["Zapthrottle Mote Extractor"], 305, L["Zapthrottle Mote Extractor Obt"] )
	addTradeSkill( L["Fel Iron Shells"], 310, L["Trainer"] )
	addTradeSkill( L["Fel Iron Musket"], 320, L["Trainer"] )
	addTradeSkill( L["Fel Iron Toolbox"], 325, L["Vendor"] )
	addTradeSkill( L["Crashin' Thrashin' Robot"], 325, L["UWD"] )
	addTradeSkill( L["Adamantite Frame"], 325, L["Trainer"] )
	addTradeSkill( L["Adamantite Grenade"], 325, L["Trainer"] )
	addTradeSkill( L["Healing Potion Injector"], 330, L["UWD"] )
	--addTradeSkill( L["Adamantite Arrow Maker"], 335, L["Trainer"] )
	addTradeSkill( L["Adamantite Scope"], 335, L["Vendor"] )
	addTradeSkill( L["White Smoke Flare"], 335, L["Vendor"] )
	addTradeSkill( L["Green Smoke Flare"], 335, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Adamantite Shells"], 335, L["Vendor"] )
	addTradeSkill( L["Purple Smoke Flare"], 335, L["UWD"] )
	addTradeSkill( L["Cogspinner Goggles"], 340, L["Vendor"] )
	addTradeSkill( L["Power Amplification Goggles"], 340, L["UWD"] )
	addTradeSkill( L["Mana Potion Injector"], 345, L["UWD"] )
	addTradeSkill( L["Adamantite Rifle"], 350, L["Vendor"] )
	addTradeSkill( L["Ultra-Spectropic Detection Goggles"], 350, L["Vendor"] )
	addTradeSkill( L["Khorium Power Core"], 350, L["Trainer"] )
	addTradeSkill( L["Felsteel Stabilizer"], 350, L["Trainer"] )
	addTradeSkill( L["Hardened Adamantite Tube"], 350, L["Trainer"] )
	--addTradeSkill( L["Flying Machine Control"], 350, L["Trainer"] )
	addTradeSkill( L["Rocket Boots Xtreme"], 355, L["Rocket Boots Xtreme Obt"] )
	addTradeSkill( L["Felsteel Boomstick"], 360, L["Felsteel Boomstick Obt"] )
	addTradeSkill( L["Hyper-Vision Goggles"], 360, L["Hyper-Vision Goggles Obt"] )
	addTradeSkill( L["Khorium Scope"], 360, L["Khorium Scope Obt"] )
	--addTradeSkill( L["Field Repair Bot 110G"], 360, L["Field Repair Bot 110G Obt"] )
	addTradeSkill( L["Ornate Khorium Rifle"], 375, L["UWD"] )
	addTradeSkill( L["Stabilized Eternium Scope"], 375, L["Stabilized Eternium Scope Obt"], L["Raid"] )
	addTradeSkill( L["Frost Grenades"], 335, L["Trainer"] )
	addTradeSkill( L["Icy Blasting Primers"], 335, L["Trainer"] )
	addTradeSkill( L["Deathblow XII Goggles"], 350,	L["Trainer"] )
	addTradeSkill( L["Destruction Holo-gogs"], 350,	L["Trainer"] )
	addTradeSkill( L["Elemental Seaforium Charge"],	350, L["Vendor"] )
	addTradeSkill( L["Furious Gizmatic Goggles"], 350, L["Trainer"] )
	addTradeSkill( L["Nigh Invulnerability Belt"], 350,	L["Trainer"] )
	addTradeSkill( L["Powerheal 4000 Lens"], 350, L["Trainer"] )
	addTradeSkill( L["Surestrike Goggles v2.0"], 350, L["Trainer"] )
	addTradeSkill( L["Tankatronic Goggles"], 350, L["Trainer"] )
	addTradeSkill( L["Wonderheal XT40 Shades"], 350, L["Trainer"] )
	addTradeSkill( L["Gyro-balanced Khorium Destroyer "], 375, L["Trainer"] )

	-- Wrath of the Litch King Recipes

	-- Gnomish Engineering
	addTradeSkill( L["Lil' Smoky"], 205, L["ENG_MEMBERSHIP_BENEFITS"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Shrink Ray"], 205, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Goggles"], 210, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Net-o-Matic Projector"], 210, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Harm Prevention Belt"], 215, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Rocket Boots"], 225, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Battle Chicken"], 230, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Mind Control Cap"], 235, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Death Ray"], 240, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["World Enlarger"], 260, L["World Enlarger Obt"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Ultrasafe Transporter - Gadgetzan"], 260, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Alarm-O-Bot"], 265, L["Alarm-O-Bot Obt"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Inlaid Mithril Cylinder Plans"], 200, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Flame Turret"], 325, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Poultryizer"], 340, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Ultrasafe Transporter - Toshley's Station"], 350, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Battle Goggles"], 375, L["Trainer"], BTS["Gnomish Engineering"] )
	addTradeSkill( L["Gnomish Power Goggles"], 375, L["Trainer"], BTS["Gnomish Engineering"] )

	-- Goblin Engineering
	addTradeSkill( L["Goblin Construction Helmet"], 205, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Mining Helmet"], 205, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Pet Bombling"], 205, L["ENG_MEMBERSHIP_BENEFITS"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Mortar"], 205, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["The Mortar: Reloaded"], 205, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Sapper Charge"], 205, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Rocket Boots"], 225, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Bomb Dispenser"], 230, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["The Big One"], 235,  L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Rocket Helmet"], 245, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Dimensional Ripper - Everlook"], 260,  L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Jumper Cables XL"], 265, L["Goblin Jumper Cables XL Obt"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Rocket Fuel Recipe"], 205, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Dragon Gun"], 240, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["The Bigger One"], 325, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Super Sapper Charge"], 340, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Goblin Rocket Launcher"], 350, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Dimensional Ripper - Area 52"], 350, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Foreman's Enchanted Helmet"], 375, L["Trainer"], BTS["Goblin Engineering"] )
	addTradeSkill( L["Foreman's Reinforced Helmet"], 375, L["Trainer"], BTS["Goblin Engineering"] )

end

-- Initializes the array adding all First Aid recipes.  As of 2.2 there are 15 recipes.

local function ARL_InitFirstAid()
  
	ARL_InitializeRecipeArray()
  
	-- Original Game Recipes
	addTradeSkill( L["Linen Bandage"], 1, L["Trainer"])
	addTradeSkill( L["Heavy Linen Bandage"], 40, L["Trainer"])
	addTradeSkill( L["Wool Bandage"], 80, L["Trainer"])
	addTradeSkill( L["Anti-Venom"], 80, L["Trainer"])
	addTradeSkill( L["Heavy Wool Bandage"], 115, L["Trainer"])
	addTradeSkill( L["Strong Anti-Venom"], 130, L["UWD"])
	addTradeSkill( L["Silk Bandage"], 150, L["Trainer"])
	addTradeSkill( L["Heavy Silk Bandage"], 180, L["Vendor"] )
	addTradeSkill( L["Mageweave Bandage"], 210, L["Vendor"] )
	addTradeSkill( L["Heavy Mageweave Bandage"], 240, L["Trainer"])
	addTradeSkill( L["Runecloth Bandage"], 260, L["Trainer"])
	addTradeSkill( L["Heavy Runecloth Bandage"], 290, L["Trainer"])
	addTradeSkill( L["Powerful Anti-Venom"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Netherweave Bandage"], 330, L["Vendor"] )
	addTradeSkill( L["Heavy Netherweave Bandage"], 360, L["Vendor"] )

	-- Wrath of the Litch King Recipes

end

-- Initializes the array adding all Jewelcrafting recipes.  As of 2.2 there are 229 recipes.

local function ARL_InitJewelcrafting()

	ARL_InitializeRecipeArray()

	-- Trainer Recipes
	addTradeSkill( L["Delicate Copper Wire"], 1, L["Trainer"] )
	addTradeSkill( L["Braided Copper Ring"], 1, L["Trainer"] )
	addTradeSkill( L["Woven Copper Ring"], 1, L["Trainer"] )
	addTradeSkill( L["Rough Stone Statue"], 1, L["Trainer"] )
	addTradeSkill( L["Heavy Copper Ring"], 5, L["Trainer"] )
	addTradeSkill( L["Malachite Pendant"], 20, L["Trainer"] )
	addTradeSkill( L["Tigerseye Band"], 20, L["Trainer"] )
	addTradeSkill( L["Inlaid Malachite Ring"], 30, L["Trainer"] )
	addTradeSkill( L["Ornate Tigerseye Necklace"], 30, L["Trainer"] )
	addTradeSkill( L["Bronze Setting"], 50, L["Trainer"] )
	addTradeSkill( L["Elegant Silver Ring"], 50, L["Trainer"] )
	addTradeSkill( L["Solid Bronze Ring"], 50, L["Trainer"] )
	addTradeSkill( L["Thick Bronze Necklace"], 50, L["Trainer"] )
	addTradeSkill( L["Coarse Stone Statue"], 50, L["Trainer"] )
	addTradeSkill( L["Simple Pearl Ring"], 60, L["Trainer"] )
	addTradeSkill( L["Bronze Band of Force"], 65, L["Trainer"] )
	addTradeSkill( L["Gloom Band"], 70, L["Trainer"] )
	addTradeSkill( L["Brilliant Necklace"], 75, L["Trainer"] )
	addTradeSkill( L["Bronze Torc"], 80, L["Trainer"] )
	addTradeSkill( L["Heavy Silver Ring"], 90, L["Trainer"] )
	addTradeSkill( L["Ring of Silver Might"], 100, L["Trainer"] )
	addTradeSkill( L["Ring of Twilight Shadows"], 100, L["Trainer"] )
	addTradeSkill( L["Heavy Jade Ring"], 105, L["Trainer"] )
	addTradeSkill( L["Barbaric Iron Collar"], 110, L["Trainer"] )
	addTradeSkill( L["Heavy Stone Statue"], 110, L["Trainer"] )
	addTradeSkill( L["Moonsoul Crown"], 120, L["Trainer"] )
	addTradeSkill( L["Golden Dragon Ring"], 135, L["Trainer"] )
	addTradeSkill( L["Mithril Filigree"], 150, L["Trainer"] )
	addTradeSkill( L["Engraved Truesilver Ring"], 170, L["Trainer"] )
	addTradeSkill( L["Solid Stone Statue"], 175, L["Trainer"] )
	addTradeSkill( L["Citrine Ring of Rapid Healing"], 180, L["Trainer"] )
	addTradeSkill( L["Golden Ring of Power"], 180, L["Trainer"] )
	addTradeSkill( L["Figurine - Jade Owl"], 200, L["Trainer"] )
	addTradeSkill( L["Truesilver Commander's Ring"], 200, L["Trainer"] )
	addTradeSkill( L["Aquamarine Signet"], 210, L["Trainer"] )
	addTradeSkill( L["Aquamarine Pendant of the Warrior"], 220, L["Trainer"] )
	addTradeSkill( L["Thorium Setting"], 225, L["Trainer"] )
	addTradeSkill( L["Dense Stone Statue"], 225, L["Trainer"] )
	addTradeSkill( L["Red Ring of Destruction"], 230, L["Trainer"] )
	addTradeSkill( L["Ruby Pendant of Fire"], 235, L["Trainer"] )
	addTradeSkill( L["Truesilver Healing Ring"], 240, L["Trainer"] )
	addTradeSkill( L["Simple Opal Ring"], 260, L["Trainer"] )
	addTradeSkill( L["Diamond Focus Ring"], 275, L["Trainer"] )
	addTradeSkill( L["Sapphire Signet"], 275, L["Trainer"] )
	addTradeSkill( L["Onslaught Ring"], 280, L["Trainer"] )
	addTradeSkill( L["Sapphire Pendant of Winter Night"], 280, L["Trainer"] )
	addTradeSkill( L["Glowing Thorium Band"], 280, L["Trainer"] )
	addTradeSkill( L["Living Emerald Pendant"], 290, L["Trainer"] )
	addTradeSkill( L["Emerald Lion Ring"], 290, L["Trainer"] )
	addTradeSkill( L["Band of Natural Fire"], 310, L["Trainer"] )
	addTradeSkill( L["Fel Iron Blood Ring"], 310, L["Trainer"] )
	addTradeSkill( L["Golden Draenite Ring"], 310, L["Trainer"] )
	addTradeSkill( L["Azure Moonstone Ring"], 320, L["Trainer"] )
	addTradeSkill( L["Mercurial Adamantite"], 325, L["Trainer"] )
	addTradeSkill( L["Heavy Adamantite Ring"], 335, L["Trainer"] )
	addTradeSkill( L["Thick Adamantite Necklace"], 335, L["Trainer"] )
	addTradeSkill( L["Brilliant Pearl Band"], 325, L["Trainer"] )
	addTradeSkill( L["Crown of the Sea Witch"], 365, L["Trainer"] )
	addTradeSkill( L["Necklace of the Deep"], 340, L["Trainer"] )
	addTradeSkill( L["Purified Jaggal Pearl"], 325, L["Trainer"] )
	addTradeSkill( L["Purified Shadow Pearl"], 350, L["Trainer"] )
	addTradeSkill( L["The Black Pearl"], 330, L["Trainer"] )

	-- Vendor Recipes
	addTradeSkill( L["Amulet of the Moon"], 110, L["Vendor"] )
	addTradeSkill( L["Pendant of the Agate Shield"], 120, L["Vendor"] )
	addTradeSkill( L["Wicked Moonstone Ring"], 125, L["Vendor"] )
	addTradeSkill( L["Heavy Iron Knuckles"], 125, L["Vendor"] )
	addTradeSkill( L["Heavy Golden Necklace of Battle"], 150, L["Vendor"] )
	addTradeSkill( L["Blazing Citrine Ring"], 150, L["Vendor"] )
	addTradeSkill( L["The Jade Eye"], 170, L["Vendor"] )
	addTradeSkill( L["Figurine - Black Pearl Panther"], 215, L["Vendor"] )
	addTradeSkill( L["Ruby Crown of Restoration"], 225, L["Vendor"] )
	addTradeSkill( L["Figurine - Truesilver Crab"], 225, L["Vendor"] )
	addTradeSkill( L["Opal Necklace of Impact"], 250, L["Vendor"] )
	addTradeSkill( L["Emerald Crown of Destruction"], 275, L["Vendor"] )
	addTradeSkill( L["Ring of Bitter Shadows"], 285, L["Vendor"] )
	addTradeSkill( L["Teardrop Blood Garnet"], 300, L["Vendor"] )
	addTradeSkill( L["Inscribed Flame Spessarite"], 300, L["Vendor"] )
	addTradeSkill( L["Radiant Deep Peridot"], 300, L["Vendor"] )
	addTradeSkill( L["Glowing Shadow Draenite"], 300, L["Vendor"] )
	addTradeSkill( L["Brilliant Golden Draenite"], 300, L["Vendor"] )
	addTradeSkill( L["Solid Azure Moonstone"], 300, L["Vendor"] )
	addTradeSkill( L["Necklace of the Diamond Tower"], 305, L["Vendor"] )
	addTradeSkill( L["Bold Blood Garnet"], 305, L["Vendor"] )
	addTradeSkill( L["Jagged Deep Peridot"], 305, L["Vendor"] )
	addTradeSkill( L["Sparkling Azure Moonstone"], 305, L["Vendor"] )
	addTradeSkill( L["Bright Blood Garnet"], 305, L["Vendor"] )
	addTradeSkill( L["Glinting Flame Spessarite"], 315, L["Vendor"] )
	addTradeSkill( L["Sovereign Shadow Draenite"], 325, L["Vendor"] )
	addTradeSkill( L["Rigid Golden Draenite"], 325, L["Vendor"] )
	addTradeSkill( L["Smooth Golden Draenite"], 325, L["Vendor"] )
	addTradeSkill( L["Mystic Dawnstone"], 350, L["Vendor"], L["PVP"] )
	addTradeSkill( L["Steady Talasite"], 350, L["Vendor"], L["PVP"] )
	
	-- World Drops
	addTradeSkill( L["Citrine Pendant of Golden Healing"], 190, L["UWD"] )
	addTradeSkill( L["Jade Pendant of Blasting"], 160, L["UWD"] )
	addTradeSkill( L["Figurine - Golden Hare"], 200, L["UWD"] )
	addTradeSkill( L["Figurine - Truesilver Boar"], 230, L["UWD"] )
	addTradeSkill( L["The Aquamarine Ward"], 245, L["UWD"] )
	addTradeSkill( L["Gem Studded Band"], 250, L["UWD"] )
	addTradeSkill( L["Figurine - Ruby Serpent"], 260, L["UWD"] )
	addTradeSkill( L["Figurine - Emerald Owl"], 285, L["UWD"] )
	addTradeSkill( L["Figurine - Black Diamond Crab"], 300, L["UWD"] )
	addTradeSkill( L["Stormy Azure Moonstone"], 315, L["UWD"] )
	addTradeSkill( L["Heavy Felsteel Ring"], 345, L["UWD"] )
	addTradeSkill( L["Bright Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Brilliant Dawnstone"], 350, L["UWD"] )
	addTradeSkill( L["Dazzling Talasite"], 350, L["UWD"] )
	addTradeSkill( L["Delicate Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Enduring Talasite"], 350, L["UWD"] )
	addTradeSkill( L["Inscribed Noble Topaz"], 350, L["UWD"] )
	addTradeSkill( L["Flashing Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Gleaming Dawnstone"], 350, L["UWD"] )
	addTradeSkill( L["Glinting Noble Topaz"], 350, L["UWD"] )
	addTradeSkill( L["Glowing Nightseye"], 350, L["UWD"] )
	addTradeSkill( L["Jagged Talasite"], 350, L["UWD"] )
	addTradeSkill( L["Luminous Noble Topaz"], 350, L["UWD"] )
	addTradeSkill( L["Lustrous Star of Elune"], 350, L["UWD"] )
	addTradeSkill( L["Potent Noble Topaz"], 350, L["UWD"] )
	addTradeSkill( L["Radiant Talasite"], 350, L["UWD"] )
	addTradeSkill( L["Rigid Dawnstone"], 350, L["UWD"] )
	addTradeSkill( L["Royal Nightseye"], 350, L["UWD"] )
	addTradeSkill( L["Runed Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Shifting Nightseye"], 350, L["UWD"] )
	addTradeSkill( L["Smooth Dawnstone"], 350, L["UWD"] )
	addTradeSkill( L["Sovereign Nightseye"], 350, L["UWD"] )
	addTradeSkill( L["Solid Star of Elune"], 350, L["UWD"] )
	addTradeSkill( L["Sparkling Star of Elune"], 350, L["UWD"] )
	addTradeSkill( L["Stormy Star of Elune"], 350, L["UWD"] )
	addTradeSkill( L["Subtle Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Teardrop Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Thick Dawnstone"], 350, L["UWD"] )
	addTradeSkill( L["Bold Living Ruby"], 350, L["UWD"] )
	addTradeSkill( L["Delicate Eternium Ring"], 355, L["UWD"] )
	addTradeSkill( L["Thick Felsteel Necklace"], 355, L["UWD"] )
	addTradeSkill( L["Living Ruby Pendant"], 355, L["UWD"] )
	addTradeSkill( L["Braided Eternium Chain"], 360, L["UWD"] )
	addTradeSkill( L["Eye of the Night"], 360,  L["UWD"] )
	addTradeSkill( L["Blazing Eternium Band"], 365, L["UWD"] )
	addTradeSkill( L["Embrace of the Dawn"], 365, L["UWD"] )
	addTradeSkill( L["Chain of the Twilight Owl"], 365, L["UWD"] )
	addTradeSkill( L["Brutal Earthstorm Diamond"], 365, L["UWD"] )
	addTradeSkill( L["Tenacious Earthstorm Diamond"], 365, L["UWD"] )
	addTradeSkill( L["Destructive Skyfire Diamond"], 365, L["UWD"] )
	addTradeSkill( L["Mystical Skyfire Diamond"], 365, L["UWD"] )
	addTradeSkill( L["Balanced Nightseye"], 350, L["RWD"] )
	addTradeSkill( L["Great Dawnstone"], 350, L["RWD"] )
	addTradeSkill( L["Infused Nightseye"], 350, L["RWD"] )
	addTradeSkill( L["Thundering Skyfire Diamond"], 365, L["RWD"] )
	addTradeSkill( L["Veiled Noble Topaz"], 350, L["RWD"] )
	addTradeSkill( L["Wicked Noble Topaz"], 350, L["RWD"] )

	-- Specific Drops
	addTradeSkill( L["Khorium Band of Shadows"], 350, L["Khorium Band of Shadows Obt"] )
	addTradeSkill( L["Khorium Band of Frost"], 355, L["Khorium Band of Frost Obt"] )
	addTradeSkill( L["Khorium Inferno Band"], 355, L["Khorium Inferno Band Obt"] )
	addTradeSkill( L["Khorium Band of Leaves"], 360, L["Khorium Band of Leaves Obt"] )
	addTradeSkill( L["Arcane Khorium Band"], 365, L["Arcane Khorium Band Obt"] )
	addTradeSkill( L["Infused Shadow Draenite"], 325, L["Infused Shadow Draenite Obt"] )
	addTradeSkill( L["Figurine - Dark Iron Scorpid"], 300, L["Dark Iron Scorpid Obt"] )
	addTradeSkill( L["Coronet of the Verdant Flame"], 370, L["Coronet of the Verdant Flame Obt"] )
	addTradeSkill( L["Circlet of Arcane Might"], 370, L["Circlet of Arcane Might Obt"] )
	--addTradeSkill( L["Chaotic Skyfire Diamond"], 365, L["Chaotic Skyfire Diamond Obt"] )

	-- Reputations
	addTradeSkill( L["Kailee's Rose"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )	
	addTradeSkill( L["Blood of Amber"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Figurine - Talasite Owl"], 370, ARL_AddReputation1( BFAC["Revered"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Ring of Arcane Shielding"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Insightful Earthstorm Diamond"], 365, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )

	addTradeSkill( L["Enigmatic Skyfire Diamond"], 365, ARL_AddReputation1( BFAC["Honored"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Pendant of Frozen Flame"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Figurine - Living Ruby Serpent"], 370, ARL_AddReputation1( BFAC["Revered"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Stone of Blades"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Facet of Eternity"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )

	addTradeSkill( L["Falling Star"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["Lower City"] ), BFAC["Lower City"] )
	addTradeSkill( L["Figurine - Felsteel Boar"], 370, ARL_AddReputation1( BFAC["Revered"], BFAC["Lower City"] ), BFAC["Lower City"] )
	addTradeSkill( L["Pendant of Thawing"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["Lower City"] ), BFAC["Lower City"] )
	addTradeSkill( L["Potent Flame Spessarite"], 325, ARL_AddReputation1( BFAC["Honored"], BFAC["Lower City"] ), BFAC["Lower City"] )

	addTradeSkill( L["Pendant of Withering"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Runed Blood Garnet"], 315, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Dazzling Deep Peridot"], 325, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	
	addTradeSkill( L["Pendant of Shadow's End"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Royal Shadow Draenite"], 305, ARL_AddReputation1( BFAC["Honored"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Gleaming Golden Draenite"], 305, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Aldor"] ), BFAC["The Aldor"] )

	addTradeSkill( L["Enduring Deep Peridot"], 315, ARL_AddReputation2( BFAC["Friendly"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Figurine - Dawnstone Crab"], 370, ARL_AddReputation2( BFAC["Revered"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
		
	addTradeSkill( L["The Frozen Eye"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Violet Eye"] ), L["Raid"] )
	
	addTradeSkill( L["Figurine - Nightseye Panther"], 370, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["The Natural Ward"], 375, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )

	addTradeSkill( L["Thick Golden Draenite"], 315, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Delicate Blood Garnet"], 325, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Shifting Shadow Draenite"], 325, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Lustrous Azure Moonstone"], 325, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Pendant of the Null Rune"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Bracing Earthstorm Diamond"], 365, ARL_AddReputation1( BFAC["Revered"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Powerful Earthstorm Diamond"], 365, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Swift Skyfire Diamond"], 365, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Crimson Sun"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Don Julio's Heart"], 360, ARL_AddReputation1( BFAC["Revered"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Luminous Flame Spessarite"], 305, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Relentless Earthstorm Diamond"], 365, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	
	addTradeSkill( L["Dazzling Seaspray Emerald"], ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Balanced Shadowsong Amethyst"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Delicate Crimson Spinel"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Bold Crimson Spinel"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Bright Crimson Spinel"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Brilliant Lionseye"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )	
	addTradeSkill( L["Enduring Seaspray Emerald"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scale of the Sands"] ), L["Raid"] )	
	addTradeSkill( L["Gleaming Lionseye"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Glinting Pyrestone"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Glowing Shadowsong Amethyst"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Infused Shadowsong Amethyst"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Jagged Seaspray Emerald"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )	
	addTradeSkill( L["Luminous Pyrestone"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Lustrous Empyrean Sapphire"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Potent Pyrestone"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Radiant Seaspray Emerald"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Royal Shadowsong Amethyst"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Smooth Lionseye"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Solid Empyrean Sapphire"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Sparkling Empyrean Sapphire"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Subtle Crimson Spinel"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Teardrop Crimson Spinel"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Thick Lionseye"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Scale of the Sands"] ), L["Raid"] )
	addTradeSkill( L["Wicked Pyrestone"], 375, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scale of the Sands"] ), L["Raid"] )

	-- Raid Drops
	addTradeSkill( L["Inscribed Pyrestone"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Mystic Lionseye"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Great Lionseye"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Sovereign Shadowsong Amethyst"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Stormy Empyrean Sapphire"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Flashing Crimson Spinel"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Veiled Pyrestone"], 375, L["HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Shifting Shadowsong Amethyst"], 375, L["HYJALBoP"], L["Raid"] )

end

-- Initializes the array adding all LeatherWorking recipes.  As of 2.2 there are 360 recipes.

local function ARL_InitLeatherWorking()

	ARL_InitializeRecipeArray()

	-- Original Game Recipes
	addTradeSkill( L["Handstitched Leather Boots"], 1, L["Trainer"] )
	addTradeSkill( L["Light Armor Kit"], 1, L["Trainer"] )
	addTradeSkill( L["Light Leather"], 1, L["Trainer"] )
	addTradeSkill( L["Handstitched Leather Vest"], 1, L["Trainer"] )
	addTradeSkill( L["Handstitched Leather Cloak"], 1, L["Trainer"] )
	addTradeSkill( L["Handstitched Leather Bracers"], 1, L["Trainer"] )
	addTradeSkill( L["Handstitched Leather Pants"], 15, L["Trainer"] )
	addTradeSkill( L["Handstitched Leather Belt"], 25, L["Trainer"] )
	addTradeSkill( L["Light Leather Quiver"], 30, L["Trainer"] )
	addTradeSkill( L["Small Leather Ammo Pouch"], 30, L["Trainer"] )
	addTradeSkill( L["Cured Light Hide"], 35, L["Trainer"] )
	addTradeSkill( L["Rugged Leather Pants"], 35, L["UWD"] )
	addTradeSkill( L["Kodo Hide Bag"], 40, L["Kodo Hide Bag Obt"], BFAC["Horde"] )
	addTradeSkill( L["Embossed Leather Vest"], 40, L["Trainer"] )
	addTradeSkill( L["Embossed Leather Gloves"], 55, L["Trainer"] )
	addTradeSkill( L["Embossed Leather Boots"], 55, L["Trainer"] )
	addTradeSkill( L["Embossed Leather Cloak"], 60, L["Trainer"] )
	addTradeSkill( L["White Leather Jerkin"], 60, L["UWD"] )
	addTradeSkill( L["Embossed Leather Pants"], 75, L["Trainer"] )
	addTradeSkill( L["Fine Leather Gloves"], 75, L["UWD"] )
	addTradeSkill( L["Fine Leather Belt"], 80, L["Trainer"] )
	addTradeSkill( L["Fine Leather Cloak"], 85, L["Trainer"] )
	addTradeSkill( L["Fine Leather Tunic"], 85, L["Trainer"] )
	addTradeSkill( L["Murloc Scale Belt"], 90, L["Vendor"] )
	addTradeSkill( L["Deviate Scale Cloak"], 90, L["Vendor"] )
	addTradeSkill( L["Moonglow Vest"], 90, L["Moonglow Vest Obt"], BFAC["Alliance"] )
	addTradeSkill( L["Fine Leather Boots"], 90, L["UWD"] )
	addTradeSkill( L["Light Leather Bracers"], 70, L["Trainer"] )
	addTradeSkill( L["Murloc Scale Breastplate"], 95, L["Vendor"] )
	addTradeSkill( L["Light Leather Pants"], 95, L["Trainer"] )
	addTradeSkill( L["Hillman's Leather Vest"], 100, L["UWD"] )
	addTradeSkill( L["Cured Medium Hide"], 100, L["Trainer"] )
	addTradeSkill( L["Black Whelp Cloak"], 100, L["Vendor"] )
	addTradeSkill( L["Medium Leather"], 100, L["Trainer"] )
	addTradeSkill( L["Black Whelp Tunic"], 100, L["Vendor"] )
	addTradeSkill( L["Medium Armor Kit"], 100, L["Trainer"] )
	addTradeSkill( L["Dark Leather Boots"], 100, L["Trainer"] )
	addTradeSkill( L["Dark Leather Tunic"], 100, L["UWD"] )
	addTradeSkill( L["Fine Leather Pants"], 105, L["UWD"] )
	addTradeSkill( L["Deviate Scale Gloves"], 105, L["Vendor"] )
	addTradeSkill( L["Dark Leather Cloak"], 110, L["Trainer"] )
	addTradeSkill( L["Dark Leather Pants"], 115, L["Trainer"] )
	addTradeSkill( L["Deviate Scale Belt"], 115, L["Deviate Scale Belt Obt"] )
	addTradeSkill( L["Dark Leather Gloves"], 120, L["UWD"] )
	addTradeSkill( L["Hillman's Belt"], 120, L["UWD"] )
	addTradeSkill( L["Red Whelp Gloves"], 120, L["Vendor"])
	addTradeSkill( L["Nimble Leather Gloves"], 120, L["Trainer"] )
	addTradeSkill( L["Toughened Leather Armor"], 120, L["Trainer"] )
	addTradeSkill( L["Dark Leather Belt"], 125, L["Trainer"] )
	addTradeSkill( L["Fletcher's Gloves"], 125, L["Trainer"] )
	addTradeSkill( L["Hillman's Shoulders"], 130, L["Trainer"] )
	addTradeSkill( L["Toughened Leather Gloves"], 135, L["Trainer"] )
	addTradeSkill( L["Herbalist's Gloves"], 135, L["Vendor"] )
	addTradeSkill( L["Earthen Leather Shoulders"], 135, L["Vendor"] )
	addTradeSkill( L["Dark Leather Shoulders"], 140, L["UWD"] )
	addTradeSkill( L["Pilferer's Gloves"], 140, L["UWD"] )
	addTradeSkill( L["Hillman's Leather Gloves"], 145, L["Trainer"] )
	addTradeSkill( L["Heavy Earthen Gloves"], 145, L["UWD"] )
	addTradeSkill( L["Hillman's Cloak"], 150, L["Trainer"] )
	addTradeSkill( L["Barbaric Gloves"], 150, L["UWD"] )
	addTradeSkill( L["Cured Heavy Hide"], 150, L["Trainer"] )
	addTradeSkill( L["Heavy Armor Kit"], 150, L["Trainer"] )
	addTradeSkill( L["Heavy Quiver"], 150, L["Trainer"] )
	addTradeSkill( L["Heavy Leather Ammo Pouch"], 150, L["Trainer"] )
	addTradeSkill( L["Heavy Leather"], 150, L["Trainer"] )
	addTradeSkill( L["Heavy Leather Ball"], 150, L["Vendor"] )
	addTradeSkill( L["Green Leather Armor"], 155, L["Vendor"] )
	addTradeSkill( L["Barbaric Bracers"], 155, L["Vendor"] )
	addTradeSkill( L["Green Leather Belt"], 160, L["Trainer"] )
	addTradeSkill( L["Guardian Pants"], 160, L["Trainer"] )
	addTradeSkill( L["Raptor Hide Belt"], 165, L["Vendor"] )
	addTradeSkill( L["Raptor Hide Harness"], 165, L["Vendor"], BFAC["Horde"] )
	addTradeSkill( L["Dusky Leather Leggings"], 165, L["UWD"] )
	addTradeSkill( L["Guardian Belt"], 170, L["RWD"] )
	addTradeSkill( L["Thick Murloc Armor"], 170, L["Vendor"] )
	addTradeSkill( L["Barbaric Leggings"], 170, L["Vendor"] )
	addTradeSkill( L["Guardian Armor"], 175, L["UWD"] )
	addTradeSkill( L["Barbaric Shoulders"], 175, L["Trainer"] )
	addTradeSkill( L["Dusky Leather Armor"], 175, L["Trainer"] )
	addTradeSkill( L["Green Whelp Armor"], 175, L["UWD"] )
	addTradeSkill( L["Green Leather Bracers"], 180, L["Trainer"] )
	addTradeSkill( L["Frost Leather Cloak"], 180, L["Trainer"] )
	addTradeSkill( L["Gem-studded Leather Belt"], 185, L["Vendor"] )
	addTradeSkill( L["Guardian Cloak"], 185, L["UWD"] )
	addTradeSkill( L["Dusky Bracers"], 185, L["Trainer"] )
	addTradeSkill( L["Barbaric Harness"], 190, L["Trainer"] )
	addTradeSkill( L["Murloc Scale Bracers"], 190, L["Vendor"] )
	addTradeSkill( L["Guardian Gloves"], 190, L["Trainer"] )
	addTradeSkill( L["Green Whelp Bracers"], 190, L["Vendor"] )
	addTradeSkill( L["Gloves of the Greatfather"], 190, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Guardian Leather Bracers"], 195, L["UWD"] )
	addTradeSkill( L["Dusky Belt"], 195, L["Trainer"] )
	addTradeSkill( L["Barbaric Belt"], 200, L["RWD"] )
	addTradeSkill( L["Dusky Boots"], 200, L["UWD"] )
	addTradeSkill( L["Swift Boots"], 200, L["UWD"] )
	addTradeSkill( L["Cured Thick Hide"], 200, L["Trainer"] )
	addTradeSkill( L["Thick Armor Kit"], 200, L["Trainer"] )
	addTradeSkill( L["Comfortable Leather Hat"], 200, L["UWD"] )
	addTradeSkill( L["Thick Leather"], 200, L["Trainer"] )
	addTradeSkill( L["Shadowskin Gloves"], 200, L["Vendor"] )
	addTradeSkill( L["Nightscape Tunic"], 205, L["Trainer"] )
	addTradeSkill( L["Nightscape Headband"], 205, L["Trainer"] )
	addTradeSkill( L["Turtle Scale Gloves"], 205, L["Vendor"] )
	addTradeSkill( L["Turtle Scale Breastplate"], 210, L["Trainer"] )
	addTradeSkill( L["Nightscape Shoulders"], 210, L["Vendor"] )
	addTradeSkill( L["Turtle Scale Bracers"], 210, L["Trainer"] )
	addTradeSkill( L["Big Voodoo Robe"], 215, L["UWD"] )
	addTradeSkill( L["Tough Scorpid Breastplate"], 220, L["Tough Scorpid Breastplate Obt"] )
	addTradeSkill( L["Wild Leather Shoulders"], 220, L["Wild Leather Shoulders Obt"] )
	addTradeSkill( L["Big Voodoo Mask"], 220, L["UWD"] )
	addTradeSkill( L["Tough Scorpid Bracers"], 220, L["Tough Scorpid Bracers Obt"] )
	addTradeSkill( L["Tough Scorpid Gloves"], 225, L["Tough Scorpid Gloves Obt"] )
	addTradeSkill( L["Wild Leather Vest"], 225, L["Wild Leather Vest Obt"] )
	addTradeSkill( L["Wild Leather Helmet"], 225, L["Wild Leather Helmet Obt"] )
	addTradeSkill( L["Quickdraw Quiver"], 225, L["Trainer"] )
	addTradeSkill( L["Thick Leather Ammo Pouch"], 225, L["Trainer"] )
	addTradeSkill( L["Nightscape Pants"], 230, L["Trainer"] )
	addTradeSkill( L["Turtle Scale Helm"], 230, L["Trainer"] )
	addTradeSkill( L["Tough Scorpid Boots"], 235, L["Tough Scorpid Boots Obt"] )
	addTradeSkill( L["Turtle Scale Leggings"], 235, L["Trainer"] )
	addTradeSkill( L["Nightscape Boots"], 235, L["Trainer"] )
	addTradeSkill( L["Big Voodoo Pants"], 240, L["UWD"] )
	addTradeSkill( L["Big Voodoo Cloak"], 240, L["UWD"] )
	addTradeSkill( L["Tough Scorpid Shoulders"], 240, L["Tough Scorpid Shoulders Obt"] )
	addTradeSkill( L["Wild Leather Boots"], 245, L["Wild Leather Boots Obt"] )
	addTradeSkill( L["Tough Scorpid Leggings"], 245, L["Tough Scorpid Leggings Obt"] )
	addTradeSkill( L["Tough Scorpid Helm"], 250, L["Tough Scorpid Helm Obt"] )
	addTradeSkill( L["Wild Leather Leggings"], 250, L["Wild Leather Leggings Obt"] )
	addTradeSkill( L["Wild Leather Cloak"], 250, L["Wild Leather Cloak Obt"] )
	addTradeSkill( L["Cured Rugged Hide"], 250, L["Trainer"] )
	addTradeSkill( L["Rugged Armor Kit"], 250, L["Trainer"] )
	addTradeSkill( L["Rugged Leather"], 250, L["Trainer"] )
	addTradeSkill( L["Heavy Scorpid Bracers"], 255, L["Vendor"] )
	addTradeSkill( L["Wicked Leather Gauntlets"], 260, L["Vendor"])  
	addTradeSkill( L["Heavy Scorpid Vest"], 265, L["Heavy Scorpid Vest Obt"] )
	addTradeSkill( L["Wicked Leather Bracers"], 265, L["Wicked Leather Bracers Obt"] )
	addTradeSkill( L["Runic Leather Gauntlets"], 270, L["UWD"] )
	addTradeSkill( L["Heavy Scorpid Gauntlets"], 275, L["UWD"] )
	addTradeSkill( L["Runic Leather Bracers"], 275, L["Runic Leather Bracers Obt"] )
	addTradeSkill( L["Heavy Scorpid Belt"], 280, L["UWD"] )
	addTradeSkill( L["Wicked Leather Headband"], 280, L["Wicked Leather Headband Obt"] )
	addTradeSkill( L["Runic Leather Belt"], 280, L["UWD"] )
	addTradeSkill( L["Heavy Scorpid Leggings"], 285, L["Heavy Scorpid Leggings Obt"] )
	addTradeSkill( L["Runic Leather Headband"], 290, L["Vendor"] )
	addTradeSkill( L["Wicked Leather Pants"], 290, L["UWD"] )
	addTradeSkill( L["Might of the Timbermaw"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Dawn Treaders"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Heavy Scorpid Helm"], 295, L["Vendor"] )
	addTradeSkill( L["Runic Leather Pants"], 300, L["UWD"] )
	addTradeSkill( L["Wicked Leather Belt"], 300, L["Wicked Leather Belt Obt"] )
	addTradeSkill( L["Heavy Scorpid Shoulders"], 300, L["Heavy Scorpid Shoulders Obt"] )
	addTradeSkill( L["Runic Leather Armor"], 300, L["Runic Leather Armor Obt"] )
	addTradeSkill( L["Wicked Leather Armor"], 300, L["Wicked Leather Armor Obt"] )
	addTradeSkill( L["Runic Leather Shoulders"], 300, L["Runic Leather Shoulders Obt"] )
	addTradeSkill( L["Core Armor Kit"], 300, L["MOLTENCORE"], L["Raid"] )
	addTradeSkill( L["Girdle of Insight"], 300, L["DMCACHE"] )
	addTradeSkill( L["Mongoose Boots"], 300, L["DMCACHE"] )
	addTradeSkill( L["Swift Flight Bracers"], 300, L["DMCACHE"] )
	addTradeSkill( L["Timbermaw Brawlers"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Golden Mantle of the Dawn"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Lava Belt"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Blood Tiger Breastplate"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Blood Tiger Shoulders"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Primal Batskin Bracers"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Primal Batskin Gloves"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Primal Batskin Jerkin"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Spitfire Bracers"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Spitfire Gauntlets"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Spitfire Breastplate"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Sandstalker Bracers"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Sandstalker Gauntlets"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Sandstalker Breastplate"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Onyxia Scale Cloak"], 300, L["Onyxia Scale Cloak Obt"], L["Raid"] )
	addTradeSkill( L["Gordok Ogre Suit"], 300, L["Gordok Ogre Suit Obt"] )
	addTradeSkill( L["Icy Scale Bracers"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icy Scale Breastplate"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icy Scale Gauntlets"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Polar Bracers"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Polar Gloves"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Polar Tunic"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icy Scale Bracers"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icy Scale Gauntlets"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Icy Scale Breastplate"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Bramblewood Belt"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Bramblewood Boots"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Bramblewood Helm"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Green Dragonscale Gauntlets"], 280, L["Trainer"] )
	addTradeSkill( L["Dragonscale Gauntlets"], 225, L["Trainer"] )
	addTradeSkill( L["Dragonscale Breastplate"], 255, L["Trainer"] )
	addTradeSkill( L["Green Dragonscale Breastplate"], 260, L["Vendor"] )
	addTradeSkill( L["Green Dragonscale Leggings"], 270, L["Green Dragonscale Leggings Obt"] )
	addTradeSkill( L["Blue Dragonscale Breastplate"], 285, L["Vendor"] )
	addTradeSkill( L["Black Dragonscale Breastplate"], 290, L["Vendor"] )
	addTradeSkill( L["Blue Dragonscale Shoulders"], 295, L["Blue Dragonscale Shoulders Obt"] )
	addTradeSkill( L["Red Dragonscale Breastplate"], 300, L["Red Dragonscale Breastplate Obt"] )
	addTradeSkill( L["Black Dragonscale Leggings"], 300, L["Black Dragonscale Leggings Obt"] )
	addTradeSkill( L["Black Dragonscale Shoulders"], 300, L["Black Dragonscale Shoulders Obt"] )
	addTradeSkill( L["Black Dragonscale Boots"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Chromatic Cloak"], 300, L["DMCACHE"] )
	addTradeSkill( L["Chromatic Gauntlets"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Blue Dragonscale Leggings"], 300, L["Trainer"] )
	addTradeSkill( L["Dreamscale Breastplate"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Gauntlets of the Sea"], 230, L["Trainer"] )
	addTradeSkill( L["Helm of Fire"], 250, L["Trainer"] )
	addTradeSkill( L["Volcanic Leggings"], 270, L["Volcanic Leggings Obt"] )
	addTradeSkill( L["Living Shoulders"], 270, L["Vendor"] )
	addTradeSkill( L["Stormshroud Pants"], 275, L["Vendor"] )
	addTradeSkill( L["Volcanic Breastplate"], 285, L["Volcanic Breastplate Obt"] )
	addTradeSkill( L["Living Leggings"], 285, L["Living Leggings Obt"] )
	addTradeSkill( L["Stormshroud Armor"], 285, L["Stormshroud Armor Obt"] )
	addTradeSkill( L["Stormshroud Shoulders"], 295, L["Stormshroud Shoulders Obt"] )
	addTradeSkill( L["Stormshroud Gloves"], 300, L["Stormshroud Gloves Obt"] )
	addTradeSkill( L["Living Breastplate"], 300, L["Living Breastplate Obt"] )
	addTradeSkill( L["Volcanic Shoulders"], 300, L["Volcanic Shoulders Obt"] )
	addTradeSkill( L["Molten Helm"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Shifting Cloak"], 300, L["DMCACHE"] )
	addTradeSkill( L["Molten Belt"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Wolfshead Helm"], 225, L["Trainer"] )
	addTradeSkill( L["Feathered Breastplate"], 250, L["Trainer"] )
	addTradeSkill( L["Chimeric Gloves"], 265, L["Vendor"] )
	addTradeSkill( L["Ironfeather Shoulders"], 270, L["Vendor"] )
	addTradeSkill( L["Chimeric Boots"], 275, L["UWD"] )
	addTradeSkill( L["Frostsaber Boots"], 275, L["Vendor"] )
	addTradeSkill( L["Warbear Harness"], 275, ARL_AddReputation1( BFAC["Friendly"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Chimeric Leggings"], 280, L["UWD"] )
	addTradeSkill( L["Frostsaber Leggings"], 285, L["Frostsaber Leggings Obt"] )
	addTradeSkill( L["Warbear Woolies"], 285, ARL_AddReputation1( BFAC["Friendly"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Chimeric Vest"], 290, L["UWD"] )
	addTradeSkill( L["Devilsaur Gauntlets"], 290, L["Vendor"] )
	addTradeSkill( L["Ironfeather Breastplate"], 290, L["Ironfeather Breastplate Obt"] )
	addTradeSkill( L["Frostsaber Gloves"], 295, L["Frostsaber Gloves Obt"] )
	addTradeSkill( L["Corehound Boots"], 295, ARL_AddReputation1( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Devilsaur Leggings"], 300, L["Devilsaur Leggings Obt"] )
	addTradeSkill( L["Frostsaber Tunic"], 300, L["Frostsaber Tunic Obt"] )
	addTradeSkill( L["Hide of the Wild"], 300, L["DMCACHE"] )
	addTradeSkill( L["Corehound Belt"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Thick Draenic Gloves"], 300, L["Trainer"] )
	addTradeSkill( L["Comfortable Insoles"], 300, L["Vendor"] )
	addTradeSkill( L["Felscale Gloves"], 300, L["Trainer"] )
	addTradeSkill( L["Knothide Armor Kit"], 300, L["Trainer"] )
	addTradeSkill( L["Knothide Leather"], 300, L["Trainer"] )
	addTradeSkill( L["Scaled Draenic Pants"], 300, L["Trainer"] )
	addTradeSkill( L["Thick Draenic Pants"], 300, L["Trainer"] )
	addTradeSkill( L["Wild Draenish Boots"], 300, L["Trainer"] )
	addTradeSkill( L["Felscale Boots"], 310, L["Trainer"] )
	addTradeSkill( L["Scaled Draenic Gloves"], 310, L["Trainer"] )
	addTradeSkill( L["Wild Draenish Gloves"], 310, L["Trainer"] )
	addTradeSkill( L["Thick Draenic Pants"], 315, L["Trainer"] )
	addTradeSkill( L["Felscale Pants"], 320, L["Trainer"] )
	addTradeSkill( L["Thick Draenic Boots"], 320, L["Trainer"] )
	addTradeSkill( L["Wild Draenish Leggings"], 320, L["Trainer"] )
	addTradeSkill( L["Heavy Knothide Leather"], 325, L["Vendor"] )
	addTradeSkill( L["Vindicator's Armor Kit"], 325, ARL_AddReputation1( BFAC["Revered"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Magister's Armor Kit"], 325, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Scaled Draenic Vest"], 325, L["Trainer"] )
	addTradeSkill( L["Reinforced Mining Bag"], 325, ARL_AddReputation2( BFAC["Honored"], BFAC["Kurenai"], BFAC["The Mag'har"] ), BFAC["The Mag'har"] )
	addTradeSkill( L["Thick Draenic Vest"], 330, L["Trainer"] )
	addTradeSkill( L["Wild Draenish Vest"], 330, L["Trainer"] )
	addTradeSkill( L["Felscale Breastplate"], 335, L["Trainer"] )
	addTradeSkill( L["Scaled Draenic Boots"], 335, L["Trainer"] )
	addTradeSkill( L["Cobrahide Leg Armor"], 335, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Clefthide Leg Armor"], 335, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Fel Leather Gloves"], 340, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Netherfury Belt"], 340, ARL_AddReputation2( BFAC["Friendly"], BFAC["Kurenai"], BFAC["The Mag'har"] ), BFAC["The Mag'har"] )
	addTradeSkill( L["Netherfury Leggings"], 340, ARL_AddReputation2( BFAC["Honored"], BFAC["Kurenai"], BFAC["The Mag'har"] ), BFAC["The Mag'har"] )
	addTradeSkill( L["Shadow Armor Kit"], 340, L["Shadow Armor Kit Obt"] )
	addTradeSkill( L["Flame Armor Kit"], 340, L["Flame Armor Kit Obt"] )
	addTradeSkill( L["Nature Armor Kit"], 340, L["Nature Armor Kit Obt"] )
	addTradeSkill( L["Arcane Armor Kit"], 340, L["Arcane Armor Kit Obt"] )
	addTradeSkill( L["Frost Armor Kit"], 340, L["Frost Armor Kit Obt"] )
	addTradeSkill( L["Drums of War"], 340, L["Trainer"] )
	addTradeSkill( L["Drums of Speed"], 345, L["UWD"] )
	--addTradeSkill( L["Drums of Speed"], 345, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	--addTradeSkill( L["Knothide Quiver"], 345, L["Unknown"] )
	--addTradeSkill( L["Knothide Ammo Pouch"], 345, L["Unknown"] )
	addTradeSkill( L["Riding Crop"], 350, L["Vendor"] )
	addTradeSkill( L["Stylin' Purple Hat"], 350, L["Stylin' Purple Hat Obt"] )
	addTradeSkill( L["Stylin' Adventure Hat"], 350, L["Stylin' Adventure Hat Obt"] )
	addTradeSkill( L["Stylin' Jungle Hat"], 350, L["Stylin' Jungle Hat Obt"] )
	addTradeSkill( L["Stylin' Crimson Hat"], 350, L["Stylin' Crimson Hat Obt"] )
	addTradeSkill( L["Fel Leather Boots"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Fel Leather Leggings"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Felstalker Belt"], 350, ARL_AddReputation2( BFAC["Friendly"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Netherfury Boots"], 350, ARL_AddReputation2( BFAC["Revered"], BFAC["Kurenai"], BFAC["The Mag'har"] ), BFAC["The Mag'har"] )
	addTradeSkill( L["Enchanted Felscale Boots"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Enchanted Felscale Gloves"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Enchanted Felscale Leggings"], 350, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Flamescale Belt"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Flamescale Boots"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Flamescale Leggings"], 350, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Enchanted Clefthoof Boots"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Enchanted Clefthoof Gloves"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Enchanted Clefthoof Leggings"], 350, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Blastguard Belt"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Blastguard Boots"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Blastguard Pants"], 350, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	--addTradeSkill( L["Heavy Knothide Armor Kit"], 350, L["Trainer"] )
	--addTradeSkill( L["Quiver of a Thousand Feathers"], 350, ARL_AddReputation1( BFAC["Revered"], BFAC["Lower City"] ), BFAC["Lower City"] )
	--addTradeSkill( L["Netherscale Ammo Pouch"], 350, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Drums of Restoration"], 350, L["UWD"] )
	--addTradeSkill( L["Drums of Restoration"], 350, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Heavy Clefthoof Leggings"], 355, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Heavy Clefthoof Boots"], 355, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Heavy Clefthoof Vest"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Felstalker Bracer"], 360, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Felstalker Breastplate"], 360, ARL_AddReputation2( BFAC["Honored"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Drums of Battle"], 365, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Sha'tar"] ), BFAC["The Sha'tar"] )
	addTradeSkill( L["Nethercobra Leg Armor"], 365, ARL_AddReputation2( BFAC["Exalted"], BFAC["Honor Hold"], BFAC["Thrallmar"] ), BFAC["Thrallmar"] )
	addTradeSkill( L["Nethercleft Leg Armor"], 365, ARL_AddReputation1( BFAC["Exalted"], BFAC["Cenarion Expedition"] ), BFAC["Cenarion Expedition"] )
	addTradeSkill( L["Cobrascale Gloves"], 365, L["EWD"] )
	addTradeSkill( L["Cobrascale Hood"], 365, L["EWD"] )
	addTradeSkill( L["Earthen Netherscale Boots"], 365, L["EWD"] )
	addTradeSkill( L["Gloves of the Living Touch"], 365, L["EWD"] )
	addTradeSkill( L["Hood of Primal Life"], 365, L["EWD"] )
	addTradeSkill( L["Living Dragonscale Helm"], 365, L["EWD"] )
	addTradeSkill( L["Netherdrake Gloves"], 365, L["EWD"] )
	addTradeSkill( L["Netherdrake Helm"], 365, L["EWD"] )
	addTradeSkill( L["Thick Netherscale Breastplate"], 365, L["EWD"] )
	addTradeSkill( L["Windslayer Wraps"], 365, L["EWD"] )
	addTradeSkill( L["Windscale Hood"], 365, L["EWD"] )
	addTradeSkill( L["Windstrike Gloves"], 365, L["EWD"] )
	addTradeSkill( L["Drums of Panic"], 370, ARL_AddReputation1( BFAC["Exalted"], BFAC["Keepers of Time"] ), BFAC["Keepers of Time"] )
	addTradeSkill( L["Boots of Shackled Souls"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Bracers of Shackled Souls"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Waistguard of Shackled Souls"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Greaves of Shackled Souls"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Cloak of Darkness"], 375, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Violet Eye"] ), L["Raid"] )
	addTradeSkill( L["Redeemed Soul Cinch"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Redeemed Soul Legguards"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Redeemed Soul Mocassins"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Redeemed Soul Wristguards"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Shadowprowler's Chestguard"], 365, ARL_AddReputation1( BFAC["Revered"], BFAC["The Violet Eye"] ), L["Raid"] )
	addTradeSkill( L["Shoulders of Lightning Reflexes"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Hurricane Boots"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Monsoon Belt"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Belt of Deep Shadow"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Belt of Natural Power"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Belt of the Black Eagle"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Boots of Natural Grace"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Boots of the Crimson Hawk"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Boots of Utter Darkness"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Bracers of Renewed Life"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Shoulderpads of Renewed Life"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Living Earth Shoulders"], 375, L["BT/HYJALBoE"], L["Raid"] )
	addTradeSkill( L["Living Earth Bindings"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Shoulders of Lightning Reflexes"], 375, L["BT/HYJALBoE"], L["Raid"] )
	addTradeSkill( L["Bindings of Lightning Reflexes"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Swiftstrike Bracers"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Swiftstrike Shoulders"], 375, L["BT/HYJALBoE"], L["Raid"] )
	--addTradeSkill( L["Glove Reinforcements"], 375, L["Unknown"] )

	-- Wrath of the Litch King Recipes

	-- Dragonscale Leatherworking
	addTradeSkill( L["Dragonstrike Leggings"], 260, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Golden Dragonstrike Breastplate"], 330, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Ebon Netherscale Belt"], 375, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Ebon Netherscale Bracers"], 375, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Ebon Netherscale Breastplate"], 375, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Netherstrike Belt"], 375, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Netherstrike Bracers"], 375, L["Trainer"], BTS["Dragonscale Leatherworking"] )
	addTradeSkill( L["Netherstrike Breastplate"], 375, L["Trainer"], BTS["Dragonscale Leatherworking"] )

	-- Elemental Leatherworking
	addTradeSkill( L["Blackstorm Leggings"], 260, L["Trainer"], BTS["Elemental Leatherworking"] )
	addTradeSkill( L["Primalstorm Breastplate"], 330, L["Trainer"], BTS["Elemental Leatherworking"] )
	addTradeSkill( L["Primalstrike Belt"], 375, L["Trainer"], BTS["Elemental Leatherworking"] )
	addTradeSkill( L["Primalstrike Bracers"], 375, L["Trainer"], BTS["Elemental Leatherworking"] )
	addTradeSkill( L["Primalstrike Vest"], 375, L["Trainer"], BTS["Elemental Leatherworking"] )

	-- Tribal Leatherworking
	addTradeSkill( L["Wildfeather Leggings"], 260, L["Trainer"], BTS["Tribal Leatherworking"] )
	addTradeSkill( L["Living Crystal Breastplate"], 330, L["Trainer"], BTS["Tribal Leatherworking"] )
	addTradeSkill( L["Windhawk Belt"], 375, L["Trainer"], BTS["Tribal Leatherworking"] )
	addTradeSkill( L["Windhawk Bracers"], 375, L["Trainer"], BTS["Tribal Leatherworking"] )
	addTradeSkill( L["Windhawk Hauberk"], 375, L["Trainer"], BTS["Tribal Leatherworking"] )

end

-- Initializes the array adding all Rogue Poisons.  As of 2.2 there are 26 recipes.

local function ARL_InitRoguePoison()

	ARL_InitializeRecipeArray()

	addTradeSkill( L["Anesthetic Poison"], 68, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Crippling Poison"], 20, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Crippling Poison II"], 50, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Mind-numbing Poison"], 24, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Mind-numbing Poison II"], 38, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Mind-numbing Poison III"], 52, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison"], 20, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison II"], 28, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison III"], 36, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison IV"], 44, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison V"], 52, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison VI"], 60, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Instant Poison VII"], 68, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison"], 30, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison II"], 38, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison III"], 46, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison IV"], 54, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison V"], 60, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison VI"], 62, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Deadly Poison VII"], 68, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Wound Poison"], 32, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Wound Poison II"], 40, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Wound Poison III"], 48, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Wound Poison IV"], 56, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Wound Poison V"], 64, L["Trainer"], BCLASS["Rogue"] )
	addTradeSkill( L["Blinding Powder"], 34, L["Trainer"], BCLASS["Rogue"] )
	
end

-- Initializes the array adding all Tailoring recipes.  As of 2.2 there are 305 recipes.

local function ARL_InitTailoring()

	ARL_InitializeRecipeArray()

	-- Original Game Recipes
	addTradeSkill( L["Bolt of Linen Cloth"], 1, L["Trainer"] )
	addTradeSkill( L["Linen Cloak"], 1, L["Trainer"] )
	addTradeSkill( L["White Linen Shirt"], 1, L["Trainer"] )
	addTradeSkill( L["Brown Linen Shirt"], 1, L["Trainer"] )
	addTradeSkill( L["Simple Linen Pants"], 1, L["Trainer"] )
	addTradeSkill( L["Brown Linen Vest"], 10, L["Trainer"] )
	addTradeSkill( L["Linen Belt"], 15, L["Trainer"] )
	addTradeSkill( L["Simple Linen Boots"], 20, L["Trainer"] )
	addTradeSkill( L["Brown Linen Pants"], 30, L["Trainer"] )
	addTradeSkill( L["Brown Linen Robe"], 30, L["Trainer"] )
	addTradeSkill( L["White Linen Robe"], 30, L["Trainer"] )
	addTradeSkill( L["Heavy Linen Gloves"], 35, L["Trainer"] )
	addTradeSkill( L["Red Linen Robe"], 40, L["UWD"] )
	addTradeSkill( L["Red Linen Shirt"], 40, L["Trainer"] )
	addTradeSkill( L["Blue Linen Shirt"], 40, L["Trainer"] )
	addTradeSkill( L["Simple Dress"], 40, L["Trainer"] )
	addTradeSkill( L["Linen Bag"], 45, L["Trainer"] )
	addTradeSkill( L["Blue Linen Vest"], 55, L["Vendor"] )
	addTradeSkill( L["Red Linen Vest"], 55, L["UWD"] )
	addTradeSkill( L["Reinforced Linen Cape"], 60, L["Trainer"] )
	addTradeSkill( L["Green Linen Bracers"], 60, L["Trainer"] )
	addTradeSkill( L["Linen Boots"], 65, L["Trainer"])
	addTradeSkill( L["Red Linen Bag"], 70, L["Vendor"] )
	addTradeSkill( L["Blue Linen Robe"], 70, L["Vendor"] )
	addTradeSkill( L["Bolt of Woolen Cloth"], 75, L["Trainer"] )
	addTradeSkill( L["Woolen Cape"], 75, L["Trainer"] )
	addTradeSkill( L["Simple Kilt"], 75, L["Trainer"] )
	addTradeSkill( L["Soft-soled Linen Boots"], 80, L["Trainer"] )
	addTradeSkill( L["Woolen Bag"], 80, L["Trainer"] )
	addTradeSkill( L["Green Woolen Vest"], 85, L["Trainer"] )
	addTradeSkill( L["Heavy Woolen Gloves"], 85, L["Trainer"] )
	addTradeSkill( L["Pearl-clasped Cloak"], 90, L["Trainer"] )
	addTradeSkill( L["Barbaric Linen Vest"], 90, L["Trainer"] )
	addTradeSkill( L["Green Linen Shirt"], 90, L["Trainer"] )
	addTradeSkill( L["Handstitched Linen Britches"], 90, L["Trainer"] )
	addTradeSkill( L["Woolen Boots"], 95, L["Trainer"] )
	addTradeSkill( L["Red Woolen Boots"], 95, L["UWD"] )
	addTradeSkill( L["Green Woolen Bag"], 95, L["UWD"] )
	addTradeSkill( L["Gray Woolen Shirt"], 100, L["Trainer"] )
	addTradeSkill( L["Heavy Woolen Cloak"], 100, L["UWD"] )
	addTradeSkill( L["Blue Overalls"], 100, L["Vendor"] )
	addTradeSkill( L["Gray Woolen Robe"], 105, L["UWD"] )
	addTradeSkill( L["Double-stitched Woolen Shoulders"], 110, L["Trainer"] )
	addTradeSkill( L["Heavy Woolen Pants"], 110, L["Trainer"] )
	addTradeSkill( L["White Woolen Dress"], 110, L["Trainer"] )
	addTradeSkill( L["Red Woolen Bag"], 115, L["Vendor"] )
	addTradeSkill( L["Greater Adept's Robe"], 115, L["Vendor"], BFAC["Alliance"] )
	addTradeSkill( L["Reinforced Woolen Shoulders"], 120, L["UWD"] )
	addTradeSkill( L["Stylish Blue Shirt"], 120, L["UWD"] )
	addTradeSkill( L["Stylish Green Shirt"], 120, L["UWD"] )
	addTradeSkill( L["Colorful Kilt"], 120, L["UWD"] )
	addTradeSkill( L["Bolt of Silk Cloth"], 125, L["Trainer"] )
	addTradeSkill( L["Phoenix Pants"], 125, L["UWD"] )
	addTradeSkill( L["Spidersilk Boots"], 125, L["Trainer"] )
	addTradeSkill( L["Stylish Red Shirt"], 125, L["Trainer"] )
	addTradeSkill( L["Phoenix Gloves"], 125, L["UWD"] )
	addTradeSkill( L["Gloves of Meditation"], 130, L["Trainer"] )
	addTradeSkill( L["Bright Yellow Shirt"], 135, L["Vendor"] )
	addTradeSkill( L["Lesser Wizard's Robe"], 135, L["Trainer"] )
	addTradeSkill( L["Spider Silk Slippers"], 140, L["UWD"] )
	addTradeSkill( L["Azure Silk Pants"], 140, L["Trainer"] )
	addTradeSkill( L["Azure Silk Gloves"], 145, L["Vendor"] )
	addTradeSkill( L["Azure Silk Hood"], 145, L["Trainer"] )
	addTradeSkill( L["Hands of Darkness"], 145, L["UWD"] )
	addTradeSkill( L["Azure Silk Vest"], 150, L["Trainer"] )
	addTradeSkill( L["Small Silk Pack"], 150, L["Trainer"] )
	addTradeSkill( L["Robes of Arcana"], 150, L["Robes of Arcana Obt"] )
	addTradeSkill( L["Truefaith Gloves"], 150, L["UWD"] )
	addTradeSkill( L["Dark Silk Shirt"], 155, L["Vendor"] )
	addTradeSkill( L["White Swashbuckler's Shirt"], 160, L["Trainer"] )
	addTradeSkill( L["Silk Headband"], 160, L["Trainer"] )
	addTradeSkill( L["Enchanter's Cowl"], 165, L["Vendor"] )
	addTradeSkill( L["Green Silk Armor"], 165, L["UWD"] )
	addTradeSkill( L["Shadow Hood"], 170, L["UWD"] )
	addTradeSkill( L["Formal White Shirt"], 170, L["Trainer"] )
	addTradeSkill( L["Earthen Vest"], 170, L["Trainer"] )
	addTradeSkill( L["Bolt of Mageweave"], 175, L["Trainer"] )
	addTradeSkill( L["Boots of the Enchanter"], 175, L["UWD"] )
	addTradeSkill( L["Green Silk Pack"], 175, L["UWD"] )
	addTradeSkill( L["Red Swashbuckler's Shirt"], 175, L["Trainer"] )
	addTradeSkill( L["Azure Silk Belt"], 175, L["Trainer"] )
	addTradeSkill( L["Crimson Silk Belt"], 175, L["Trainer"] )
	addTradeSkill( L["Azure Silk Cloak"], 175, L["Vendor"] )
	addTradeSkill( L["Spider Belt"], 180, L["UWD"] )
	addTradeSkill( L["Green Silken Shoulders"], 180, L["Trainer"] )
	addTradeSkill( L["Crimson Silk Cloak"], 180, L["Vendor"] )
	addTradeSkill( L["Long Silken Cloak"], 185, L["Trainer"] )
	addTradeSkill( L["Rich Purple Silk Shirt"], 185, L["UWD"] )
	addTradeSkill( L["Black Silk Pack"], 185, L["Black Silk Pack Obt"] )
	addTradeSkill( L["Crimson Silk Vest"], 185, L["Trainer"] )
	addTradeSkill( L["Robe of Power"], 190, L["Trainer"] )
	addTradeSkill( L["Crimson Silk Shoulders"], 190, L["UWD"] )
	addTradeSkill( L["Azure Shoulders"], 190, L["UWD"] )
	addTradeSkill( L["Green Holiday Shirt"], 190, L["WintersVeil"], L["Seasonal"] )
	addTradeSkill( L["Earthen Silk Belt"], 195, L["UWD"] )
	addTradeSkill( L["Crimson Silk Pantaloons"], 195, L["Trainer"] )
	addTradeSkill( L["Icy Cloak"], 200, L["Vendor"] )
	addTradeSkill( L["Star Belt"], 200, L["UWD"] )
	addTradeSkill( L["Black Swashbuckler's Shirt"], 200, L["Vendor"] )
	addTradeSkill( L["Crimson Silk Robe"], 205, L["Vendor"] )
	addTradeSkill( L["Black Mageweave Vest"], 205, L["Trainer"] )
	addTradeSkill( L["Black Mageweave Leggings"], 205, L["Trainer"] )
	addTradeSkill( L["Crimson Silk Gloves"], 210, L["Trainer"] )
	addTradeSkill( L["Black Mageweave Robe"], 210, L["Trainer"] )
	addTradeSkill( L["Shadoweave Pants"], 210, L["Trainer"] )
	addTradeSkill( L["Black Mageweave Gloves"], 215, L["Trainer"] )
	addTradeSkill( L["Shadoweave Robe"], 215, L["Trainer"] )
	addTradeSkill( L["Red Mageweave Vest"], 215, L["UWD"] )
	addTradeSkill( L["White Bandit Mask"], 215, L["UWD"] )
	addTradeSkill( L["Red Mageweave Pants"], 215, L["UWD"] )
	addTradeSkill( L["Orange Mageweave Shirt"], 215, L["Trainer"] )
	addTradeSkill( L["Orange Martial Shirt"], 220, L["Vendor"] )
	addTradeSkill( L["Mageweave Bag"], 225, L["Trainer"] )
	addTradeSkill( L["Red Mageweave Gloves"], 225, L["UWD"] )
	addTradeSkill( L["Dreamweave Gloves"], 225, L["Trainer"] )
	addTradeSkill( L["Cindercloth Robe"], 225, L["Trainer"] )
	addTradeSkill( L["Dreamweave Vest"], 225, L["Trainer"] )
	addTradeSkill( L["Shadoweave Gloves"], 225, L["Trainer"] )
	addTradeSkill( L["Enchanted Mageweave Pouch"], 225, L["Vendor"] )
	addTradeSkill( L["Black Mageweave Headband"], 230, L["Trainer"] )
	addTradeSkill( L["Black Mageweave Boots"], 230, L["Trainer"] )
	addTradeSkill( L["Black Mageweave Shoulders"], 230, L["Trainer"] )
	addTradeSkill( L["Lavender Mageweave Shirt"], 230, L["Vendor"] )
	addTradeSkill( L["Shadoweave Shoulders"], 235, L["Trainer"] )
	addTradeSkill( L["Simple Black Dress"], 235, L["Trainer"] )
	addTradeSkill( L["Red Mageweave Shoulders"], 235, L["UWD"] )
	addTradeSkill( L["Red Mageweave Bag"], 235, L["Trainer"] )
	addTradeSkill( L["Pink Mageweave Shirt"], 235, L["Vendor"] )
	addTradeSkill( L["Admiral's Hat"], 240, L["Vendor"] )
	addTradeSkill( L["Shadoweave Boots"], 240, L["Trainer"] )
	addTradeSkill( L["Red Mageweave Headband"], 240, L["UWD"] )
	addTradeSkill( L["Tuxedo Shirt"], 240, L["Vendor"] )
	addTradeSkill( L["Shadoweave Mask"], 245, L["Shadoweave Mask Obt"] )
	addTradeSkill( L["Cindercloth Boots"], 245, L["Trainer"] )
	addTradeSkill( L["Tuxedo Pants"], 245, L["Vendor"] )
	addTradeSkill( L["White Wedding Dress"], 250, L["Vendor"] )
	addTradeSkill( L["Dreamweave Circlet"], 250, L["Trainer"] )
	addTradeSkill( L["Tuxedo Jacket"], 250, L["Vendor"] )
	addTradeSkill( L["Bolt of Runecloth"], 250, L["Trainer"] )
	addTradeSkill( L["Mooncloth"], 250, L["Vendor"] )
	addTradeSkill( L["Festive Red Dress"], 250, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Festival Dress"], 250, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Festive Red Pant Suit"], 250, L["Lunar Festival"], L["Seasonal"] )
	addTradeSkill( L["Runecloth Belt"], 255, L["Trainer"] )
	addTradeSkill( L["Frostweave Tunic"], 255, L["UWD"] )
	addTradeSkill( L["Frostweave Robe"], 255, L["UWD"] )
	addTradeSkill( L["Runecloth Robe"], 260, L["Vendor"] )
	addTradeSkill( L["Runecloth Bag"], 260, L["Vendor"] )
	addTradeSkill( L["Runecloth Tunic"], 260, L["UWD"] )
	addTradeSkill( L["Cindercloth Vest"], 260, L["Cindercloth Vest Obt"] )
	addTradeSkill( L["Soul Pouch"], 260, L["Vendor"] )
	addTradeSkill( L["Runecloth Cloak"], 265, L["Vendor"] )
	addTradeSkill( L["Ghostweave Belt"], 265, L["Ghostweave Belt Obt"] )
	addTradeSkill( L["Frostweave Gloves"], 265, L["UWD"] )
	addTradeSkill( L["Cindercloth Gloves"], 270, L["Cindercloth Gloves Obt"] )
	addTradeSkill( L["Brightcloth Gloves"], 270, L["UWD"] )
	addTradeSkill( L["Ghostweave Gloves"], 270, L["Ghostweave Gloves Obt"] )
	addTradeSkill( L["Brightcloth Robe"], 270, L["UWD"] )
	addTradeSkill( L["Ghostweave Vest"], 275, L["Ghostweave Vest Obt"] )
	addTradeSkill( L["Runecloth Gloves"], 275, L["Vendor"] )
	addTradeSkill( L["Cindercloth Cloak"], 275, L["Cindercloth Cloak Obt"] )
	addTradeSkill( L["Felcloth Pants"], 275, L["Vendor"] )
	addTradeSkill( L["Brightcloth Cloak"], 275, L["UWD"] )
	addTradeSkill( L["Wizardweave Leggings"], 275, L["Wizardweave Leggings Obt"] )
	addTradeSkill( L["Cloak of Fire"], 275, L["Cloak of Fire Obt"] )
	addTradeSkill( L["Enchanted Runecloth Bag"], 275, L["Vendor"] )
	addTradeSkill( L["Cenarion Herb Bag"], 275, L["Vendor"] )
	addTradeSkill( L["Runecloth Boots"], 280, L["Vendor"] )
	addTradeSkill( L["Frostweave Pants"], 280, L["UWD"] )
	addTradeSkill( L["Cindercloth Pants"], 280, L["Cindercloth Pants Obt"] )
	addTradeSkill( L["Robe of Winter Night"], 285, L["Robe of Winter Night Obt"] )
	addTradeSkill( L["Felcloth Boots"], 285, L["UWD"] )
	addTradeSkill( L["Runecloth Pants"], 285, L["UWD"] )
	addTradeSkill( L["Felcloth Bag"], 285, L["Felcloth Bag Obt"] )
	addTradeSkill( L["Brightcloth Pants"], 290, L["UWD"] )
	addTradeSkill( L["Mooncloth Leggings"], 290, L["UWD"] )
	addTradeSkill( L["Mooncloth Boots"], 290, L["Mooncloth Boots Obt"] )
	addTradeSkill( L["Ghostweave Pants"], 290, L["Ghostweave Pants Obt"] )
	addTradeSkill( L["Felcloth Hood"], 290, L["UWD"] )
	addTradeSkill( L["Wisdom of the Timbermaw"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Argent Boots"], 290, ARL_AddReputation1( BFAC["Honored"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Runecloth Headband"], 295, L["UWD"] )
	addTradeSkill( L["Mooncloth Bag"], 300, L["UWD"] )
	addTradeSkill( L["Wizardweave Robe"], 300, L["Wizardweave Robe Obt"] )
	addTradeSkill( L["Mooncloth Vest"], 300, L["UWD"] )
	addTradeSkill( L["Mooncloth Shoulders"], 300, L["UWD"] )
	addTradeSkill( L["Runecloth Shoulders"], 300, L["UWD"] )
	addTradeSkill( L["Wizardweave Turban"], 300, L["Wizardweave Turban Obt"] )
	addTradeSkill( L["Felcloth Robe"], 300, L["UWD"] )
	addTradeSkill( L["Mooncloth Circlet"], 300, L["RWD"] )
	addTradeSkill( L["Gordok Ogre Suit"], 300, L["Gordok Ogre Suit Obt"] )
	addTradeSkill( L["Felcloth Shoulders"], 300, L["UWD"] )
	addTradeSkill( L["Gloves of Spell Mastery"], 300, L["EWD"] )
	addTradeSkill( L["Bottomless Bag"], 300, L["RWD"] )
	addTradeSkill( L["Truefaith Vestments"], 300, L["Truefaith Vestments Obt"], BCLASS["Priest"] )
	addTradeSkill( L["Robe of the Archmage"], 300, L["Robe of the Archmage Obt"], BCLASS["Mage"] )
	addTradeSkill( L["Robe of the Void"], 300, L["Robe of the Void Obt"], BCLASS["Warlock"] )
	addTradeSkill( L["Flarecore Mantle"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Flarecore Gloves"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Flarecore Wraps"], 300, L["MOLTENCORE"] )
	addTradeSkill( L["Belt of the Archmage"], 300, L["DMCACHE"] )
	addTradeSkill( L["Felcloth Gloves"], 300, L["DMCACHE"] )
	addTradeSkill( L["Inferno Gloves"], 300, L["DMCACHE"] )
	addTradeSkill( L["Mooncloth Gloves"], 300, L["DMCACHE"] )
	addTradeSkill( L["Cloak of Warding"], 300, L["DMCACHE"] )
	addTradeSkill( L["Mooncloth Robe"], 300, L["Vendor"] )
	addTradeSkill( L["Mantle of the Timbermaw"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Timbermaw Hold"] ), BFAC["Timbermaw Hold"] )
	addTradeSkill( L["Argent Shoulders"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), BFAC["Argent Dawn"] )
	addTradeSkill( L["Flarecore Robe"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Flarecore Leggings"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Thorium Brotherhood"] ), BFAC["Thorium Brotherhood"] )
	addTradeSkill( L["Bloodvine Boots"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Bloodvine Leggings"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Bloodvine Vest"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Zandalar Tribe"] ), BFAC["Zandalar Tribe"] )
	addTradeSkill( L["Runed Stygian Belt"], 300, L["TrueBelieverQuest"] )
	addTradeSkill( L["Runed Stygian Boots"], 300, L["TrueBelieverQuest"] )
	addTradeSkill( L["Runed Stygian Leggings"], 300, L["TrueBelieverQuest"], L["Raid"] )
	addTradeSkill( L["Core Felcloth Bag"], 300, L["MOLTENCORE"] )
	addTradeSkill( L["Big Bag of Enchantment"], 300, L["Big Bag of Enchantment Obt"] )
	addTradeSkill( L["Satchel of Cenarius"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Gaea's Embrace"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Sylvan Crown"], 300, ARL_AddReputation1( BFAC["Honored"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Sylvan Shoulders"], 300, ARL_AddReputation1( BFAC["Friendly"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Sylvan Vest"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Cenarion Circle"] ), BFAC["Cenarion Circle"] )
	addTradeSkill( L["Glacial Gloves"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Glacial Wrists"], 300, ARL_AddReputation1( BFAC["Revered"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Glacial Vest"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Argent Dawn"] ), L["Raid"] )
	addTradeSkill( L["Glacial Cloak"], 300, ARL_AddReputation1( BFAC["Exalted"], BFAC["Argent Dawn"] ), L["Raid"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Netherweave Net"], 300, L["Trainer"] )
	addTradeSkill( L["Bolt of Netherweave"], 300, L["Trainer"] )
	addTradeSkill( L["Netherweave Bracers"], 310, L["Trainer"] )
	addTradeSkill( L["Netherweave Belt"], 310, L["Trainer"] )
	addTradeSkill( L["Netherweave Bag"], 315, L["Trainer"] )
	addTradeSkill( L["Netherweave Gloves"], 320, L["Trainer"] )
	addTradeSkill( L["Bolt of Imbued Netherweave"], 325, L["Vendor"] )
	addTradeSkill( L["Netherweave Pants"], 325, L["Trainer"] )
	addTradeSkill( L["Netherweave Boots"], 335, L["Trainer"] )
	addTradeSkill( L["Mystic Spellthread"], 335, ARL_AddReputation1( BFAC["Honored"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Silver Spellthread"], 335, ARL_AddReputation1( BFAC["Honored"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Imbued Netherweave Bag"], 340, L["Vendor"] )
	addTradeSkill( L["Netherweave Robe"], 340, L["Vendor"] )
	addTradeSkill( L["Imbued Netherweave Pants"], 340, L["Vendor"] )
	addTradeSkill( L["Bag of Jewels"], 340, ARL_AddReputation1( BFAC["Honored"], BFAC["The Consortium"] ), BFAC["The Consortium"] )
	addTradeSkill( L["Bolt of Soulcloth"], 345, L["Vendor"] )
	addTradeSkill( L["Netherweave Tunic"], 345, L["Vendor"] )
	addTradeSkill( L["Primal Mooncloth"], 350, L["Vendor"] )
	addTradeSkill( L["Imbued Netherweave Boots"], 350, L["Vendor"] )
	addTradeSkill( L["Arcanoweave Bracers"], 350, L["Arcanoweave Bracers Obt"] )
	addTradeSkill( L["Unyielding Bracers"], 350, L["UWD"] )
	addTradeSkill( L["Bracers of Havok"], 350, L["UWD"] )
	addTradeSkill( L["Blackstrike Bracers"], 350, L["UWD"] )
	addTradeSkill( L["Cloak of the Black Void"], 350, L["UWD"] )
	addTradeSkill( L["Cloak of Eternity"], 350, L["UWD"] )
	addTradeSkill( L["White Remedy Cape"], 350, L["UWD"] )
	addTradeSkill( L["Spellcloth"], 350, L["Vendor"] )
	addTradeSkill( L["Shadowcloth"], 350, L["Vendor"] )
	addTradeSkill( L["Cloak of Arcane Evasion"], 350, ARL_AddReputation1( BFAC["Honored"], BFAC["Lower City"] ), BFAC["Lower City"] )
	addTradeSkill( L["Flameheart Bracers"], 350, ARL_AddReputation1( BFAC["Friendly"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Soulcloth Gloves"], 355, L["Vendor"] )
	addTradeSkill( L["Imbued Netherweave Robe"], 360, L["Vendor"] )
	addTradeSkill( L["Imbued Netherweave Tunic"], 360, L["Vendor"] )
	addTradeSkill( L["Arcanoweave Boots"], 360, L["Arcanoweave Boots Obt"] )
	addTradeSkill( L["Flameheart Gloves"], 360, ARL_AddReputation1( BFAC["Honored"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Soulcloth Shoulders"], 365, L["Soulcloth Shoulders Obt"], L["Raid"] )
	addTradeSkill( L["Unyielding Girdle"], 365, L["UWD"] )
	addTradeSkill( L["Girdle of Ruination"], 365, L["UWD"] )
	addTradeSkill( L["Black Belt of Knowledge"], 365, L["UWD"] )
	addTradeSkill( L["Resolute Cape"], 365, L["UWD"] )
	addTradeSkill( L["Vengeance Wrap"], 365, L["UWD"] )
	addTradeSkill( L["Manaweave Cloak"], 365, L["UWD"] )
	addTradeSkill( L["Arcanoweave Robe"], 370, L["Arcanoweave Robe Obt"] )
	addTradeSkill( L["Flameheart Vest"], 370, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Spellfire Bag"], 375, L["Vendor"] )
	addTradeSkill( L["Ebon Shadowbag"], 375, L["Vendor"] )
	addTradeSkill( L["Primal Mooncloth Bag"], 375, L["Vendor"] )
	addTradeSkill( L["Soulcloth Vest"], 375, L["Soulcloth Vest"], L["Raid"] )
	addTradeSkill( L["Runic Spellthread"], 375, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Scryers"] ), BFAC["The Scryers"] )
	addTradeSkill( L["Golden Spellthread"], 375, ARL_AddReputation1( BFAC["Exalted"], BFAC["The Aldor"] ), BFAC["The Aldor"] )
	addTradeSkill( L["Whitemend Pants"], 375, L["Whitemend Pants Obt"] )
	addTradeSkill( L["Spellstrike Pants"], 375, L["Spellstrike Pants Obt"] )
	addTradeSkill( L["Battlecast Pants"], 375, L["Battlecast Pants Obt"] )
	addTradeSkill( L["Whitemend Hood"], 375, L["Whitemend Hood Obt"] )
	addTradeSkill( L["Spellstrike Hood"], 375, L["Spellstrike Hood Obt"] )
	addTradeSkill( L["Battlecast Hood"], 375, L["Battlecast Hood Obt"] )
	addTradeSkill( L["Boots of the Long Road"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Belt of the Long Road"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Belt of Blasting"], 375, L["SSC/TKBoP"], L["Raid"] )
	addTradeSkill( L["Boots of Blasting"], 375, L["SSC/TKBoE"], L["Raid"] )
	addTradeSkill( L["Swiftheal Wraps"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Swiftheal Mantle"], 375, L["BT/HYJALBoE"], L["Raid"] )
	addTradeSkill( L["Bracers of Nimble Thought"], 375, L["BT/HYJALBoP"], L["Raid"] )
	addTradeSkill( L["Mantle of Nimble Thought"], 375, L["BT/HYJALBoE"], L["Raid"] )
	addTradeSkill( L["Night's End"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Soulguard Bracers"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Soulguard Girdle"], 375, ARL_AddReputation1( BFAC["Friendly"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Soulguard Leggings"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )
	addTradeSkill( L["Soulguard Slippers"], 375, ARL_AddReputation1( BFAC["Honored"], BFAC["Ashtongue Deathsworn"] ), L["Raid"] )

	-- Wrath of the Litch King Recipes

	-- Primal Mooncloth Tailoring
	addTradeSkill( L["Primal Mooncloth Belt"], 355, L["Vendor"], BTS["Mooncloth Tailoring"] )
	addTradeSkill( L["Primal Mooncloth Shoulders"], 365, L["Vendor"], BTS["Mooncloth Tailoring"] )
	addTradeSkill( L["Primal Mooncloth Robe"], 375, L["Vendor"], BTS["Mooncloth Tailoring"] )

	-- Shadoweave Tailoring
	addTradeSkill( L["Frozen Shadoweave Shoulders"], 355, L["Vendor"], BTS["Shadoweave Tailoring"] )
	addTradeSkill( L["Frozen Shadoweave Boots"], 365, L["Vendor"], BTS["Shadoweave Tailoring"] )
	addTradeSkill( L["Frozen Shadoweave Vest"], 375, L["Vendor"], BTS["Shadoweave Tailoring"] )

	-- Spellfire Tailoring
	addTradeSkill( L["Spellfire Belt"], 355, L["Vendor"], BTS["Spellfire Tailoring"] )
	addTradeSkill( L["Spellfire Gloves"], 365, L["Vendor"], BTS["Spellfire Tailoring"] )
	addTradeSkill( L["Spellfire Vest"], 370, L["Vendor"], L["Trainer"], BTS["Spellfire Tailoring"] )

end

-- Initializes the array adding all Smelting recipes.  As of 2.2 there are 20 recipes.

local function ARL_InitSmelting()
  
	ARL_InitializeRecipeArray()

  	-- Original Game Recipes
	addTradeSkill( L["Smelt Copper"], 1, L["Trainer"] )
	addTradeSkill( L["Smelt Tin"], 65, L["Trainer"] )
	addTradeSkill( L["Smelt Bronze"], 65, L["Trainer"] )
	addTradeSkill( L["Smelt Silver"], 75, L["Trainer"] )
	addTradeSkill( L["Smelt Iron"], 125, L["Trainer"] )
	addTradeSkill( L["Smelt Gold"], 155, L["Trainer"] )
	addTradeSkill( L["Smelt Steel"], 165, L["Trainer"] )
	addTradeSkill( L["Smelt Mithril"], 175, L["Trainer"] )
	addTradeSkill( L["Smelt Dark Iron"], 230, L["Dark Iron Obt"] )
	addTradeSkill( L["Smelt Truesilver"], 230, L["Trainer"] )
	addTradeSkill( L["Smelt Thorium"], 250, L["Trainer"] )
	addTradeSkill( L["Smelt Elementium"], 270, L["Elementium Obt"], L["Raid"] )

	-- Burning Crusade Recipes
	addTradeSkill( L["Fire Sunder"], 300, L["Trainer"] )
	addTradeSkill( L["Earth Shatter"], 300, L["Trainer"] )
	addTradeSkill( L["Smelt Fel Iron"], 300, L["Trainer"] )
	addTradeSkill( L["Smelt Adamantite"], 350, L["Trainer"] )
	addTradeSkill( L["Smelt Felsteel"], 350, L["Trainer"] )
	addTradeSkill( L["Smelt Eternium"], 350, L["Trainer"] )
	addTradeSkill( L["Smelt Khorium"], 375, L["Trainer"] )
	addTradeSkill( L["Smelt Hardened Adamantite"], 375, L["Trainer"] )

	-- Wrath of the Litch King Recipes

end

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeTradeRecipes(CurrentProfession)

	if CurrentProfession == BTS["Alchemy"] then

		-- Add all alchemy recipes to the table
		ARL_InitAlchemy()
		
	elseif CurrentProfession == BTS["Blacksmithing"] then
		
		-- Add all blacksmithing recipes to the table
		ARL_InitBlackSmith()

	elseif CurrentProfession == BTS["Cooking"] then

		-- Add all cooking recipes to the table
		ARL_InitCooking()

	elseif CurrentProfession == BTS["Engineering"] then
		
		-- Add all engineering recipes to the table
		ARL_InitEngineering()
	
	elseif CurrentProfession == BTS["First Aid"] then

		-- Add all first aid recipes to the table
		ARL_InitFirstAid()

	elseif CurrentProfession == BTS["Leatherworking"] then

		-- Add all leatherworking recipes to the table		
		ARL_InitLeatherWorking()

	elseif CurrentProfession == BTS["Poisons"] then

		-- Add all rogue poisons recipes to the table
		ARL_InitRoguePoison()

	elseif CurrentProfession == BTS["Mining"] then

		-- Add all smelting recipes to the table
		ARL_InitSmelting()

	elseif CurrentProfession == BTS["Tailoring"] then

		-- Add all tailoring recipes to the table
		ARL_InitTailoring()

	-- Burning Crusade Professions
	elseif CurrentProfession == BTS["Jewelcrafting"] then

		-- Add all jewelcrafting recipes to the table
		ARL_InitJewelcrafting()

	else

		DEFAULT_CHAT_FRAME:AddMessage( L["UnknownTradeSkill"]:format( CurrentProfession ) )
		
	end

end

-- Initialize the profession tables depending on which skill window is opened.

local function ARL_InitializeCraftRecipes(CurrentProfession)

	local CurrentProfessionLevel

	if CurrentProfession == BTS["Enchanting"] then

		-- Get the current level of the craft.
		CurrentProfessionLevel = getglobal( "CraftRankFrame" ):GetValue() --Better way to do this?

		-- Add all enchanting recipes to the table
		ARL_InitEnchanting()

	elseif CurrentProfession == L["Beast Training"] then

		-- Player level = profession level for beast training
		CurrentProfessionLevel = UnitLevel("player")

		-- Add all beast training recipes to the table
		ARL_InitBeastTraining()

	else

		CurrentProfessionLevel = 0
		DEFAULT_CHAT_FRAME:AddMessage( L["UnknownTradeSkill"]:format( CurrentProfession ) )

	end

	return CurrentProfessionLevel

end

--[[

	GUI functions

]]--

-- Function to run when the + is clicked in the frame.  Will expand the recipe name and print out how to obtain it.

local function AckisRecipeList_OnClickExpandRecipe()

	if ( this.IsPushed == false ) then

		local RecipeText = this:GetText()

		-- Changed the graphic of the + to a -
		this:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-MinusButton-Down")
		this:SetDisabledTexture("Interface\\Buttons\\UI-MinusButton-Disabled")
		this:SetHighlightTexture("Interface\\Buttons\\UI-MinusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = true

		-- Show expanded text
		if ( MissingRecipeListing[ RecipeText ][ "Acquire" ] == nil ) then

			this.RecipeAquireText:SetText( "No acquisition information availible." )

		else

			this.RecipeAquireText:SetText( MissingRecipeListing[ RecipeText ][ "Acquire" ] )

		end

		-- Reposition the next recipe entry
		if ( this.NextRecipe ~= nil ) then

			local TempText = this.NextRecipe:GetText()

			this.NextRecipe:SetText("")
			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, -10)
			this.NextRecipe:SetText(TempText)

		end

	else

		-- Changed the graphic of the - to a +
		this:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
		this:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
		this:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
		this:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")

		-- Keep track of button state
		this.IsPushed = false

		-- Hide expanded text
		this.RecipeAquireText:SetText("")

		-- Reposition the next recipe entry
		if ( this.NextRecipe ~= nil ) then

			this.NextRecipe:ClearAllPoints()
			this.NextRecipe:SetPoint("TOPLEFT", this, "BOTTOMLEFT", 0, 0)

		end

	end

	AckisRecipeListFrameScrollBar:UpdateScrollChildRect()

end

-- Sets variables for RecipeButtons

local function AckisRecipeList_SetRecipeListParams(frame)

	frame:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up")
	frame:SetPushedTexture("Interface\\Buttons\\UI-PlusButton-Down")
	frame:SetDisabledTexture("Interface\\Buttons\\UI-PlusButton-Disabled")
	frame:SetHighlightTexture("Interface\\Buttons\\UI-PlusButton-Hilight")
	frame:SetTextColor(1, 1, 1)
	frame:SetScript("OnClick", AckisRecipeList_OnClickExpandRecipe)
	frame.IsPushed = false

	frame.RecipeAquireText = frame:CreateFontString(frame:GetName() .. "Text", "DIALOG")

	frame.RecipeAquireText:ClearAllPoints()
	frame.RecipeAquireText:SetPoint("TOPLEFT", frame, "BOTTOMLEFT", 10, 0)
	frame.RecipeAquireText:SetFontObject("GameFontNormalSmall")
	frame.RecipeAquireText:SetTextColor(1, 1, 1)

end

-- Scrolls the frame up and down

local function AckisRecipeList_ScrollBar()

end

-- Closes the frame and cleans sets everything that was displayed to nil

local function AckisRecipeList_CloseFrame()

	-- Clean up recipe entries
	local RecipeFrame = AckisRecipeListRecipe1

	-- Create x number of entries for all missing recipes
	while ( RecipeFrame ~= nil ) do

		RecipeFrame.RecipeAquireText:ClearAllPoints()
		RecipeFrame.RecipeAquireText:SetText("")
		RecipeFrame.RecipeAquireText:Hide()

		RecipeFrame:ClearAllPoints()
		RecipeFrame:SetText("")
		RecipeFrame:Hide()

		local NextRecipe = RecipeFrame.NextRecipe
		RecipeFrame = nil
		RecipeFrame = NextRecipe
		NextRecipe = nil

	end

	AckisRecipeListFrameCloseButton:ClearAllPoints()
	AckisRecipeListFrameCloseButton:SetText("")
	AckisRecipeListFrameCloseButton = nil

	AckisRecipeListFrameXButton:ClearAllPoints()
	AckisRecipeListFrameXButton = nil

	AckisRecipeListFrameScrollBar:ClearAllPoints()
	AckisRecipeListFrameScrollBar = nil

	AckisRecipeListFrameHeaderFrame:ClearAllPoints()
	AckisRecipeListFrameHeaderFrame = nil

	AckisRecipeListFrameHeaderFrameTexture:ClearAllPoints()
	AckisRecipeListFrameHeaderFrameTexture:Hide()
	AckisRecipeListFrameHeaderFrameTexture = nil

	AckisRecipeListFrameHeaderFrameText:ClearAllPoints()
	AckisRecipeListFrameHeaderFrameText:SetText("")
	AckisRecipeListFrameHeaderFrameText = nil

	AckisRecipeListFrame:ClearAllPoints()
	AckisRecipeListFrame:Hide()
	AckisRecipeListFrame = nil

end

-- Adds the necessary buttons to the main frame

local function ARL_AddButtons()

	-- Add close button
	AckisRecipeListFrameCloseButton = CreateFrame("Button", "AckisRecipeListFrameCloseButton", AckisRecipeListFrame, "UIPanelButtonTemplate")

	AckisRecipeListFrameCloseButton:SetFrameStrata("DIALOG")
	AckisRecipeListFrameCloseButton:SetWidth(100)
	AckisRecipeListFrameCloseButton:SetHeight(24)
	AckisRecipeListFrameCloseButton:ClearAllPoints()
	AckisRecipeListFrameCloseButton:SetPoint("BOTTOMRIGHT", AckisRecipeListFrame, -10, 10)
	AckisRecipeListFrameCloseButton:RegisterForClicks("LeftButtonUp")
	AckisRecipeListFrameCloseButton:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end)
	AckisRecipeListFrameCloseButton:SetFont("GameFontHighlightSmall",12)
	AckisRecipeListFrameCloseButton:Enable()
	AckisRecipeListFrameCloseButton:SetTextColor(1, 1, 1)
	AckisRecipeListFrameCloseButton:SetText("Close")

	-- Add a "close with x" button
	AckisRecipeListFrameXButton = CreateFrame("Button", "AckisRecipeListFrameXButton", AckisRecipeListFrame, "UIPanelCloseButton")

	AckisRecipeListFrameXButton:ClearAllPoints()
	AckisRecipeListFrameXButton:SetPoint("TOPRIGHT", AckisRecipeListFrame, "TOPRIGHT", 0, 0)
	AckisRecipeListFrameXButton:RegisterForClicks("LeftButtonUp")
	AckisRecipeListFrameXButton:SetScript("OnClick", function() AckisRecipeList_CloseFrame() end)
	AckisRecipeListFrameXButton:Enable()

end

-- Adds header to the main frame

local function ARL_AddHeader()

	-- Add header frame
	AckisRecipeListFrameHeaderFrame = CreateFrame("Frame", "AckisRecipeListFrameHeaderFrame", AckisRecipeListFrame)

	AckisRecipeListFrameHeaderFrame:SetWidth(192)
	AckisRecipeListFrameHeaderFrame:SetHeight(32)
	AckisRecipeListFrameHeaderFrame:ClearAllPoints()
	AckisRecipeListFrameHeaderFrame:SetPoint("TOP", AckisRecipeListFrame, "TOP", 0, 6)
	AckisRecipeListFrameHeaderFrame:EnableMouse(true)
	AckisRecipeListFrameHeaderFrame:SetMovable(true)
	AckisRecipeListFrameHeaderFrame:SetScript("OnMouseDown", function()	AckisRecipeListFrame:StartMoving()	end)
	AckisRecipeListFrameHeaderFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)

	-- Add texture to the header frame
	AckisRecipeListFrameHeaderFrameTexture = AckisRecipeListFrameHeaderFrame:CreateTexture("AckisRecipeListFrameHeaderFrameTexture", "ARTWORK")

	AckisRecipeListFrameHeaderFrameTexture:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
	AckisRecipeListFrameHeaderFrameTexture:SetWidth(384)
	AckisRecipeListFrameHeaderFrameTexture:SetHeight(64)
	AckisRecipeListFrameHeaderFrameTexture:ClearAllPoints()
	AckisRecipeListFrameHeaderFrameTexture:SetPoint("TOP", AckisRecipeListFrameHeaderFrame, "TOP", 0, 5)
	AckisRecipeListFrameHeaderFrameTexture:Show()

	-- Add text to header frame
	AckisRecipeListFrameHeaderFrameText = AckisRecipeListFrameHeaderFrame:CreateFontString("AckisRecipeListFrameHeaderFrameText", "ARTWORK")

	AckisRecipeListFrameHeaderFrameText:SetFontObject(GameFontNormal)
	AckisRecipeListFrameHeaderFrameText:ClearAllPoints()
	AckisRecipeListFrameHeaderFrameText:SetPoint("CENTER", AckisRecipeListFrameHeaderFrame, "CENTER", 0, 0)
	AckisRecipeListFrameHeaderFrameText:SetText(L["ARLTitle"])

end

-- Add progression bar to frame

local function ARL_ProgressionBar()

	AckisRecipeListFrameProgressBar = CreateFrame("StatusBar", "AckisRecipeListFrameProgressBar", AckisRecipeListFrame)

	AckisRecipeListFrameProgressBar:SetWidth(260)
	AckisRecipeListFrameProgressBar:SetHeight(20)
	AckisRecipeListFrameProgressBar:ClearAllPoints()
	AckisRecipeListFrameProgressBar:SetPoint("BOTTOMLEFT", AckisRecipeListFrame, 10, 10)
	AckisRecipeListFrameProgressBar:SetMinMaxValues(0, FoundRecipes)
	AckisRecipeListFrameProgressBar:SetStatusBarTexture("Interface\\PaperDollInfoFrame\\UI-Character-Skills-Bar")
	AckisRecipeListFrameProgressBar:SetValue(NumberOfRecipes)
	AckisRecipeListFrameProgressBar:SetOrientation("HORIZONTAL")
	AckisRecipeListFrameProgressBar:SetStatusBarColor(0.25, 0.25, 0.75)

	-- Add text to header frame
	AckisRecipeListFrameProgressBarText = AckisRecipeListFrameHeaderFrame:CreateFontString("AckisRecipeListFrameProgressBarText", "ARTWORK")

	AckisRecipeListFrameProgressBarText:SetFontObject(GameFontNormal)
	AckisRecipeListFrameProgressBarText:ClearAllPoints()
	AckisRecipeListFrameProgressBarText:SetPoint("CENTER", AckisRecipeListFrameProgressBar, "CENTER", 0, 0)
	AckisRecipeListFrameProgressBarText:SetText( L["GUIProgressBar"]:format( FoundRecipes, NumberOfRecipes, math.floor( FoundRecipes / NumberOfRecipes * 100 ) ) )

	AckisRecipeListFrameProgressBar:Show()

end

-- Adds a scroll bar to the main frame

local function ARL_AddScrollBar()

	-- Add scroll bar
	AckisRecipeListFrameScrollBar = CreateFrame("ScrollFrame", "AckisRecipeListFrameScrollBar", AckisRecipeListFrame, "UIPanelScrollFrameTemplate")

	AckisRecipeListFrameScrollBar:ClearAllPoints()
	AckisRecipeListFrameScrollBar:SetPoint("TOPRIGHT", AckisRecipeListFrame, -30, -30)
	AckisRecipeListFrameScrollBar:SetWidth(340)
	AckisRecipeListFrameScrollBar:SetHeight(350)
	AckisRecipeListFrameScrollBar:SetScript("OnVerticalScroll", AckisRecipeList_ScrollBar)
	AckisRecipeListFrameScrollBar:EnableMouseWheel(true)
	AckisRecipeListFrameScrollBar:EnableMouse(true)

	AckisRecipeListFrameScrollFrame = CreateFrame("Frame", "AckisRecipeListFrameScrollFrame", AckisRecipeListFrameScrollBar)
	AckisRecipeListFrameScrollFrame:SetHeight(300)
	AckisRecipeListFrameScrollFrame:SetWidth(340)
	AckisRecipeListFrameScrollFrame:ClearAllPoints()

	AckisRecipeListFrameScrollBar:SetScrollChild(AckisRecipeListFrameScrollFrame)

end

-- Adds recipe text info to the frames

local function ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedList, CurrentSpeciality)

	ARLProfessionText = AckisRecipeListFrameScrollFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	ARLProfessionText:SetTextColor(1.0, 1.0, 0.1)

	if ( CurrentSpeciality == "" ) then

		ARLProfessionText:SetText(CurrentProfession)

	else

		ARLProfessionText:SetText(L["RecipeListHeader"]:format(CurrentProfession, CurrentSpeciality) )

	end

	ARLProfessionText:SetPoint("TOP", 0, 0)

	local OldFrame = nil
	
	-- No sorting at all
	if ( SortedList == nil ) then

		local i = 1
		local RecipeName = next(MissingRecipeListing, nil)

		while ( RecipeName ~= nil ) do

			if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel) ) then

				local RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. i, AckisRecipeListFrameScrollFrame, "ClassTrainerSkillButtonTemplate")

				-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
				if ( OldFrame ~= nil ) then

					OldFrame.NextRecipe = RecipeFrame

				end

				-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable
				if ( i == AckisRecipeList:GetNumMissingRecipes() ) then

					RecipeFrame.NextRecipe = nil
		
				else

					OldFrame = RecipeFrame

				end

				RecipeFrame:ClearAllPoints()

				-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
				if ( i == 1 ) then

					RecipeFrame:SetPoint("TOPLEFT", AckisRecipeListFrameScrollFrame, "TOPLEFT", 5, -30)

				else

					RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (i - 1), "BOTTOMLEFT", 0, -1)

				end

				RecipeFrame:SetText(RecipeName)
				AckisRecipeList_SetRecipeListParams(RecipeFrame)
				RecipeFrame:Show()

			end

			i = i + 1

			-- Move on to the next entry in the table
			RecipeName = next(MissingRecipeListing, RecipeName)
	
		end

	-- Sorting
	else

		for i, RecipeName in ipairs(SortedList) do

			if ( AckisRecipeList:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel) ) then

				local RecipeFrame = CreateFrame("Button", "AckisRecipeListRecipe" .. i, AckisRecipeListFrameScrollFrame, "ClassTrainerSkillButtonTemplate")

				-- If we have a previous recipe, set the previous recipe next recipe to this current recipe
				if ( OldFrame ~= nil ) then

					OldFrame.NextRecipe = RecipeFrame

				end

				-- If we're at the last recipe, set the next reicpe to nil, otherwise set the previous entries nextrecipe to a temp variable
				if ( i == AckisRecipeList:GetNumMissingRecipes() ) then

					RecipeFrame.NextRecipe = nil
		
				else

					OldFrame = RecipeFrame

				end

				RecipeFrame:ClearAllPoints()

				-- If we're on the first recipe, set the points in relation to the main frame, otherwise set them in relation to the previous recipe
				if ( i == 1 ) then

					RecipeFrame:SetPoint("TOPLEFT", AckisRecipeListFrameScrollFrame, "TOPLEFT", 5, -30)

				else

					RecipeFrame:SetPoint("TOPLEFT", "AckisRecipeListRecipe" .. (i - 1), "BOTTOMLEFT", 0, -1)

				end

				RecipeFrame:SetText(RecipeName)
				AckisRecipeList_SetRecipeListParams(RecipeFrame)
				RecipeFrame:Show()

			end

		end

	end

end

-- Creates the initial frame to display recipes into

function AckisRecipeList:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

	-- Create the main frame
	AckisRecipeListFrame = CreateFrame("Frame", "AckisRecipeListFrame", UIParent)

	AckisRecipeListFrame:SetFrameStrata("DIALOG")
	AckisRecipeListFrame:SetWidth(384)
	AckisRecipeListFrame:SetHeight(430)
	AckisRecipeListFrame:SetBackdrop(
		{
			bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
			tile="false",
			edgeSize = 16,
			insets = {
						left = 5,
						right = 5,
						top = 5,
						bottom = 5
					}
		})
	AckisRecipeListFrame:SetBackdropColor(0, 0, 0)
	AckisRecipeListFrame:EnableMouse(true)
	AckisRecipeListFrame:SetMovable(true)
	AckisRecipeListFrame:ClearAllPoints()

	-- Anchor the frame to the trade window or the crafting window

	-- Anchor to Advanced Trade Skill Window
	if ( ATSWFrame ) then

		AckisRecipeListFrame:SetPoint("RIGHT", ATSW, "RIGHT", 345, 30)

	-- Anchor to trade skill window
	elseif ( SkillType == "Trade" ) then

		AckisRecipeListFrame:SetPoint("RIGHT", TradeSkillFrame, "RIGHT", 345, 30)

	-- Anchor to crafting window
	elseif ( SkillType == "Craft" ) then

		AckisRecipeListFrame:SetPoint("RIGHT", CraftFrame, "RIGHT", 345, 30)

	-- Nothing found to anchor, just put it up in the middle
	else

		AckisRecipeListFrame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)

	end

	AckisRecipeListFrame:SetScript("OnMouseDown", function() AckisRecipeListFrame:StartMoving() end)
	AckisRecipeListFrame:SetScript("OnMouseUp", function() AckisRecipeListFrame:StopMovingOrSizing() end)

	-- Add frame elements
	ARL_AddButtons()

	ARL_AddHeader()
	
	ARL_ProgressionBar()

	ARL_AddScrollBar()

	ARL_AddRecipeInfo(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

end

--[[

	Scanning functions

]]--

-- Scans your recipe book for Trade Skill Recipes

function AckisRecipeList:ScanTradeSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumTradeSkills() do

		skillName, skillType, _, _ = GetTradeSkillInfo(i)

		-- Ignore all trade skill headers
		if (skillType ~= "header") then

			AckisRecipeList:CheckRecipe(skillName)

		-- If it is a header then expand it so scanning can continue
		else

			ExpandTradeSkillSubClass(i)
		
		end

	end
	
end

-- Scans the recipelisting adding all missing recipes to the MissingRecipeListing

function AckisRecipeList:ScanMissingRecipes()

	-- Parse the recipe listing table, adding entries to the MissingRecipeListing table
	if ( RecipeListing ~= nil ) then

		local RecipeName = next(RecipeListing, nil)

			while (RecipeName ~= nil) do

				-- If the recipe is not known then print out the info
				if ( RecipeListing[ RecipeName ][ "Known" ] == false ) then

					MissingRecipeListing[ RecipeName ] = {}
					MissingRecipeListing[ RecipeName ][ "Level" ] = RecipeListing[ RecipeName ][ "Level" ]
					MissingRecipeListing[ RecipeName ][ "Acquire" ] = RecipeListing[ RecipeName ][ "Acquire" ]
					MissingRecipeListing[ RecipeName ][ "Speciality" ] = RecipeListing[ RecipeName ][ "Speciality" ]

				end

				-- Move on to the next entry in the table
				RecipeName = next(RecipeListing, RecipeName)
	
			end

	end

	-- Done with RecipeList now, so I can empty the table to free up memory now
	ARL_ResetRecipeList()

end

-- Scans your recipe book for Craft Skill Recipes (enchanting is handled differently than other trade skills)

function AckisRecipeList:ScanCraftSkills(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, _, skillType, _, isExpanded, _, _ = GetCraftInfo(i)

		-- Ignore all trade skill headers
		if (skillType ~= "header") then

			AckisRecipeList:CheckRecipe(skillName)

		-- If it is a header then expand it so scanning can continue
		else

			ExpandCraftSkillLine(i)

		end

	end

end

-- Scans your recipe book for beast training skills

function AckisRecipeList:ScanBeastTraining(CurrentTradeSkill)

	-- Scan through all recipes
	for i = 1, GetNumCrafts() do

		skillName, skillRank, _, _, _, _, _ = GetCraftInfo(i) -- Don't need a lot of this information, what to do with it?

		local FullSkillName = skillName .. " (" .. skillRank .. ")"

		AckisRecipeList:CheckRecipe(FullSkillName)

	end

end

-- Function to be called when /arl guiscan is run.

function AckisRecipeList:AckisRecipeList_GUISCAN()

	AckisRecipeList:AckisRecipeList_Command( "GUI" )

end

-- Function to be called when /arl scan is run.

function AckisRecipeList:AckisRecipeList_SCAN()

	AckisRecipeList:AckisRecipeList_Command( "NOGUI" )

end

-- Main logic for add-on, will call all sub-functions

function AckisRecipeList:AckisRecipeList_Command(ARLGUICheck)

	local CurrentProfession, CurrentProfessionLevel, CurrentSpeciality, SortedRecipeIndex

	if ( SkillType == nil ) then

		DEFAULT_CHAT_FRAME:AddMessage( L["OpenTradeSkillWindow"] )

	-- Trade type skills
	elseif ( SkillType == "Trade" ) then

		-- Get the name of the current trade skill opened, along with the current level of the skill. 
		CurrentProfession, CurrentProfessionLevel, _ = GetTradeSkillLine()

		CurrentSpeciality = AckisRecipeList:GetTradeSpeciality(CurrentProfession)

		ARL_InitializeTradeRecipes(CurrentProfession)

		if ( CurrentProfession == BTS["Poisons"] ) then

			-- Player level = profession level for rogue poisons
			CurrentProfessionLevel = UnitLevel("player")

		end

		AckisRecipeList:ScanTradeSkills(CurrentProfession)

		AckisRecipeList:ScanMissingRecipes()

		if ( AckisRecipeList:GetAllSorting() == "Skill" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingSkill)

		elseif ( AckisRecipeList:GetAllSorting() == "Name" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingName)

		end

		if ( ARLGUICheck == "NOGUI" ) then

			AckisRecipeList:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)

			AckisRecipeList:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex, CurrentProfession, CurrentSpeciality)

		else

			AckisRecipeList:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

		end

	-- Craft type skills
	elseif ( SkillType == "Craft" ) then

		-- Get the name of the current craft.
		CurrentProfession = GetCraftName()

		CurrentProfessionLevel = ARL_InitializeCraftRecipes(CurrentProfession)

		CurrentSpeciality = AckisRecipeList:GetTradeSpeciality(CurrentProfession)

		if CurrentProfession == BTS["Enchanting"] then

			-- Scan for missing enchanting recipes
			AckisRecipeList:ScanCraftSkills(CurrentProfession)

		elseif CurrentProfession == L["Beast Training"] then

			-- Scan for missing beast training
			AckisRecipeList:ScanBeastTraining(CurrentProfession)

		end

		AckisRecipeList:ScanMissingRecipes()

		if ( AckisRecipeList:GetAllSorting() == "Skill" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingSkill)

		elseif ( AckisRecipeList:GetAllSorting() == "Name" ) then

			SortedRecipeIndex = AckisRecipeList:SortMissingRecipes(ARL_SortMissingName)

		end

		if ( ARLGUICheck == "NOGUI" ) then

			AckisRecipeList:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)

			AckisRecipeList:DisplayRecipeResults(CurrentProfessionLevel, SortedRecipeIndex, CurrentProfession, CurrentSpeciality)

		else

			AckisRecipeList:AckisRecipeList_CreateFrame(CurrentProfession, CurrentProfessionLevel, SortedRecipeIndex, CurrentSpeciality)

		end	

	end

end
